declare module '@sage/wh-stock-api-partial' {
    import type {
        Depositor,
        Location,
        Package as SageWhMasterData$Package,
        StockNature,
        Store,
        UnitOfMeasure,
    } from '@sage/wh-master-data-api';
    import type { Package as SageWhProductData$Package, Product, ProductsContainer } from '@sage/wh-product-data-api';
    import type { Package as SageWhStockData$Package } from '@sage/wh-stock-data-api';
    import type { Package as SageWhStructure$Package } from '@sage/wh-structure-api';
    import type { Package as SageWhSystem$Package, Site } from '@sage/wh-system-api';
    import type { Package as SageXtremAppMetadata$Package } from '@sage/xtrem-app-metadata-api';
    import type { Package as SageXtremX3SystemUtils$Package, SysUser } from '@sage/xtrem-x3-system-utils-api';
    import type {
        AggregateQueryOperation,
        AggregateReadOperation,
        ClientNode,
        ClientNodeInput,
        GetDefaultsOperation,
        QueryOperation,
        ReadOperation,
        decimal,
        integer,
    } from '@sage/xtrem-client';
    export interface SimplifiedStockCountLine extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        simplifiedStockCount: SimplifiedStockCount;
        line: integer;
        status: SimplifiedStockCountStatus;
        depositor: Depositor;
        product: Product;
        homogeneousQuantity: string;
        homogeneousContainer: ProductsContainer;
        enteredQuantity: string;
        pendingInputQuantity: string;
        pendingOutputQuantity: string;
        expectedQuantity: string;
    }
    export interface SimplifiedStockCountLineInput extends ClientNodeInput {
        site?: string;
        simplifiedStockCount?: string;
        line?: integer | string;
        status?: SimplifiedStockCountStatus;
        depositor?: string;
        product?: string;
        homogeneousQuantity?: decimal | string;
        homogeneousContainer?: string;
        enteredQuantity?: decimal | string;
        pendingInputQuantity?: decimal | string;
        pendingOutputQuantity?: decimal | string;
        expectedQuantity?: decimal | string;
    }
    export interface SimplifiedStockCountLineBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        simplifiedStockCount: SimplifiedStockCount;
        line: integer;
        status: SimplifiedStockCountStatus;
        depositor: Depositor;
        product: Product;
        homogeneousQuantity: string;
        homogeneousContainer: ProductsContainer;
        enteredQuantity: string;
        pendingInputQuantity: string;
        pendingOutputQuantity: string;
        expectedQuantity: string;
    }
    export interface SimplifiedStockCountLine$Lookups {
        site: QueryOperation<Site>;
        simplifiedStockCount: QueryOperation<SimplifiedStockCount>;
        depositor: QueryOperation<Depositor>;
        product: QueryOperation<Product>;
        homogeneousContainer: QueryOperation<ProductsContainer>;
    }
    export interface SimplifiedStockCountLine$Operations {
        query: QueryOperation<SimplifiedStockCountLine>;
        read: ReadOperation<SimplifiedStockCountLine>;
        aggregate: {
            read: AggregateReadOperation<SimplifiedStockCountLine>;
            query: AggregateQueryOperation<SimplifiedStockCountLine>;
        };
        lookups(dataOrId: string | { data: SimplifiedStockCountLineInput }): SimplifiedStockCountLine$Lookups;
        getDefaults: GetDefaultsOperation<SimplifiedStockCountLine>;
    }
    export interface SimplifiedStockCount extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        reference: string;
        status: SimplifiedStockCountStatus;
        store: Store;
        location: Location;
        closingDate: string;
    }
    export interface SimplifiedStockCountInput extends ClientNodeInput {
        site?: string;
        code?: string;
        reference?: string;
        status?: SimplifiedStockCountStatus;
        store?: string;
        location?: string;
        closingDate?: string;
    }
    export interface SimplifiedStockCountBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        reference: string;
        status: SimplifiedStockCountStatus;
        store: Store;
        location: Location;
        closingDate: string;
    }
    export interface SimplifiedStockCount$Lookups {
        site: QueryOperation<Site>;
        store: QueryOperation<Store>;
        location: QueryOperation<Location>;
    }
    export interface SimplifiedStockCount$Operations {
        query: QueryOperation<SimplifiedStockCount>;
        read: ReadOperation<SimplifiedStockCount>;
        aggregate: {
            read: AggregateReadOperation<SimplifiedStockCount>;
            query: AggregateQueryOperation<SimplifiedStockCount>;
        };
        lookups(dataOrId: string | { data: SimplifiedStockCountInput }): SimplifiedStockCount$Lookups;
        getDefaults: GetDefaultsOperation<SimplifiedStockCount>;
    }
    export interface StockImage extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        product: Product;
        stockStatus: StockNature;
        lotNumber: string;
        quantityInStock: string;
        quantityInPendingOutput: string;
        quantityInPendingInput: string;
        quantityReceivedButNotAddressed: string;
        quantityPreparedButNotShipped: string;
        quantityBlocked: string;
        quantityInReserve: string;
        quantityBlockedInPendingInput: string;
        quantityBlockedInPendingOutput: string;
        quantityReservedPendingInput: string;
        quantityReservedPendingOutput: string;
        quantityInBalanceForPreparation: string;
        quantityReserveToBePrepared: string;
        quantityExpected: string;
        quantityInPendingAssembly: string;
        stockUnit: UnitOfMeasure;
    }
    export interface StockImageInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        product?: string;
        stockStatus?: string;
        lotNumber?: string;
        quantityInStock?: decimal | string;
        quantityInPendingOutput?: decimal | string;
        quantityInPendingInput?: decimal | string;
        quantityReceivedButNotAddressed?: decimal | string;
        quantityPreparedButNotShipped?: decimal | string;
        quantityBlocked?: decimal | string;
        quantityInReserve?: decimal | string;
        quantityBlockedInPendingInput?: decimal | string;
        quantityBlockedInPendingOutput?: decimal | string;
        quantityReservedPendingInput?: decimal | string;
        quantityReservedPendingOutput?: decimal | string;
        quantityInBalanceForPreparation?: decimal | string;
        quantityReserveToBePrepared?: decimal | string;
        quantityExpected?: decimal | string;
        quantityInPendingAssembly?: decimal | string;
        stockUnit?: string;
    }
    export interface StockImageBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        product: Product;
        stockStatus: StockNature;
        lotNumber: string;
        quantityInStock: string;
        quantityInPendingOutput: string;
        quantityInPendingInput: string;
        quantityReceivedButNotAddressed: string;
        quantityPreparedButNotShipped: string;
        quantityBlocked: string;
        quantityInReserve: string;
        quantityBlockedInPendingInput: string;
        quantityBlockedInPendingOutput: string;
        quantityReservedPendingInput: string;
        quantityReservedPendingOutput: string;
        quantityInBalanceForPreparation: string;
        quantityReserveToBePrepared: string;
        quantityExpected: string;
        quantityInPendingAssembly: string;
        stockUnit: UnitOfMeasure;
    }
    export interface StockImage$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        product: QueryOperation<Product>;
        stockStatus: QueryOperation<StockNature>;
        stockUnit: QueryOperation<UnitOfMeasure>;
    }
    export interface StockImage$Operations {
        query: QueryOperation<StockImage>;
        read: ReadOperation<StockImage>;
        aggregate: {
            read: AggregateReadOperation<StockImage>;
            query: AggregateQueryOperation<StockImage>;
        };
        lookups(dataOrId: string | { data: StockImageInput }): StockImage$Lookups;
        getDefaults: GetDefaultsOperation<StockImage>;
    }
    export interface Package {
        '@sage/wh-stock/SimplifiedStockCountLine': SimplifiedStockCountLine$Operations;
        '@sage/wh-stock/SimplifiedStockCount': SimplifiedStockCount$Operations;
        '@sage/wh-stock/StockImage': StockImage$Operations;
    }
    export interface GraphApi
        extends Package,
            SageWhMasterData$Package,
            SageWhProductData$Package,
            SageWhStockData$Package,
            SageWhStructure$Package,
            SageWhSystem$Package,
            SageXtremAppMetadata$Package,
            SageXtremX3SystemUtils$Package {}
}
declare module '@sage/wh-stock-api' {
    export type * from '@sage/wh-stock-api-partial';
}
declare module '@sage/wh-master-data-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/wh-stock-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/wh-product-data-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/wh-stock-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/wh-stock-data-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/wh-stock-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/wh-structure-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/wh-stock-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/wh-system-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/wh-stock-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/xtrem-app-metadata-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/wh-stock-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/xtrem-x3-system-utils-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/wh-stock-api';
    export interface GraphApi extends GraphApiExtension {}
}
