declare module '@sage/wh-stock-data-api-partial' {
    import type {
        AppointmentManagement,
        AssignmentClass,
        Carrier,
        Currency,
        Customer,
        Depositor,
        GenericRound,
        GenericWave,
        Location,
        LocationInput,
        LocationSplitAddresses,
        LocationSplitAddressesBinding,
        LocationSplitAddressesInput,
        MovementCode,
        Operand,
        Package as SageWhMasterData$Package,
        ParcelType,
        PreparationArea,
        RangeOfParcel,
        RotationClass,
        SerialGroup,
        ShippingUnitType,
        StockCountClass,
        StockNature,
        StorageType,
        Store,
        Supplier,
        TariffCode,
        TransportMode,
        TransportType,
        UnitOfMeasure,
        WorkCenter,
    } from '@sage/wh-master-data-api';
    import type {
        Container,
        Family,
        Group,
        HazardousMaterialsClass,
        IcpeClasses,
        InputMode,
        OnuCode,
        Origin,
        OutputMode,
        Package as SageWhProductData$Package,
        PickingMode,
        Product,
        ProductActiveMatters,
        ProductActiveMattersBinding,
        ProductActiveMattersInput,
        ProductInput,
        ProductIsPrintableDescriptions,
        ProductIsPrintableDescriptionsBinding,
        ProductIsPrintableDescriptionsInput,
        ProductPercentageActiveMatters,
        ProductPercentageActiveMattersBinding,
        ProductPercentageActiveMattersInput,
        ProductsContainer,
        ReceiptMode,
        Risk,
        SubFamily,
        SubGroup,
        TransportCategory,
    } from '@sage/wh-product-data-api';
    import type { Country, Package as SageWhStructure$Package } from '@sage/wh-structure-api';
    import type { GenericPrintReport, Language, Package as SageWhSystem$Package, Site } from '@sage/wh-system-api';
    import type { Package as SageXtremAppMetadata$Package } from '@sage/xtrem-app-metadata-api';
    import type { Package as SageXtremX3SystemUtils$Package, SysUser } from '@sage/xtrem-x3-system-utils-api';
    import type {
        AggregateQueryOperation,
        AggregateReadOperation,
        BinaryStream,
        ClientCollection,
        ClientNode,
        ClientNodeInput,
        GetDefaultsOperation,
        QueryOperation,
        ReadOperation,
        VitalClientNode,
        VitalClientNodeInput,
        decimal,
        integer,
    } from '@sage/xtrem-client';
    export interface AdjustmentMovementFinalsAndInitialsValues extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        consumptionUnitQuantity: string;
        homogeneousContainer: ProductsContainer;
        homogeneousQuantity: string;
        container: ProductsContainer;
        numberOfContainer: string;
        stockStatus: StockNature;
        originSource: Origin;
        reservationNumber: string;
        supportNumber: string;
        lotNumber: string;
        receiptDate: string;
        manufacturedDate: string;
        sellByDate: string;
        shipByDate: string;
        useByDate: string;
        detentionDate: string;
        fifoDate: string;
    }
    export interface AdjustmentMovementFinalsAndInitialsValuesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        consumptionUnitQuantity?: decimal | string;
        homogeneousContainer?: string;
        homogeneousQuantity?: decimal | string;
        container?: string;
        numberOfContainer?: decimal | string;
        stockStatus?: string;
        originSource?: string;
        reservationNumber?: string;
        supportNumber?: string;
        lotNumber?: string;
        receiptDate?: string;
        manufacturedDate?: string;
        sellByDate?: string;
        shipByDate?: string;
        useByDate?: string;
        detentionDate?: string;
        fifoDate?: string;
    }
    export interface AdjustmentMovementFinalsAndInitialsValuesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        consumptionUnitQuantity: string;
        homogeneousContainer: ProductsContainer;
        homogeneousQuantity: string;
        container: ProductsContainer;
        numberOfContainer: string;
        stockStatus: StockNature;
        originSource: Origin;
        reservationNumber: string;
        supportNumber: string;
        lotNumber: string;
        receiptDate: string;
        manufacturedDate: string;
        sellByDate: string;
        shipByDate: string;
        useByDate: string;
        detentionDate: string;
        fifoDate: string;
    }
    export interface AdjustmentMovementFinalsAndInitialsValues$Lookups {
        homogeneousContainer: QueryOperation<ProductsContainer>;
        container: QueryOperation<ProductsContainer>;
        stockStatus: QueryOperation<StockNature>;
        originSource: QueryOperation<Origin>;
    }
    export interface AdjustmentMovementFinalsAndInitialsValues$Operations {
        query: QueryOperation<AdjustmentMovementFinalsAndInitialsValues>;
        read: ReadOperation<AdjustmentMovementFinalsAndInitialsValues>;
        aggregate: {
            read: AggregateReadOperation<AdjustmentMovementFinalsAndInitialsValues>;
            query: AggregateQueryOperation<AdjustmentMovementFinalsAndInitialsValues>;
        };
        lookups(
            dataOrId: string | { data: AdjustmentMovementFinalsAndInitialsValuesInput },
        ): AdjustmentMovementFinalsAndInitialsValues$Lookups;
        getDefaults: GetDefaultsOperation<AdjustmentMovementFinalsAndInitialsValues>;
    }
    export interface AdjustmentMovement extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        date: string;
        time: string;
        movement: MovementCode;
        movementType: AdjustmentType;
        product: Product;
        store: Store;
        location: Location;
        locationType: LocationType;
        stockObject: StockObject;
        containerNumber: string;
        stockObjectLinkNumber: string;
        adjustmentQuantity: string;
        adjustmentContainer: ProductsContainer;
        adjustmentConsumptionUnitQuantity: string;
        level: ContainerLevel;
        isKeyInSerialNumber: boolean;
        stockCount: StockCount;
        counting: Counting;
        countingLine: CountLine;
        assemblyDeclaration: KitDeclaration;
        transfer: TransferMovement;
        movementTransfer: TransferMovement;
        adjustmentComment: string;
        finalsAndInitialsValues: ClientCollection<AdjustmentMovementFinalsAndInitialsValues>;
    }
    export interface AdjustmentMovementInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        date?: string;
        time?: string;
        movement?: string;
        movementType?: AdjustmentType;
        product?: string;
        store?: string;
        location?: string;
        locationType?: LocationType;
        stockObject?: string;
        containerNumber?: string;
        stockObjectLinkNumber?: string;
        adjustmentQuantity?: decimal | string;
        adjustmentContainer?: string;
        adjustmentConsumptionUnitQuantity?: decimal | string;
        level?: ContainerLevel;
        isKeyInSerialNumber?: boolean | string;
        stockCount?: string;
        counting?: integer | string;
        countingLine?: integer | string;
        assemblyDeclaration?: string;
        transfer?: string;
        movementTransfer?: string;
        adjustmentComment?: string;
        finalsAndInitialsValues?: Partial<AdjustmentMovementFinalsAndInitialsValuesInput>[];
    }
    export interface AdjustmentMovementBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        date: string;
        time: string;
        movement: MovementCode;
        movementType: AdjustmentType;
        product: Product;
        store: Store;
        location: Location;
        locationType: LocationType;
        stockObject: StockObject;
        containerNumber: string;
        stockObjectLinkNumber: string;
        adjustmentQuantity: string;
        adjustmentContainer: ProductsContainer;
        adjustmentConsumptionUnitQuantity: string;
        level: ContainerLevel;
        isKeyInSerialNumber: boolean;
        stockCount: StockCount;
        counting: Counting;
        countingLine: CountLine;
        assemblyDeclaration: KitDeclaration;
        transfer: TransferMovement;
        movementTransfer: TransferMovement;
        adjustmentComment: string;
        finalsAndInitialsValues: ClientCollection<AdjustmentMovementFinalsAndInitialsValuesBinding>;
    }
    export interface AdjustmentMovement$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        movement: QueryOperation<MovementCode>;
        product: QueryOperation<Product>;
        store: QueryOperation<Store>;
        location: QueryOperation<Location>;
        stockObject: QueryOperation<StockObject>;
        adjustmentContainer: QueryOperation<ProductsContainer>;
        stockCount: QueryOperation<StockCount>;
        counting: QueryOperation<Counting>;
        countingLine: QueryOperation<CountLine>;
        assemblyDeclaration: QueryOperation<KitDeclaration>;
        transfer: QueryOperation<TransferMovement>;
        movementTransfer: QueryOperation<TransferMovement>;
    }
    export interface AdjustmentMovement$Operations {
        query: QueryOperation<AdjustmentMovement>;
        read: ReadOperation<AdjustmentMovement>;
        aggregate: {
            read: AggregateReadOperation<AdjustmentMovement>;
            query: AggregateQueryOperation<AdjustmentMovement>;
        };
        lookups(dataOrId: string | { data: AdjustmentMovementInput }): AdjustmentMovement$Lookups;
        getDefaults: GetDefaultsOperation<AdjustmentMovement>;
    }
    export interface AdministrativeReceiptLine extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        receipt: AdministrativeReceipt;
        expectedInput: ExpectedInput;
        expectedInputLine: ExpectedInputLine;
        splitLineNumber: integer;
        depositor: Depositor;
        lineNumber: integer;
        status: ReceiptLineStatus;
        product: Product;
        receivedQuantityInConsumptionUnit: string;
        inputContainer: ProductsContainer;
        lotNumber: string;
        supportNumber: string;
        reservationNumber: string;
        stockStatus: StockNature;
        store: Store;
        isExclusiveStore: boolean;
        isDispute: boolean;
        isPutAway: boolean;
        source: Origin;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        useByDate: string;
        shipByDate: string;
        fifoDate: string;
        administrativeReceiptMovements: ClientCollection<AdministrativeReceiptMovement>;
    }
    export interface AdministrativeReceiptLineInput extends ClientNodeInput {
        site?: string;
        receipt?: string;
        expectedInput?: string;
        expectedInputLine?: integer | string;
        splitLineNumber?: integer | string;
        depositor?: string;
        lineNumber?: integer | string;
        status?: ReceiptLineStatus;
        product?: string;
        receivedQuantityInConsumptionUnit?: decimal | string;
        inputContainer?: string;
        lotNumber?: string;
        supportNumber?: string;
        reservationNumber?: string;
        stockStatus?: string;
        store?: string;
        isExclusiveStore?: boolean | string;
        isDispute?: boolean | string;
        isPutAway?: boolean | string;
        source?: string;
        manufacturedDate?: string;
        detentionDate?: string;
        sellByDate?: string;
        useByDate?: string;
        shipByDate?: string;
        fifoDate?: string;
        administrativeReceiptMovements?: Partial<AdministrativeReceiptMovementInput>[];
    }
    export interface AdministrativeReceiptLineBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        receipt: AdministrativeReceipt;
        expectedInput: ExpectedInput;
        expectedInputLine: ExpectedInputLine;
        splitLineNumber: integer;
        depositor: Depositor;
        lineNumber: integer;
        status: ReceiptLineStatus;
        product: Product;
        receivedQuantityInConsumptionUnit: string;
        inputContainer: ProductsContainer;
        lotNumber: string;
        supportNumber: string;
        reservationNumber: string;
        stockStatus: StockNature;
        store: Store;
        isExclusiveStore: boolean;
        isDispute: boolean;
        isPutAway: boolean;
        source: Origin;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        useByDate: string;
        shipByDate: string;
        fifoDate: string;
        administrativeReceiptMovements: ClientCollection<AdministrativeReceiptMovement>;
    }
    export interface AdministrativeReceiptLine$Lookups {
        site: QueryOperation<Site>;
        receipt: QueryOperation<AdministrativeReceipt>;
        expectedInput: QueryOperation<ExpectedInput>;
        expectedInputLine: QueryOperation<ExpectedInputLine>;
        depositor: QueryOperation<Depositor>;
        product: QueryOperation<Product>;
        inputContainer: QueryOperation<ProductsContainer>;
        stockStatus: QueryOperation<StockNature>;
        store: QueryOperation<Store>;
        source: QueryOperation<Origin>;
    }
    export interface AdministrativeReceiptLine$Operations {
        query: QueryOperation<AdministrativeReceiptLine>;
        read: ReadOperation<AdministrativeReceiptLine>;
        aggregate: {
            read: AggregateReadOperation<AdministrativeReceiptLine>;
            query: AggregateQueryOperation<AdministrativeReceiptLine>;
        };
        lookups(dataOrId: string | { data: AdministrativeReceiptLineInput }): AdministrativeReceiptLine$Lookups;
        getDefaults: GetDefaultsOperation<AdministrativeReceiptLine>;
    }
    export interface AdministrativeReceiptMovement extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        receipt: AdministrativeReceipt;
        lineNumber: integer;
        receiptMovementNumber: integer;
        depositor: Depositor;
        product: Product;
        numberOfContainers: string;
        container: ProductsContainer;
        numberOfConsumptionUnit: string;
        homogeneousQuantity: string;
        homogeneousContainer: ProductsContainer;
    }
    export interface AdministrativeReceiptMovementInput extends ClientNodeInput {
        site?: string;
        receipt?: string;
        lineNumber?: integer | string;
        receiptMovementNumber?: integer | string;
        depositor?: string;
        product?: string;
        numberOfContainers?: decimal | string;
        container?: string;
        numberOfConsumptionUnit?: decimal | string;
        homogeneousQuantity?: decimal | string;
        homogeneousContainer?: string;
    }
    export interface AdministrativeReceiptMovementBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        receipt: AdministrativeReceipt;
        lineNumber: integer;
        receiptMovementNumber: integer;
        depositor: Depositor;
        product: Product;
        numberOfContainers: string;
        container: ProductsContainer;
        numberOfConsumptionUnit: string;
        homogeneousQuantity: string;
        homogeneousContainer: ProductsContainer;
    }
    export interface AdministrativeReceiptMovement$Lookups {
        site: QueryOperation<Site>;
        receipt: QueryOperation<AdministrativeReceipt>;
        depositor: QueryOperation<Depositor>;
        product: QueryOperation<Product>;
        container: QueryOperation<ProductsContainer>;
        homogeneousContainer: QueryOperation<ProductsContainer>;
    }
    export interface AdministrativeReceiptMovement$Operations {
        query: QueryOperation<AdministrativeReceiptMovement>;
        read: ReadOperation<AdministrativeReceiptMovement>;
        aggregate: {
            read: AggregateReadOperation<AdministrativeReceiptMovement>;
            query: AggregateQueryOperation<AdministrativeReceiptMovement>;
        };
        lookups(dataOrId: string | { data: AdministrativeReceiptMovementInput }): AdministrativeReceiptMovement$Lookups;
        getDefaults: GetDefaultsOperation<AdministrativeReceiptMovement>;
    }
    export interface AdministrativeReceipt extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        carrierAppointment: AppointmentManagement;
        carrier: Carrier;
        carrierName: string;
        carriageReference: string;
        transportationMethod: TransportMode;
        store: Store;
        dock: Location;
        date: string;
        time: string;
        numberOfLoads: integer;
        grossWeight: string;
        status: ReceiptStatus;
        duration: string;
        lines: ClientCollection<AdministrativeReceiptLine>;
    }
    export interface AdministrativeReceiptInput extends ClientNodeInput {
        site?: string;
        code?: string;
        carrierAppointment?: string;
        carrier?: string;
        carrierName?: string;
        carriageReference?: string;
        transportationMethod?: string;
        store?: string;
        dock?: string;
        date?: string;
        time?: string;
        numberOfLoads?: integer | string;
        grossWeight?: decimal | string;
        status?: ReceiptStatus;
        duration?: string;
        lines?: Partial<AdministrativeReceiptLineInput>[];
    }
    export interface AdministrativeReceiptBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        carrierAppointment: AppointmentManagement;
        carrier: Carrier;
        carrierName: string;
        carriageReference: string;
        transportationMethod: TransportMode;
        store: Store;
        dock: Location;
        date: string;
        time: string;
        numberOfLoads: integer;
        grossWeight: string;
        status: ReceiptStatus;
        duration: string;
        lines: ClientCollection<AdministrativeReceiptLine>;
    }
    export interface AdministrativeReceipt$Lookups {
        site: QueryOperation<Site>;
        carrierAppointment: QueryOperation<AppointmentManagement>;
        carrier: QueryOperation<Carrier>;
        transportationMethod: QueryOperation<TransportMode>;
        store: QueryOperation<Store>;
        dock: QueryOperation<Location>;
    }
    export interface AdministrativeReceipt$Operations {
        query: QueryOperation<AdministrativeReceipt>;
        read: ReadOperation<AdministrativeReceipt>;
        aggregate: {
            read: AggregateReadOperation<AdministrativeReceipt>;
            query: AggregateQueryOperation<AdministrativeReceipt>;
        };
        lookups(dataOrId: string | { data: AdministrativeReceiptInput }): AdministrativeReceipt$Lookups;
        getDefaults: GetDefaultsOperation<AdministrativeReceipt>;
    }
    export interface AssemblingMovementContainerLevels extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        containerLevel: ProductsContainer;
        quantityOfConsumptionUnitPerLevel: string;
    }
    export interface AssemblingMovementContainerLevelsInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        containerLevel?: string;
        quantityOfConsumptionUnitPerLevel?: decimal | string;
    }
    export interface AssemblingMovementContainerLevelsBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        containerLevel: ProductsContainer;
        quantityOfConsumptionUnitPerLevel: string;
    }
    export interface AssemblingMovementContainerLevels$Lookups {
        containerLevel: QueryOperation<ProductsContainer>;
    }
    export interface AssemblingMovementContainerLevels$Operations {
        query: QueryOperation<AssemblingMovementContainerLevels>;
        read: ReadOperation<AssemblingMovementContainerLevels>;
        aggregate: {
            read: AggregateReadOperation<AssemblingMovementContainerLevels>;
            query: AggregateQueryOperation<AssemblingMovementContainerLevels>;
        };
        lookups(
            dataOrId: string | { data: AssemblingMovementContainerLevelsInput },
        ): AssemblingMovementContainerLevels$Lookups;
        getDefaults: GetDefaultsOperation<AssemblingMovementContainerLevels>;
    }
    export interface AssemblingMovement extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        assemblyOrder: AssemblingOrder;
        assemblyOrderLineNumber: integer;
        assemblyWave: AssemblingWave;
        lineType: DoLineType;
        product: Product;
        numberOfContainer: string;
        container: ProductsContainer;
        homogeneousContainerCoefficient: string;
        consumptionUnitQuantity: string;
        numberOfKits: string;
        movementCode: MovementCode;
        lotNumber: string;
        stockStatus: StockNature;
        reservationNumber: string;
        supportNumber: string;
        status: AssemblyMovementStatus;
        originSource: Origin;
        receiptDate: string;
        fifoDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        shipByDate: string;
        useByDate: string;
        store: Store;
        location: Location;
        locationType: LocationType;
        stockObject: StockObject;
        replenishment: TransferMovement;
        transfer: TransferMovement;
        adjustment: AdjustmentMovement;
        kitDeclaration: KitDeclaration;
        isKitTransferAuthorized: boolean;
        flowNumber: integer;
        containerNumber: string;
        homogeneousContainer: ProductsContainer;
        homogeneousQuantity: string;
        originContainer: ProductsContainer;
        originQuantity: string;
        validatingOperator: Operand;
        validatingUser: string;
        postingDate: string;
        postingTime: integer;
        containerLevels: ClientCollection<AssemblingMovementContainerLevels>;
    }
    export interface AssemblingMovementInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        assemblyOrder?: string;
        assemblyOrderLineNumber?: integer | string;
        assemblyWave?: string;
        lineType?: DoLineType;
        product?: string;
        numberOfContainer?: decimal | string;
        container?: string;
        homogeneousContainerCoefficient?: decimal | string;
        consumptionUnitQuantity?: decimal | string;
        numberOfKits?: decimal | string;
        movementCode?: string;
        lotNumber?: string;
        stockStatus?: string;
        reservationNumber?: string;
        supportNumber?: string;
        status?: AssemblyMovementStatus;
        originSource?: string;
        receiptDate?: string;
        fifoDate?: string;
        manufacturedDate?: string;
        detentionDate?: string;
        sellByDate?: string;
        shipByDate?: string;
        useByDate?: string;
        store?: string;
        location?: string;
        locationType?: LocationType;
        stockObject?: string;
        replenishment?: string;
        transfer?: string;
        adjustment?: string;
        kitDeclaration?: string;
        isKitTransferAuthorized?: boolean | string;
        flowNumber?: integer | string;
        containerNumber?: string;
        homogeneousContainer?: string;
        homogeneousQuantity?: decimal | string;
        originContainer?: string;
        originQuantity?: decimal | string;
        validatingOperator?: string;
        validatingUser?: string;
        postingDate?: string;
        postingTime?: integer | string;
        containerLevels?: Partial<AssemblingMovementContainerLevelsInput>[];
    }
    export interface AssemblingMovementBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        assemblyOrder: AssemblingOrder;
        assemblyOrderLineNumber: integer;
        assemblyWave: AssemblingWave;
        lineType: DoLineType;
        product: Product;
        numberOfContainer: string;
        container: ProductsContainer;
        homogeneousContainerCoefficient: string;
        consumptionUnitQuantity: string;
        numberOfKits: string;
        movementCode: MovementCode;
        lotNumber: string;
        stockStatus: StockNature;
        reservationNumber: string;
        supportNumber: string;
        status: AssemblyMovementStatus;
        originSource: Origin;
        receiptDate: string;
        fifoDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        shipByDate: string;
        useByDate: string;
        store: Store;
        location: Location;
        locationType: LocationType;
        stockObject: StockObject;
        replenishment: TransferMovement;
        transfer: TransferMovement;
        adjustment: AdjustmentMovement;
        kitDeclaration: KitDeclaration;
        isKitTransferAuthorized: boolean;
        flowNumber: integer;
        containerNumber: string;
        homogeneousContainer: ProductsContainer;
        homogeneousQuantity: string;
        originContainer: ProductsContainer;
        originQuantity: string;
        validatingOperator: Operand;
        validatingUser: string;
        postingDate: string;
        postingTime: integer;
        containerLevels: ClientCollection<AssemblingMovementContainerLevelsBinding>;
    }
    export interface AssemblingMovement$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        assemblyOrder: QueryOperation<AssemblingOrder>;
        assemblyWave: QueryOperation<AssemblingWave>;
        product: QueryOperation<Product>;
        container: QueryOperation<ProductsContainer>;
        movementCode: QueryOperation<MovementCode>;
        stockStatus: QueryOperation<StockNature>;
        originSource: QueryOperation<Origin>;
        store: QueryOperation<Store>;
        location: QueryOperation<Location>;
        stockObject: QueryOperation<StockObject>;
        replenishment: QueryOperation<TransferMovement>;
        transfer: QueryOperation<TransferMovement>;
        adjustment: QueryOperation<AdjustmentMovement>;
        kitDeclaration: QueryOperation<KitDeclaration>;
        homogeneousContainer: QueryOperation<ProductsContainer>;
        originContainer: QueryOperation<ProductsContainer>;
        validatingOperator: QueryOperation<Operand>;
    }
    export interface AssemblingMovement$Operations {
        query: QueryOperation<AssemblingMovement>;
        read: ReadOperation<AssemblingMovement>;
        aggregate: {
            read: AggregateReadOperation<AssemblingMovement>;
            query: AggregateQueryOperation<AssemblingMovement>;
        };
        lookups(dataOrId: string | { data: AssemblingMovementInput }): AssemblingMovement$Lookups;
        getDefaults: GetDefaultsOperation<AssemblingMovement>;
    }
    export interface AssemblingOrderLine extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        assemblyOrder: AssemblingOrder;
        lineNumber: integer;
        status: AssemblyOrderStatus;
        date: string;
        reference: string;
        stockStatus: StockNature;
        lotNumber: string;
        lineType: DoLineType;
        product: Product;
        numberOfContainer: string;
        container: ProductsContainer;
        totalQuantity: string;
        launchedQuantity: string;
        shortageQuantity: string;
        declaredQuantity: string;
        validatedQuantity: string;
        launchDate: string;
        launchTime: string;
        endProcessingDate: string;
        endProcessingTime: string;
        kitDeclaration: KitDeclaration;
        numberOfKitQuantity: string;
        movementCode: MovementCode;
        comments: string;
        notes: string;
        assemblyWave: AssemblingWave;
        flowNumber: integer;
    }
    export interface AssemblingOrderLineInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        assemblyOrder?: string;
        lineNumber?: integer | string;
        status?: AssemblyOrderStatus;
        date?: string;
        reference?: string;
        stockStatus?: string;
        lotNumber?: string;
        lineType?: DoLineType;
        product?: string;
        numberOfContainer?: decimal | string;
        container?: string;
        totalQuantity?: decimal | string;
        launchedQuantity?: decimal | string;
        shortageQuantity?: decimal | string;
        declaredQuantity?: decimal | string;
        validatedQuantity?: decimal | string;
        launchDate?: string;
        launchTime?: string;
        endProcessingDate?: string;
        endProcessingTime?: string;
        kitDeclaration?: string;
        numberOfKitQuantity?: decimal | string;
        movementCode?: string;
        comments?: string;
        notes?: string;
        assemblyWave?: string;
        flowNumber?: integer | string;
    }
    export interface AssemblingOrderLineBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        assemblyOrder: AssemblingOrder;
        lineNumber: integer;
        status: AssemblyOrderStatus;
        date: string;
        reference: string;
        stockStatus: StockNature;
        lotNumber: string;
        lineType: DoLineType;
        product: Product;
        numberOfContainer: string;
        container: ProductsContainer;
        totalQuantity: string;
        launchedQuantity: string;
        shortageQuantity: string;
        declaredQuantity: string;
        validatedQuantity: string;
        launchDate: string;
        launchTime: string;
        endProcessingDate: string;
        endProcessingTime: string;
        kitDeclaration: KitDeclaration;
        numberOfKitQuantity: string;
        movementCode: MovementCode;
        comments: string;
        notes: string;
        assemblyWave: AssemblingWave;
        flowNumber: integer;
    }
    export interface AssemblingOrderLine$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        assemblyOrder: QueryOperation<AssemblingOrder>;
        stockStatus: QueryOperation<StockNature>;
        product: QueryOperation<Product>;
        container: QueryOperation<ProductsContainer>;
        kitDeclaration: QueryOperation<KitDeclaration>;
        movementCode: QueryOperation<MovementCode>;
        assemblyWave: QueryOperation<AssemblingWave>;
    }
    export interface AssemblingOrderLine$Operations {
        query: QueryOperation<AssemblingOrderLine>;
        read: ReadOperation<AssemblingOrderLine>;
        aggregate: {
            read: AggregateReadOperation<AssemblingOrderLine>;
            query: AggregateQueryOperation<AssemblingOrderLine>;
        };
        lookups(dataOrId: string | { data: AssemblingOrderLineInput }): AssemblingOrderLine$Lookups;
        getDefaults: GetDefaultsOperation<AssemblingOrderLine>;
    }
    export interface AssemblingOrder extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        reference: string;
        type: Type;
        isUrgent: boolean;
        servicePriority: ServicePriority;
        status: AssemblyOrderStatus;
        date: string;
        workOrderNumber: string;
        workOrderDate: string;
        plannedLaunchDate: string;
        plannedLaunchTime: string;
        plannedEndDate: string;
        plannedEndTime: string;
        transmittedByL3: TransmissionL3;
        endProcessingDate: string;
        endProcessingTime: string;
        movementCode: MovementCode;
        assemblyWave: AssemblingWave;
        launchDate: string;
        launchTime: string;
        lines: ClientCollection<AssemblingOrderLine>;
    }
    export interface AssemblingOrderInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        reference?: string;
        type?: Type;
        isUrgent?: boolean | string;
        servicePriority?: ServicePriority;
        status?: AssemblyOrderStatus;
        date?: string;
        workOrderNumber?: string;
        workOrderDate?: string;
        plannedLaunchDate?: string;
        plannedLaunchTime?: string;
        plannedEndDate?: string;
        plannedEndTime?: string;
        transmittedByL3?: TransmissionL3;
        endProcessingDate?: string;
        endProcessingTime?: string;
        movementCode?: string;
        assemblyWave?: string;
        launchDate?: string;
        launchTime?: string;
        lines?: Partial<AssemblingOrderLineInput>[];
    }
    export interface AssemblingOrderBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        reference: string;
        type: Type;
        isUrgent: boolean;
        servicePriority: ServicePriority;
        status: AssemblyOrderStatus;
        date: string;
        workOrderNumber: string;
        workOrderDate: string;
        plannedLaunchDate: string;
        plannedLaunchTime: string;
        plannedEndDate: string;
        plannedEndTime: string;
        transmittedByL3: TransmissionL3;
        endProcessingDate: string;
        endProcessingTime: string;
        movementCode: MovementCode;
        assemblyWave: AssemblingWave;
        launchDate: string;
        launchTime: string;
        lines: ClientCollection<AssemblingOrderLine>;
    }
    export interface AssemblingOrder$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        movementCode: QueryOperation<MovementCode>;
        assemblyWave: QueryOperation<AssemblingWave>;
    }
    export interface AssemblingOrder$Operations {
        query: QueryOperation<AssemblingOrder>;
        read: ReadOperation<AssemblingOrder>;
        aggregate: {
            read: AggregateReadOperation<AssemblingOrder>;
            query: AggregateQueryOperation<AssemblingOrder>;
        };
        lookups(dataOrId: string | { data: AssemblingOrderInput }): AssemblingOrder$Lookups;
        getDefaults: GetDefaultsOperation<AssemblingOrder>;
    }
    export interface AssemblingWave extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        type: Type;
        launchDate: string;
        launchTime: string;
        numberOfAssemblyOrders: integer;
        numberOfAssemblyOrderLines: integer;
        numberOfReserveMovements: integer;
        numberOfPickingMovements: integer;
        numberOfIncompleteLines: integer;
        numberOfReplenishmentMovements: integer;
        numberOfTransferOrders: integer;
        status: WaveStatus;
        volume: string;
        weight: string;
        numberOfTransferMovements: integer;
        store: Store;
        location: Location;
        isAvailableStock: boolean;
        isPickingStock: boolean;
        isTransferIncomplete: boolean;
        isMissionToBlock: boolean;
        missionPriority: integer;
    }
    export interface AssemblingWaveInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        type?: Type;
        launchDate?: string;
        launchTime?: string;
        numberOfAssemblyOrders?: integer | string;
        numberOfAssemblyOrderLines?: integer | string;
        numberOfReserveMovements?: integer | string;
        numberOfPickingMovements?: integer | string;
        numberOfIncompleteLines?: integer | string;
        numberOfReplenishmentMovements?: integer | string;
        numberOfTransferOrders?: integer | string;
        status?: WaveStatus;
        volume?: decimal | string;
        weight?: decimal | string;
        numberOfTransferMovements?: integer | string;
        store?: string;
        location?: string;
        isAvailableStock?: boolean | string;
        isPickingStock?: boolean | string;
        isTransferIncomplete?: boolean | string;
        isMissionToBlock?: boolean | string;
        missionPriority?: integer | string;
    }
    export interface AssemblingWaveBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        type: Type;
        launchDate: string;
        launchTime: string;
        numberOfAssemblyOrders: integer;
        numberOfAssemblyOrderLines: integer;
        numberOfReserveMovements: integer;
        numberOfPickingMovements: integer;
        numberOfIncompleteLines: integer;
        numberOfReplenishmentMovements: integer;
        numberOfTransferOrders: integer;
        status: WaveStatus;
        volume: string;
        weight: string;
        numberOfTransferMovements: integer;
        store: Store;
        location: Location;
        isAvailableStock: boolean;
        isPickingStock: boolean;
        isTransferIncomplete: boolean;
        isMissionToBlock: boolean;
        missionPriority: integer;
    }
    export interface AssemblingWave$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        store: QueryOperation<Store>;
        location: QueryOperation<Location>;
    }
    export interface AssemblingWave$Operations {
        query: QueryOperation<AssemblingWave>;
        read: ReadOperation<AssemblingWave>;
        aggregate: {
            read: AggregateReadOperation<AssemblingWave>;
            query: AggregateQueryOperation<AssemblingWave>;
        };
        lookups(dataOrId: string | { data: AssemblingWaveInput }): AssemblingWave$Lookups;
        getDefaults: GetDefaultsOperation<AssemblingWave>;
    }
    export interface AutoPalletizationOrder extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        status: AutoPalletizationStatus;
        deliveryOrder: DeliveryOrder;
        numberOfShippingUnits: integer;
        numberOfParcels: integer;
        date: string;
        time: string;
        wave: Wave;
        preparationArea: PreparationArea;
        validatingOperator: Operand;
        postingDate: string;
        postingTime: integer;
        validatingUser: string;
    }
    export interface AutoPalletizationOrderInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        status?: AutoPalletizationStatus;
        deliveryOrder?: string;
        numberOfShippingUnits?: integer | string;
        numberOfParcels?: integer | string;
        date?: string;
        time?: string;
        wave?: string;
        preparationArea?: string;
        validatingOperator?: string;
        postingDate?: string;
        postingTime?: integer | string;
        validatingUser?: string;
    }
    export interface AutoPalletizationOrderBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        status: AutoPalletizationStatus;
        deliveryOrder: DeliveryOrder;
        numberOfShippingUnits: integer;
        numberOfParcels: integer;
        date: string;
        time: string;
        wave: Wave;
        preparationArea: PreparationArea;
        validatingOperator: Operand;
        postingDate: string;
        postingTime: integer;
        validatingUser: string;
    }
    export interface AutoPalletizationOrder$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        deliveryOrder: QueryOperation<DeliveryOrder>;
        wave: QueryOperation<Wave>;
        preparationArea: QueryOperation<PreparationArea>;
        validatingOperator: QueryOperation<Operand>;
    }
    export interface AutoPalletizationOrder$Operations {
        query: QueryOperation<AutoPalletizationOrder>;
        read: ReadOperation<AutoPalletizationOrder>;
        aggregate: {
            read: AggregateReadOperation<AutoPalletizationOrder>;
            query: AggregateQueryOperation<AutoPalletizationOrder>;
        };
        lookups(dataOrId: string | { data: AutoPalletizationOrderInput }): AutoPalletizationOrder$Lookups;
        getDefaults: GetDefaultsOperation<AutoPalletizationOrder>;
    }
    export interface CarriageNote extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        round: Round;
        shipmentDate: string;
        shipmentTime: string;
        linearMeters: string;
        truckPlacard: string;
        sealNumber: string;
        numberOfCarriageReceipts: integer;
        numberOfDeliveryNotes: integer;
        weight: string;
        volume: string;
        numberOfParcels: integer;
        numberOfShippingUnits: integer;
        freightCharge: string;
        currency: Currency;
        dockType: DockManagement;
    }
    export interface CarriageNoteInput extends ClientNodeInput {
        site?: string;
        code?: string;
        round?: string;
        shipmentDate?: string;
        shipmentTime?: string;
        linearMeters?: decimal | string;
        truckPlacard?: string;
        sealNumber?: string;
        numberOfCarriageReceipts?: integer | string;
        numberOfDeliveryNotes?: integer | string;
        weight?: decimal | string;
        volume?: decimal | string;
        numberOfParcels?: integer | string;
        numberOfShippingUnits?: integer | string;
        freightCharge?: decimal | string;
        currency?: string;
        dockType?: DockManagement;
    }
    export interface CarriageNoteBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        round: Round;
        shipmentDate: string;
        shipmentTime: string;
        linearMeters: string;
        truckPlacard: string;
        sealNumber: string;
        numberOfCarriageReceipts: integer;
        numberOfDeliveryNotes: integer;
        weight: string;
        volume: string;
        numberOfParcels: integer;
        numberOfShippingUnits: integer;
        freightCharge: string;
        currency: Currency;
        dockType: DockManagement;
    }
    export interface CarriageNote$Lookups {
        site: QueryOperation<Site>;
        round: QueryOperation<Round>;
        currency: QueryOperation<Currency>;
    }
    export interface CarriageNote$Operations {
        query: QueryOperation<CarriageNote>;
        read: ReadOperation<CarriageNote>;
        aggregate: {
            read: AggregateReadOperation<CarriageNote>;
            query: AggregateQueryOperation<CarriageNote>;
        };
        lookups(dataOrId: string | { data: CarriageNoteInput }): CarriageNote$Lookups;
        getDefaults: GetDefaultsOperation<CarriageNote>;
    }
    export interface CarriageReceiptShipToCompanyNames extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        code: string;
        shipToCompanyName: string;
    }
    export interface CarriageReceiptShipToCompanyNamesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        code?: string;
        shipToCompanyName?: string;
    }
    export interface CarriageReceiptShipToCompanyNamesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        code: string;
        shipToCompanyName: string;
    }
    export interface CarriageReceiptShipToCompanyNames$Operations {
        query: QueryOperation<CarriageReceiptShipToCompanyNames>;
        read: ReadOperation<CarriageReceiptShipToCompanyNames>;
        aggregate: {
            read: AggregateReadOperation<CarriageReceiptShipToCompanyNames>;
            query: AggregateQueryOperation<CarriageReceiptShipToCompanyNames>;
        };
        getDefaults: GetDefaultsOperation<CarriageReceiptShipToCompanyNames>;
    }
    export interface CarriageReceiptShiptToAddresses extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        code: string;
        shiptToAddress: string;
    }
    export interface CarriageReceiptShiptToAddressesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        code?: string;
        shiptToAddress?: string;
    }
    export interface CarriageReceiptShiptToAddressesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        code: string;
        shiptToAddress: string;
    }
    export interface CarriageReceiptShiptToAddresses$Operations {
        query: QueryOperation<CarriageReceiptShiptToAddresses>;
        read: ReadOperation<CarriageReceiptShiptToAddresses>;
        aggregate: {
            read: AggregateReadOperation<CarriageReceiptShiptToAddresses>;
            query: AggregateQueryOperation<CarriageReceiptShiptToAddresses>;
        };
        getDefaults: GetDefaultsOperation<CarriageReceiptShiptToAddresses>;
    }
    export interface CarriageReceipt extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        deliveryNote: CarriageNote;
        round: Round;
        shipmentDate: string;
        shipmentTime: string;
        linearMeters: string;
        truckPlacard: string;
        sealNumber: string;
        weight: string;
        volume: string;
        numberOfParcels: integer;
        numberOfShippingUnits: integer;
        numberOfDeliveryNotes: integer;
        shipToCustomer: Customer;
        shipToPostalCode: string;
        shipToCity: string;
        shipToCountry: Country;
        shipToCountryName: string;
        shipToRegion: string;
        deliveryArea: string;
        freightCharge: string;
        currency: Currency;
        dockType: DockManagement;
        shipToCompanyNames: ClientCollection<CarriageReceiptShipToCompanyNames>;
        shiptToAddresses: ClientCollection<CarriageReceiptShiptToAddresses>;
    }
    export interface CarriageReceiptInput extends ClientNodeInput {
        site?: string;
        code?: string;
        deliveryNote?: string;
        round?: string;
        shipmentDate?: string;
        shipmentTime?: string;
        linearMeters?: decimal | string;
        truckPlacard?: string;
        sealNumber?: string;
        weight?: decimal | string;
        volume?: decimal | string;
        numberOfParcels?: integer | string;
        numberOfShippingUnits?: integer | string;
        numberOfDeliveryNotes?: integer | string;
        shipToCustomer?: string;
        shipToPostalCode?: string;
        shipToCity?: string;
        shipToCountry?: string;
        shipToCountryName?: string;
        shipToRegion?: string;
        deliveryArea?: string;
        freightCharge?: decimal | string;
        currency?: string;
        dockType?: DockManagement;
        shipToCompanyNames?: Partial<CarriageReceiptShipToCompanyNamesInput>[];
        shiptToAddresses?: Partial<CarriageReceiptShiptToAddressesInput>[];
    }
    export interface CarriageReceiptBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        deliveryNote: CarriageNote;
        round: Round;
        shipmentDate: string;
        shipmentTime: string;
        linearMeters: string;
        truckPlacard: string;
        sealNumber: string;
        weight: string;
        volume: string;
        numberOfParcels: integer;
        numberOfShippingUnits: integer;
        numberOfDeliveryNotes: integer;
        shipToCustomer: Customer;
        shipToPostalCode: string;
        shipToCity: string;
        shipToCountry: Country;
        shipToCountryName: string;
        shipToRegion: string;
        deliveryArea: string;
        freightCharge: string;
        currency: Currency;
        dockType: DockManagement;
        shipToCompanyNames: ClientCollection<CarriageReceiptShipToCompanyNamesBinding>;
        shiptToAddresses: ClientCollection<CarriageReceiptShiptToAddressesBinding>;
    }
    export interface CarriageReceipt$Lookups {
        site: QueryOperation<Site>;
        deliveryNote: QueryOperation<CarriageNote>;
        round: QueryOperation<Round>;
        shipToCustomer: QueryOperation<Customer>;
        shipToCountry: QueryOperation<Country>;
        currency: QueryOperation<Currency>;
    }
    export interface CarriageReceipt$Operations {
        query: QueryOperation<CarriageReceipt>;
        read: ReadOperation<CarriageReceipt>;
        aggregate: {
            read: AggregateReadOperation<CarriageReceipt>;
            query: AggregateQueryOperation<CarriageReceipt>;
        };
        lookups(dataOrId: string | { data: CarriageReceiptInput }): CarriageReceipt$Lookups;
        getDefaults: GetDefaultsOperation<CarriageReceipt>;
    }
    export interface CountLine extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        stockCount: StockCount;
        counting: Counting;
        line: integer;
        isKeyInSerialNumber: boolean;
        isInput: boolean;
        sort: string;
        depositor: Depositor;
        product: Product;
        store: Store;
        location: Location;
        numberOfContainer: string;
        container: ProductsContainer;
        consumptionUnitQuantity: string;
        stockStatus: StockNature;
        reservationNumber: string;
        lotNumber: string;
        supportNumber: string;
        originSource: Origin;
        fifoDate: string;
        receiptDate: string;
        manufacturedDate: string;
        sellByDate: string;
        useByDate: string;
        shipByDate: string;
        rowLevel: string;
        travelSequence: string;
        inventoryDiscrepancy: InventoryDiscrepancy;
    }
    export interface CountLineInput extends ClientNodeInput {
        site?: string;
        stockCount?: string;
        counting?: integer | string;
        line?: integer | string;
        isKeyInSerialNumber?: boolean | string;
        isInput?: boolean | string;
        sort?: string;
        depositor?: string;
        product?: string;
        store?: string;
        location?: string;
        numberOfContainer?: decimal | string;
        container?: string;
        consumptionUnitQuantity?: decimal | string;
        stockStatus?: string;
        reservationNumber?: string;
        lotNumber?: string;
        supportNumber?: string;
        originSource?: string;
        fifoDate?: string;
        receiptDate?: string;
        manufacturedDate?: string;
        sellByDate?: string;
        useByDate?: string;
        shipByDate?: string;
        rowLevel?: string;
        travelSequence?: string;
        inventoryDiscrepancy?: InventoryDiscrepancy;
    }
    export interface CountLineBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        stockCount: StockCount;
        counting: Counting;
        line: integer;
        isKeyInSerialNumber: boolean;
        isInput: boolean;
        sort: string;
        depositor: Depositor;
        product: Product;
        store: Store;
        location: Location;
        numberOfContainer: string;
        container: ProductsContainer;
        consumptionUnitQuantity: string;
        stockStatus: StockNature;
        reservationNumber: string;
        lotNumber: string;
        supportNumber: string;
        originSource: Origin;
        fifoDate: string;
        receiptDate: string;
        manufacturedDate: string;
        sellByDate: string;
        useByDate: string;
        shipByDate: string;
        rowLevel: string;
        travelSequence: string;
        inventoryDiscrepancy: InventoryDiscrepancy;
    }
    export interface CountLine$Lookups {
        site: QueryOperation<Site>;
        stockCount: QueryOperation<StockCount>;
        counting: QueryOperation<Counting>;
        depositor: QueryOperation<Depositor>;
        product: QueryOperation<Product>;
        store: QueryOperation<Store>;
        location: QueryOperation<Location>;
        container: QueryOperation<ProductsContainer>;
        stockStatus: QueryOperation<StockNature>;
        originSource: QueryOperation<Origin>;
    }
    export interface CountLine$Operations {
        query: QueryOperation<CountLine>;
        read: ReadOperation<CountLine>;
        aggregate: {
            read: AggregateReadOperation<CountLine>;
            query: AggregateQueryOperation<CountLine>;
        };
        lookups(dataOrId: string | { data: CountLineInput }): CountLine$Lookups;
        getDefaults: GetDefaultsOperation<CountLine>;
    }
    export interface Counting extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        stockCount: StockCount;
        code: integer;
        reference: string;
        status: InventoryStatus;
        countingType: CountingType;
        isProductWithoutStock: boolean;
        store: Store;
        aisle: string;
        row: string;
        isPicking: boolean;
        isReserve: boolean;
        referenceCount1: Counting;
        referenceCount2: Counting;
        lineInError: InventoryDiscrepancy;
        comments: string;
        date: string;
        closingDate: string;
        numberOfLines: integer;
    }
    export interface CountingInput extends ClientNodeInput {
        site?: string;
        stockCount?: string;
        code?: integer | string;
        reference?: string;
        status?: InventoryStatus;
        countingType?: CountingType;
        isProductWithoutStock?: boolean | string;
        store?: string;
        aisle?: string;
        row?: string;
        isPicking?: boolean | string;
        isReserve?: boolean | string;
        referenceCount1?: integer | string;
        referenceCount2?: integer | string;
        lineInError?: InventoryDiscrepancy;
        comments?: string;
        date?: string;
        closingDate?: string;
        numberOfLines?: integer | string;
    }
    export interface CountingBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        stockCount: StockCount;
        code: integer;
        reference: string;
        status: InventoryStatus;
        countingType: CountingType;
        isProductWithoutStock: boolean;
        store: Store;
        aisle: string;
        row: string;
        isPicking: boolean;
        isReserve: boolean;
        referenceCount1: Counting;
        referenceCount2: Counting;
        lineInError: InventoryDiscrepancy;
        comments: string;
        date: string;
        closingDate: string;
        numberOfLines: integer;
    }
    export interface Counting$Lookups {
        site: QueryOperation<Site>;
        stockCount: QueryOperation<StockCount>;
        store: QueryOperation<Store>;
        referenceCount1: QueryOperation<Counting>;
        referenceCount2: QueryOperation<Counting>;
    }
    export interface Counting$Operations {
        query: QueryOperation<Counting>;
        read: ReadOperation<Counting>;
        aggregate: {
            read: AggregateReadOperation<Counting>;
            query: AggregateQueryOperation<Counting>;
        };
        lookups(dataOrId: string | { data: CountingInput }): Counting$Lookups;
        getDefaults: GetDefaultsOperation<Counting>;
    }
    export interface DeliveryNoteBillToAddresses extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        billToAddress: string;
    }
    export interface DeliveryNoteBillToAddressesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        billToAddress?: string;
    }
    export interface DeliveryNoteBillToAddressesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        billToAddress: string;
    }
    export interface DeliveryNoteBillToAddresses$Operations {
        query: QueryOperation<DeliveryNoteBillToAddresses>;
        read: ReadOperation<DeliveryNoteBillToAddresses>;
        aggregate: {
            read: AggregateReadOperation<DeliveryNoteBillToAddresses>;
            query: AggregateQueryOperation<DeliveryNoteBillToAddresses>;
        };
        getDefaults: GetDefaultsOperation<DeliveryNoteBillToAddresses>;
    }
    export interface DeliveryNoteBillToCompanyNames extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        billToCompanyName: string;
    }
    export interface DeliveryNoteBillToCompanyNamesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        billToCompanyName?: string;
    }
    export interface DeliveryNoteBillToCompanyNamesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        billToCompanyName: string;
    }
    export interface DeliveryNoteBillToCompanyNames$Operations {
        query: QueryOperation<DeliveryNoteBillToCompanyNames>;
        read: ReadOperation<DeliveryNoteBillToCompanyNames>;
        aggregate: {
            read: AggregateReadOperation<DeliveryNoteBillToCompanyNames>;
            query: AggregateQueryOperation<DeliveryNoteBillToCompanyNames>;
        };
        getDefaults: GetDefaultsOperation<DeliveryNoteBillToCompanyNames>;
    }
    export interface DeliveryNoteNumberOfDispatchableParcels extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        numberOfDispatchableParcel: integer;
    }
    export interface DeliveryNoteNumberOfDispatchableParcelsInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        numberOfDispatchableParcel?: integer | string;
    }
    export interface DeliveryNoteNumberOfDispatchableParcelsBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        numberOfDispatchableParcel: integer;
    }
    export interface DeliveryNoteNumberOfDispatchableParcels$Operations {
        query: QueryOperation<DeliveryNoteNumberOfDispatchableParcels>;
        read: ReadOperation<DeliveryNoteNumberOfDispatchableParcels>;
        aggregate: {
            read: AggregateReadOperation<DeliveryNoteNumberOfDispatchableParcels>;
            query: AggregateQueryOperation<DeliveryNoteNumberOfDispatchableParcels>;
        };
        getDefaults: GetDefaultsOperation<DeliveryNoteNumberOfDispatchableParcels>;
    }
    export interface DeliveryNoteShipToAddresses extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        shipToAddress: string;
    }
    export interface DeliveryNoteShipToAddressesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        shipToAddress?: string;
    }
    export interface DeliveryNoteShipToAddressesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        shipToAddress: string;
    }
    export interface DeliveryNoteShipToAddresses$Operations {
        query: QueryOperation<DeliveryNoteShipToAddresses>;
        read: ReadOperation<DeliveryNoteShipToAddresses>;
        aggregate: {
            read: AggregateReadOperation<DeliveryNoteShipToAddresses>;
            query: AggregateQueryOperation<DeliveryNoteShipToAddresses>;
        };
        getDefaults: GetDefaultsOperation<DeliveryNoteShipToAddresses>;
    }
    export interface DeliveryNoteShipToCompanyNames extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        shipToCompanyName: string;
    }
    export interface DeliveryNoteShipToCompanyNamesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        shipToCompanyName?: string;
    }
    export interface DeliveryNoteShipToCompanyNamesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        shipToCompanyName: string;
    }
    export interface DeliveryNoteShipToCompanyNames$Operations {
        query: QueryOperation<DeliveryNoteShipToCompanyNames>;
        read: ReadOperation<DeliveryNoteShipToCompanyNames>;
        aggregate: {
            read: AggregateReadOperation<DeliveryNoteShipToCompanyNames>;
            query: AggregateQueryOperation<DeliveryNoteShipToCompanyNames>;
        };
        getDefaults: GetDefaultsOperation<DeliveryNoteShipToCompanyNames>;
    }
    export interface DeliveryNote extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        creationDate: string;
        creationTime: string;
        isFinalDeliveryNote: boolean;
        isUpdateDeliveryNote: boolean;
        deliveryOrder: DeliveryOrder;
        reference: string;
        orderReference: string;
        orderNumber: string;
        orderDate: string;
        soldToCustomer: string;
        customerReference: string;
        pickingMode: PickingMode;
        movementCode: MovementCode;
        partialDeliveryManagement: PartialDeliveryAuthorized;
        expectedDeliveryDate: string;
        expectedDeliveryTime: string;
        shipmentDate: string;
        shipmentTime: string;
        shipmentSite: Site;
        round: Round;
        carriageReceipt: CarriageReceipt;
        carrier: Carrier;
        transportationMethod: TransportMode;
        carriageReference: string;
        freightCharge: string;
        currency: Currency;
        roundPosition: integer;
        genericRound: GenericRound;
        transportType: TransportType;
        deliveryArea: string;
        wave: Wave;
        preparationArea: PreparationArea;
        shipToCustomer: Customer;
        shipToPostalCode: string;
        shipToCity: string;
        shipToCountry: Country;
        shipToCountryName: string;
        shipToRegion: string;
        shipToTelephone: string;
        shipToFax: string;
        shipToNotes: string;
        billToCustomer: Customer;
        billToPostalCode: string;
        billToCity: string;
        billToCountry: Country;
        billToCountryName: string;
        billToRegion: string;
        billToTelephone: string;
        billToFax: string;
        billToNotes: string;
        numberOfParcels: integer;
        numberOfShippingUnit: integer;
        weight: string;
        volume: string;
        linearMeters: string;
        numberOfDeliveryOrderLines: integer;
        deliveryNotePrintingReport: GenericPrintReport;
        printLanguage: Language;
        ediManagementStatus: EdiMngtStatus;
        numberOfParcelsWithoutMessage: integer;
        ediManagementLevel: EdiLevel;
        queryNumber: integer;
        billToAddresses: ClientCollection<DeliveryNoteBillToAddresses>;
        billToCompanyNames: ClientCollection<DeliveryNoteBillToCompanyNames>;
        numberOfDispatchableParcels: ClientCollection<DeliveryNoteNumberOfDispatchableParcels>;
        shipToAddresses: ClientCollection<DeliveryNoteShipToAddresses>;
        shipToCompanyNames: ClientCollection<DeliveryNoteShipToCompanyNames>;
    }
    export interface DeliveryNoteInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        creationDate?: string;
        creationTime?: string;
        isFinalDeliveryNote?: boolean | string;
        isUpdateDeliveryNote?: boolean | string;
        deliveryOrder?: string;
        reference?: string;
        orderReference?: string;
        orderNumber?: string;
        orderDate?: string;
        soldToCustomer?: string;
        customerReference?: string;
        pickingMode?: string;
        movementCode?: string;
        partialDeliveryManagement?: PartialDeliveryAuthorized;
        expectedDeliveryDate?: string;
        expectedDeliveryTime?: string;
        shipmentDate?: string;
        shipmentTime?: string;
        shipmentSite?: string;
        round?: string;
        carriageReceipt?: string;
        carrier?: string;
        transportationMethod?: string;
        carriageReference?: string;
        freightCharge?: decimal | string;
        currency?: string;
        roundPosition?: integer | string;
        genericRound?: string;
        transportType?: string;
        deliveryArea?: string;
        wave?: string;
        preparationArea?: string;
        shipToCustomer?: string;
        shipToPostalCode?: string;
        shipToCity?: string;
        shipToCountry?: string;
        shipToCountryName?: string;
        shipToRegion?: string;
        shipToTelephone?: string;
        shipToFax?: string;
        shipToNotes?: string;
        billToCustomer?: string;
        billToPostalCode?: string;
        billToCity?: string;
        billToCountry?: string;
        billToCountryName?: string;
        billToRegion?: string;
        billToTelephone?: string;
        billToFax?: string;
        billToNotes?: string;
        numberOfParcels?: integer | string;
        numberOfShippingUnit?: integer | string;
        weight?: decimal | string;
        volume?: decimal | string;
        linearMeters?: decimal | string;
        numberOfDeliveryOrderLines?: integer | string;
        deliveryNotePrintingReport?: string;
        printLanguage?: string;
        ediManagementStatus?: EdiMngtStatus;
        numberOfParcelsWithoutMessage?: integer | string;
        ediManagementLevel?: EdiLevel;
        queryNumber?: integer | string;
        billToAddresses?: Partial<DeliveryNoteBillToAddressesInput>[];
        billToCompanyNames?: Partial<DeliveryNoteBillToCompanyNamesInput>[];
        numberOfDispatchableParcels?: Partial<DeliveryNoteNumberOfDispatchableParcelsInput>[];
        shipToAddresses?: Partial<DeliveryNoteShipToAddressesInput>[];
        shipToCompanyNames?: Partial<DeliveryNoteShipToCompanyNamesInput>[];
    }
    export interface DeliveryNoteBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        creationDate: string;
        creationTime: string;
        isFinalDeliveryNote: boolean;
        isUpdateDeliveryNote: boolean;
        deliveryOrder: DeliveryOrder;
        reference: string;
        orderReference: string;
        orderNumber: string;
        orderDate: string;
        soldToCustomer: string;
        customerReference: string;
        pickingMode: PickingMode;
        movementCode: MovementCode;
        partialDeliveryManagement: PartialDeliveryAuthorized;
        expectedDeliveryDate: string;
        expectedDeliveryTime: string;
        shipmentDate: string;
        shipmentTime: string;
        shipmentSite: Site;
        round: Round;
        carriageReceipt: CarriageReceipt;
        carrier: Carrier;
        transportationMethod: TransportMode;
        carriageReference: string;
        freightCharge: string;
        currency: Currency;
        roundPosition: integer;
        genericRound: GenericRound;
        transportType: TransportType;
        deliveryArea: string;
        wave: Wave;
        preparationArea: PreparationArea;
        shipToCustomer: Customer;
        shipToPostalCode: string;
        shipToCity: string;
        shipToCountry: Country;
        shipToCountryName: string;
        shipToRegion: string;
        shipToTelephone: string;
        shipToFax: string;
        shipToNotes: string;
        billToCustomer: Customer;
        billToPostalCode: string;
        billToCity: string;
        billToCountry: Country;
        billToCountryName: string;
        billToRegion: string;
        billToTelephone: string;
        billToFax: string;
        billToNotes: string;
        numberOfParcels: integer;
        numberOfShippingUnit: integer;
        weight: string;
        volume: string;
        linearMeters: string;
        numberOfDeliveryOrderLines: integer;
        deliveryNotePrintingReport: GenericPrintReport;
        printLanguage: Language;
        ediManagementStatus: EdiMngtStatus;
        numberOfParcelsWithoutMessage: integer;
        ediManagementLevel: EdiLevel;
        queryNumber: integer;
        billToAddresses: ClientCollection<DeliveryNoteBillToAddressesBinding>;
        billToCompanyNames: ClientCollection<DeliveryNoteBillToCompanyNamesBinding>;
        numberOfDispatchableParcels: ClientCollection<DeliveryNoteNumberOfDispatchableParcelsBinding>;
        shipToAddresses: ClientCollection<DeliveryNoteShipToAddressesBinding>;
        shipToCompanyNames: ClientCollection<DeliveryNoteShipToCompanyNamesBinding>;
    }
    export interface DeliveryNote$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        deliveryOrder: QueryOperation<DeliveryOrder>;
        pickingMode: QueryOperation<PickingMode>;
        movementCode: QueryOperation<MovementCode>;
        shipmentSite: QueryOperation<Site>;
        round: QueryOperation<Round>;
        carriageReceipt: QueryOperation<CarriageReceipt>;
        carrier: QueryOperation<Carrier>;
        transportationMethod: QueryOperation<TransportMode>;
        currency: QueryOperation<Currency>;
        genericRound: QueryOperation<GenericRound>;
        transportType: QueryOperation<TransportType>;
        wave: QueryOperation<Wave>;
        preparationArea: QueryOperation<PreparationArea>;
        shipToCustomer: QueryOperation<Customer>;
        shipToCountry: QueryOperation<Country>;
        billToCustomer: QueryOperation<Customer>;
        billToCountry: QueryOperation<Country>;
        deliveryNotePrintingReport: QueryOperation<GenericPrintReport>;
        printLanguage: QueryOperation<Language>;
    }
    export interface DeliveryNote$Operations {
        query: QueryOperation<DeliveryNote>;
        read: ReadOperation<DeliveryNote>;
        aggregate: {
            read: AggregateReadOperation<DeliveryNote>;
            query: AggregateQueryOperation<DeliveryNote>;
        };
        lookups(dataOrId: string | { data: DeliveryNoteInput }): DeliveryNote$Lookups;
        getDefaults: GetDefaultsOperation<DeliveryNote>;
    }
    export interface DeliveryOrderBillToAddresses extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        billToAddress: string;
    }
    export interface DeliveryOrderBillToAddressesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        billToAddress?: string;
    }
    export interface DeliveryOrderBillToAddressesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        billToAddress: string;
    }
    export interface DeliveryOrderBillToAddresses$Operations {
        query: QueryOperation<DeliveryOrderBillToAddresses>;
        read: ReadOperation<DeliveryOrderBillToAddresses>;
        aggregate: {
            read: AggregateReadOperation<DeliveryOrderBillToAddresses>;
            query: AggregateQueryOperation<DeliveryOrderBillToAddresses>;
        };
        getDefaults: GetDefaultsOperation<DeliveryOrderBillToAddresses>;
    }
    export interface DeliveryOrderBillToCompanyNames extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        billToCompanyName: string;
    }
    export interface DeliveryOrderBillToCompanyNamesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        billToCompanyName?: string;
    }
    export interface DeliveryOrderBillToCompanyNamesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        billToCompanyName: string;
    }
    export interface DeliveryOrderBillToCompanyNames$Operations {
        query: QueryOperation<DeliveryOrderBillToCompanyNames>;
        read: ReadOperation<DeliveryOrderBillToCompanyNames>;
        aggregate: {
            read: AggregateReadOperation<DeliveryOrderBillToCompanyNames>;
            query: AggregateQueryOperation<DeliveryOrderBillToCompanyNames>;
        };
        getDefaults: GetDefaultsOperation<DeliveryOrderBillToCompanyNames>;
    }
    export interface DeliveryOrderLine extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        deliveryOrder: DeliveryOrder;
        lineNumber: integer;
        status: DeliveryOrderLineStatus;
        pointer: integer;
        kitPointer: integer;
        referenceNumber: string;
        orderNumber: string;
        lineType: DoLineType;
        numberOfKit: string;
        product: Product;
        quantityOfContainers: string;
        container: ProductsContainer;
        numberOfConsumptionUnit: string;
        quantityTotalShipped: string;
        stockStatus: StockNature;
        reservationNumber: string;
        lotNumber: string;
        isSingleLot: boolean;
        supportNumber: string;
        movementCode: MovementCode;
        fifoDate: string;
        creationDate: string;
        launchedQuantity: string;
        shortageQuantity: string;
        preparedQuantity: string;
        shippedQuantity: string;
        voidedQuantity: string;
        transferredQuantity: string;
        notTransferredQuantity: string;
        postponedQuantity: string;
        crossDockingQuantity: string;
        isCrossDockingManagement: boolean;
        isDirectMovementNotAddressed: boolean;
        isExpectedInputUnderReceipt: boolean;
        comments: string;
        notes: string;
        launchDate: string;
        launchTime: string;
        waitingToShipDate: string;
        waitingToShipTime: string;
        shipmentDate: string;
        shipmentTime: string;
        parcelRange: RangeOfParcel;
        groupOfParcel: string;
        maximumLevelDispatchInState: ContainerLevel;
        isContractDate: boolean;
        outputMovements: ClientCollection<OutputMovement>;
    }
    export interface DeliveryOrderLineInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        deliveryOrder?: string;
        lineNumber?: integer | string;
        status?: DeliveryOrderLineStatus;
        pointer?: integer | string;
        kitPointer?: integer | string;
        referenceNumber?: string;
        orderNumber?: string;
        lineType?: DoLineType;
        numberOfKit?: decimal | string;
        product?: string;
        quantityOfContainers?: decimal | string;
        container?: string;
        numberOfConsumptionUnit?: decimal | string;
        quantityTotalShipped?: decimal | string;
        stockStatus?: string;
        reservationNumber?: string;
        lotNumber?: string;
        isSingleLot?: boolean | string;
        supportNumber?: string;
        movementCode?: string;
        fifoDate?: string;
        creationDate?: string;
        launchedQuantity?: decimal | string;
        shortageQuantity?: decimal | string;
        preparedQuantity?: decimal | string;
        shippedQuantity?: decimal | string;
        voidedQuantity?: decimal | string;
        transferredQuantity?: decimal | string;
        notTransferredQuantity?: decimal | string;
        postponedQuantity?: decimal | string;
        crossDockingQuantity?: decimal | string;
        isCrossDockingManagement?: boolean | string;
        isDirectMovementNotAddressed?: boolean | string;
        isExpectedInputUnderReceipt?: boolean | string;
        comments?: string;
        notes?: string;
        launchDate?: string;
        launchTime?: string;
        waitingToShipDate?: string;
        waitingToShipTime?: string;
        shipmentDate?: string;
        shipmentTime?: string;
        parcelRange?: string;
        groupOfParcel?: string;
        maximumLevelDispatchInState?: ContainerLevel;
        isContractDate?: boolean | string;
        outputMovements?: Partial<OutputMovementInput>[];
    }
    export interface DeliveryOrderLineBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        deliveryOrder: DeliveryOrder;
        lineNumber: integer;
        status: DeliveryOrderLineStatus;
        pointer: integer;
        kitPointer: integer;
        referenceNumber: string;
        orderNumber: string;
        lineType: DoLineType;
        numberOfKit: string;
        product: Product;
        quantityOfContainers: string;
        container: ProductsContainer;
        numberOfConsumptionUnit: string;
        quantityTotalShipped: string;
        stockStatus: StockNature;
        reservationNumber: string;
        lotNumber: string;
        isSingleLot: boolean;
        supportNumber: string;
        movementCode: MovementCode;
        fifoDate: string;
        creationDate: string;
        launchedQuantity: string;
        shortageQuantity: string;
        preparedQuantity: string;
        shippedQuantity: string;
        voidedQuantity: string;
        transferredQuantity: string;
        notTransferredQuantity: string;
        postponedQuantity: string;
        crossDockingQuantity: string;
        isCrossDockingManagement: boolean;
        isDirectMovementNotAddressed: boolean;
        isExpectedInputUnderReceipt: boolean;
        comments: string;
        notes: string;
        launchDate: string;
        launchTime: string;
        waitingToShipDate: string;
        waitingToShipTime: string;
        shipmentDate: string;
        shipmentTime: string;
        parcelRange: RangeOfParcel;
        groupOfParcel: string;
        maximumLevelDispatchInState: ContainerLevel;
        isContractDate: boolean;
        outputMovements: ClientCollection<OutputMovement>;
    }
    export interface DeliveryOrderLine$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        deliveryOrder: QueryOperation<DeliveryOrder>;
        product: QueryOperation<Product>;
        container: QueryOperation<ProductsContainer>;
        stockStatus: QueryOperation<StockNature>;
        movementCode: QueryOperation<MovementCode>;
        parcelRange: QueryOperation<RangeOfParcel>;
    }
    export interface DeliveryOrderLine$Operations {
        query: QueryOperation<DeliveryOrderLine>;
        read: ReadOperation<DeliveryOrderLine>;
        aggregate: {
            read: AggregateReadOperation<DeliveryOrderLine>;
            query: AggregateQueryOperation<DeliveryOrderLine>;
        };
        lookups(dataOrId: string | { data: DeliveryOrderLineInput }): DeliveryOrderLine$Lookups;
        getDefaults: GetDefaultsOperation<DeliveryOrderLine>;
    }
    export interface DeliveryOrderShipToAddresses extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        shipToAddress: string;
    }
    export interface DeliveryOrderShipToAddressesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        shipToAddress?: string;
    }
    export interface DeliveryOrderShipToAddressesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        shipToAddress: string;
    }
    export interface DeliveryOrderShipToAddresses$Operations {
        query: QueryOperation<DeliveryOrderShipToAddresses>;
        read: ReadOperation<DeliveryOrderShipToAddresses>;
        aggregate: {
            read: AggregateReadOperation<DeliveryOrderShipToAddresses>;
            query: AggregateQueryOperation<DeliveryOrderShipToAddresses>;
        };
        getDefaults: GetDefaultsOperation<DeliveryOrderShipToAddresses>;
    }
    export interface DeliveryOrderShipToCompanyNames extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        shipToCompanyName: string;
    }
    export interface DeliveryOrderShipToCompanyNamesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        shipToCompanyName?: string;
    }
    export interface DeliveryOrderShipToCompanyNamesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        shipToCompanyName: string;
    }
    export interface DeliveryOrderShipToCompanyNames$Operations {
        query: QueryOperation<DeliveryOrderShipToCompanyNames>;
        read: ReadOperation<DeliveryOrderShipToCompanyNames>;
        aggregate: {
            read: AggregateReadOperation<DeliveryOrderShipToCompanyNames>;
            query: AggregateQueryOperation<DeliveryOrderShipToCompanyNames>;
        };
        getDefaults: GetDefaultsOperation<DeliveryOrderShipToCompanyNames>;
    }
    export interface DeliveryOrder extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        referenceNumber: string;
        status: DoHeaderStatus;
        isMergingOfFlows: boolean;
        date: string;
        plannedLaunchDate: string;
        plannedLaunchTime: string;
        expectedDeliveryDate: string;
        expectedDeliveryTime: string;
        orderReference: string;
        orderNumber: string;
        orderDate: string;
        soldTo: string;
        customerReference: string;
        movementCode: MovementCode;
        pickingMode: PickingMode;
        partialDelivery: PartialDeliveryAuthorized;
        servicePriority: ServicePriority;
        isUrgent: boolean;
        originalDeliveryOrder: DeliveryOrder;
        splittingNumber: integer;
        isOutputShortageManagement: boolean;
        isPacking: Packing;
        isParcelPalletisation: boolean;
        isLoadingOfParcels: boolean;
        isShipmentManagement: boolean;
        shipTo: Customer;
        shipToPostalCode: string;
        shipToCity: string;
        shipToCountry: Country;
        shipToCountryName: string;
        shipToRegion: string;
        shipToTelephone: string;
        shipToFax: string;
        deliveryArea: string;
        deliveryNotePrintingReport: GenericPrintReport;
        printLanguage: Language;
        shipToCustomerNotes: string;
        round: Round;
        genericRound: GenericRound;
        carrier: Carrier;
        transportationMethod: TransportMode;
        carriageReference: string;
        transportType: TransportType;
        roundPosition: integer;
        billToCustomer: Customer;
        billToCountry: Country;
        billToCountryName: string;
        billToCity: string;
        billToPostalCode: string;
        billToRegion: string;
        billToTelephone: string;
        billToFax: string;
        billToCustomerNotes: string;
        wave: Wave;
        launchDate: string;
        launchTime: string;
        pickingDate: string;
        pickingTime: string;
        packingDate: string;
        packingTime: string;
        shipmentDate: string;
        shipmentTime: string;
        transmittedFromL3: TransmissionL3;
        isCarrierAmountCalculation: boolean;
        priceListCode: TariffCode;
        currency: Currency;
        crossDockingLevel: CrossDockingBlockingLevel;
        isCrossDockingManagement: boolean;
        isSsccManagementOnOutput: boolean;
        isShippingUnitSingleDeliveryOrder: boolean;
        isShippingUnitSingleCustomer: boolean;
        shippingUnitType: ShippingUnitType;
        shippingUnitGroup: string;
        lines: ClientCollection<DeliveryOrderLine>;
        billToAddresses: ClientCollection<DeliveryOrderBillToAddresses>;
        billToCompanyNames: ClientCollection<DeliveryOrderBillToCompanyNames>;
        shipToAddresses: ClientCollection<DeliveryOrderShipToAddresses>;
        shipToCompanyNames: ClientCollection<DeliveryOrderShipToCompanyNames>;
    }
    export interface DeliveryOrderInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        referenceNumber?: string;
        status?: DoHeaderStatus;
        isMergingOfFlows?: boolean | string;
        date?: string;
        plannedLaunchDate?: string;
        plannedLaunchTime?: string;
        expectedDeliveryDate?: string;
        expectedDeliveryTime?: string;
        orderReference?: string;
        orderNumber?: string;
        orderDate?: string;
        soldTo?: string;
        customerReference?: string;
        movementCode?: string;
        pickingMode?: string;
        partialDelivery?: PartialDeliveryAuthorized;
        servicePriority?: ServicePriority;
        isUrgent?: boolean | string;
        originalDeliveryOrder?: string;
        splittingNumber?: integer | string;
        isOutputShortageManagement?: boolean | string;
        isPacking?: Packing;
        isParcelPalletisation?: boolean | string;
        isLoadingOfParcels?: boolean | string;
        isShipmentManagement?: boolean | string;
        shipTo?: string;
        shipToPostalCode?: string;
        shipToCity?: string;
        shipToCountry?: string;
        shipToCountryName?: string;
        shipToRegion?: string;
        shipToTelephone?: string;
        shipToFax?: string;
        deliveryArea?: string;
        deliveryNotePrintingReport?: string;
        printLanguage?: string;
        shipToCustomerNotes?: string;
        round?: string;
        genericRound?: string;
        carrier?: string;
        transportationMethod?: string;
        carriageReference?: string;
        transportType?: string;
        roundPosition?: integer | string;
        billToCustomer?: string;
        billToCountry?: string;
        billToCountryName?: string;
        billToCity?: string;
        billToPostalCode?: string;
        billToRegion?: string;
        billToTelephone?: string;
        billToFax?: string;
        billToCustomerNotes?: string;
        wave?: string;
        launchDate?: string;
        launchTime?: string;
        pickingDate?: string;
        pickingTime?: string;
        packingDate?: string;
        packingTime?: string;
        shipmentDate?: string;
        shipmentTime?: string;
        transmittedFromL3?: TransmissionL3;
        isCarrierAmountCalculation?: boolean | string;
        priceListCode?: string;
        currency?: string;
        crossDockingLevel?: CrossDockingBlockingLevel;
        isCrossDockingManagement?: boolean | string;
        isSsccManagementOnOutput?: boolean | string;
        isShippingUnitSingleDeliveryOrder?: boolean | string;
        isShippingUnitSingleCustomer?: boolean | string;
        shippingUnitType?: string;
        shippingUnitGroup?: string;
        lines?: Partial<DeliveryOrderLineInput>[];
        billToAddresses?: Partial<DeliveryOrderBillToAddressesInput>[];
        billToCompanyNames?: Partial<DeliveryOrderBillToCompanyNamesInput>[];
        shipToAddresses?: Partial<DeliveryOrderShipToAddressesInput>[];
        shipToCompanyNames?: Partial<DeliveryOrderShipToCompanyNamesInput>[];
    }
    export interface DeliveryOrderBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        referenceNumber: string;
        status: DoHeaderStatus;
        isMergingOfFlows: boolean;
        date: string;
        plannedLaunchDate: string;
        plannedLaunchTime: string;
        expectedDeliveryDate: string;
        expectedDeliveryTime: string;
        orderReference: string;
        orderNumber: string;
        orderDate: string;
        soldTo: string;
        customerReference: string;
        movementCode: MovementCode;
        pickingMode: PickingMode;
        partialDelivery: PartialDeliveryAuthorized;
        servicePriority: ServicePriority;
        isUrgent: boolean;
        originalDeliveryOrder: DeliveryOrder;
        splittingNumber: integer;
        isOutputShortageManagement: boolean;
        isPacking: Packing;
        isParcelPalletisation: boolean;
        isLoadingOfParcels: boolean;
        isShipmentManagement: boolean;
        shipTo: Customer;
        shipToPostalCode: string;
        shipToCity: string;
        shipToCountry: Country;
        shipToCountryName: string;
        shipToRegion: string;
        shipToTelephone: string;
        shipToFax: string;
        deliveryArea: string;
        deliveryNotePrintingReport: GenericPrintReport;
        printLanguage: Language;
        shipToCustomerNotes: string;
        round: Round;
        genericRound: GenericRound;
        carrier: Carrier;
        transportationMethod: TransportMode;
        carriageReference: string;
        transportType: TransportType;
        roundPosition: integer;
        billToCustomer: Customer;
        billToCountry: Country;
        billToCountryName: string;
        billToCity: string;
        billToPostalCode: string;
        billToRegion: string;
        billToTelephone: string;
        billToFax: string;
        billToCustomerNotes: string;
        wave: Wave;
        launchDate: string;
        launchTime: string;
        pickingDate: string;
        pickingTime: string;
        packingDate: string;
        packingTime: string;
        shipmentDate: string;
        shipmentTime: string;
        transmittedFromL3: TransmissionL3;
        isCarrierAmountCalculation: boolean;
        priceListCode: TariffCode;
        currency: Currency;
        crossDockingLevel: CrossDockingBlockingLevel;
        isCrossDockingManagement: boolean;
        isSsccManagementOnOutput: boolean;
        isShippingUnitSingleDeliveryOrder: boolean;
        isShippingUnitSingleCustomer: boolean;
        shippingUnitType: ShippingUnitType;
        shippingUnitGroup: string;
        lines: ClientCollection<DeliveryOrderLine>;
        billToAddresses: ClientCollection<DeliveryOrderBillToAddressesBinding>;
        billToCompanyNames: ClientCollection<DeliveryOrderBillToCompanyNamesBinding>;
        shipToAddresses: ClientCollection<DeliveryOrderShipToAddressesBinding>;
        shipToCompanyNames: ClientCollection<DeliveryOrderShipToCompanyNamesBinding>;
    }
    export interface DeliveryOrder$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        movementCode: QueryOperation<MovementCode>;
        pickingMode: QueryOperation<PickingMode>;
        originalDeliveryOrder: QueryOperation<DeliveryOrder>;
        shipTo: QueryOperation<Customer>;
        shipToCountry: QueryOperation<Country>;
        deliveryNotePrintingReport: QueryOperation<GenericPrintReport>;
        printLanguage: QueryOperation<Language>;
        round: QueryOperation<Round>;
        genericRound: QueryOperation<GenericRound>;
        carrier: QueryOperation<Carrier>;
        transportationMethod: QueryOperation<TransportMode>;
        transportType: QueryOperation<TransportType>;
        billToCustomer: QueryOperation<Customer>;
        billToCountry: QueryOperation<Country>;
        wave: QueryOperation<Wave>;
        priceListCode: QueryOperation<TariffCode>;
        currency: QueryOperation<Currency>;
        shippingUnitType: QueryOperation<ShippingUnitType>;
    }
    export interface DeliveryOrder$Operations {
        query: QueryOperation<DeliveryOrder>;
        read: ReadOperation<DeliveryOrder>;
        aggregate: {
            read: AggregateReadOperation<DeliveryOrder>;
            query: AggregateQueryOperation<DeliveryOrder>;
        };
        lookups(dataOrId: string | { data: DeliveryOrderInput }): DeliveryOrder$Lookups;
        getDefaults: GetDefaultsOperation<DeliveryOrder>;
    }
    export interface DirectInputAddresses extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        address: string;
    }
    export interface DirectInputAddressesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        address?: string;
    }
    export interface DirectInputAddressesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        address: string;
    }
    export interface DirectInputAddresses$Operations {
        query: QueryOperation<DirectInputAddresses>;
        read: ReadOperation<DirectInputAddresses>;
        aggregate: {
            read: AggregateReadOperation<DirectInputAddresses>;
            query: AggregateQueryOperation<DirectInputAddresses>;
        };
        getDefaults: GetDefaultsOperation<DirectInputAddresses>;
    }
    export interface DirectInputLine extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        directInput: DirectInput;
        lineNumber: integer;
        pointerNumber: integer;
        referenceNumber: string;
        product: Product;
        multipleProduct: string;
        numberOfConsumptionUnit: string;
        numberOfContainers: string;
        container: ProductsContainer;
        inputContainer: ProductsContainer;
        movementCode: MovementCode;
        supportNumber: string;
        reservationNumber: string;
        lotNumber: string;
        stockStatus: StockNature;
        fifoDate: string;
        receiptDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        useByDate: string;
        shipByDate: string;
        status: InputLineStatus;
        numberOfConsumptionUnitStored: string;
        receipt: AdministrativeReceipt;
        receiptLineNumber: integer;
        expectedInputLineNumber: integer;
        inputLineType: string;
        imposedStore: Store;
        isExclusiveStore: boolean;
        isKeyInSerialNumber: boolean;
        source: Origin;
        isCustomerReturn: boolean;
        receiptMovements: ClientCollection<ReceiptMovement>;
    }
    export interface DirectInputLineInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        directInput?: string;
        lineNumber?: integer | string;
        pointerNumber?: integer | string;
        referenceNumber?: string;
        product?: string;
        multipleProduct?: string;
        numberOfConsumptionUnit?: decimal | string;
        numberOfContainers?: decimal | string;
        container?: string;
        inputContainer?: string;
        movementCode?: string;
        supportNumber?: string;
        reservationNumber?: string;
        lotNumber?: string;
        stockStatus?: string;
        fifoDate?: string;
        receiptDate?: string;
        manufacturedDate?: string;
        detentionDate?: string;
        sellByDate?: string;
        useByDate?: string;
        shipByDate?: string;
        status?: InputLineStatus;
        numberOfConsumptionUnitStored?: decimal | string;
        receipt?: string;
        receiptLineNumber?: integer | string;
        expectedInputLineNumber?: integer | string;
        inputLineType?: string;
        imposedStore?: string;
        isExclusiveStore?: boolean | string;
        isKeyInSerialNumber?: boolean | string;
        source?: string;
        isCustomerReturn?: boolean | string;
        receiptMovements?: Partial<ReceiptMovementInput>[];
    }
    export interface DirectInputLineBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        directInput: DirectInput;
        lineNumber: integer;
        pointerNumber: integer;
        referenceNumber: string;
        product: Product;
        multipleProduct: string;
        numberOfConsumptionUnit: string;
        numberOfContainers: string;
        container: ProductsContainer;
        inputContainer: ProductsContainer;
        movementCode: MovementCode;
        supportNumber: string;
        reservationNumber: string;
        lotNumber: string;
        stockStatus: StockNature;
        fifoDate: string;
        receiptDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        useByDate: string;
        shipByDate: string;
        status: InputLineStatus;
        numberOfConsumptionUnitStored: string;
        receipt: AdministrativeReceipt;
        receiptLineNumber: integer;
        expectedInputLineNumber: integer;
        inputLineType: string;
        imposedStore: Store;
        isExclusiveStore: boolean;
        isKeyInSerialNumber: boolean;
        source: Origin;
        isCustomerReturn: boolean;
        receiptMovements: ClientCollection<ReceiptMovement>;
    }
    export interface DirectInputLine$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        directInput: QueryOperation<DirectInput>;
        product: QueryOperation<Product>;
        container: QueryOperation<ProductsContainer>;
        inputContainer: QueryOperation<ProductsContainer>;
        movementCode: QueryOperation<MovementCode>;
        stockStatus: QueryOperation<StockNature>;
        receipt: QueryOperation<AdministrativeReceipt>;
        imposedStore: QueryOperation<Store>;
        source: QueryOperation<Origin>;
    }
    export interface DirectInputLine$Operations {
        query: QueryOperation<DirectInputLine>;
        read: ReadOperation<DirectInputLine>;
        aggregate: {
            read: AggregateReadOperation<DirectInputLine>;
            query: AggregateQueryOperation<DirectInputLine>;
        };
        lookups(dataOrId: string | { data: DirectInputLineInput }): DirectInputLine$Lookups;
        getDefaults: GetDefaultsOperation<DirectInputLine>;
    }
    export interface DirectInputSupplierNames extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        supplierName: string;
    }
    export interface DirectInputSupplierNamesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        supplierName?: string;
    }
    export interface DirectInputSupplierNamesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        supplierName: string;
    }
    export interface DirectInputSupplierNames$Operations {
        query: QueryOperation<DirectInputSupplierNames>;
        read: ReadOperation<DirectInputSupplierNames>;
        aggregate: {
            read: AggregateReadOperation<DirectInputSupplierNames>;
            query: AggregateQueryOperation<DirectInputSupplierNames>;
        };
        getDefaults: GetDefaultsOperation<DirectInputSupplierNames>;
    }
    export interface DirectInput extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        movementCode: MovementCode;
        referenceNumber: string;
        date: string;
        supplier: Supplier;
        postalCode: string;
        country: Country;
        countryName: string;
        city: string;
        region: string;
        telephone: string;
        fax: string;
        carrier: Carrier;
        carrierName: string;
        carriageReference: string;
        transportationMethod: TransportMode;
        status: InputHeaderStatus;
        expectedInputNumber: string;
        receipt: AdministrativeReceipt;
        receiptDate: string;
        transmittedFromL3: TransmissionL3;
        isControlled: boolean;
        isCrossDocking: boolean;
        lines: ClientCollection<DirectInputLine>;
        addresses: ClientCollection<DirectInputAddresses>;
        supplierNames: ClientCollection<DirectInputSupplierNames>;
    }
    export interface DirectInputInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        movementCode?: string;
        referenceNumber?: string;
        date?: string;
        supplier?: string;
        postalCode?: string;
        country?: string;
        countryName?: string;
        city?: string;
        region?: string;
        telephone?: string;
        fax?: string;
        carrier?: string;
        carrierName?: string;
        carriageReference?: string;
        transportationMethod?: string;
        status?: InputHeaderStatus;
        expectedInputNumber?: string;
        receipt?: string;
        receiptDate?: string;
        transmittedFromL3?: TransmissionL3;
        isControlled?: boolean | string;
        isCrossDocking?: boolean | string;
        lines?: Partial<DirectInputLineInput>[];
        addresses?: Partial<DirectInputAddressesInput>[];
        supplierNames?: Partial<DirectInputSupplierNamesInput>[];
    }
    export interface DirectInputBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        movementCode: MovementCode;
        referenceNumber: string;
        date: string;
        supplier: Supplier;
        postalCode: string;
        country: Country;
        countryName: string;
        city: string;
        region: string;
        telephone: string;
        fax: string;
        carrier: Carrier;
        carrierName: string;
        carriageReference: string;
        transportationMethod: TransportMode;
        status: InputHeaderStatus;
        expectedInputNumber: string;
        receipt: AdministrativeReceipt;
        receiptDate: string;
        transmittedFromL3: TransmissionL3;
        isControlled: boolean;
        isCrossDocking: boolean;
        lines: ClientCollection<DirectInputLine>;
        addresses: ClientCollection<DirectInputAddressesBinding>;
        supplierNames: ClientCollection<DirectInputSupplierNamesBinding>;
    }
    export interface DirectInput$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        movementCode: QueryOperation<MovementCode>;
        supplier: QueryOperation<Supplier>;
        country: QueryOperation<Country>;
        carrier: QueryOperation<Carrier>;
        transportationMethod: QueryOperation<TransportMode>;
        receipt: QueryOperation<AdministrativeReceipt>;
    }
    export interface DirectInput$Operations {
        query: QueryOperation<DirectInput>;
        read: ReadOperation<DirectInput>;
        aggregate: {
            read: AggregateReadOperation<DirectInput>;
            query: AggregateQueryOperation<DirectInput>;
        };
        lookups(dataOrId: string | { data: DirectInputInput }): DirectInput$Lookups;
        getDefaults: GetDefaultsOperation<DirectInput>;
    }
    export interface ExpectedInputAddresses extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        address: string;
    }
    export interface ExpectedInputAddressesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        address?: string;
    }
    export interface ExpectedInputAddressesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        address: string;
    }
    export interface ExpectedInputAddresses$Operations {
        query: QueryOperation<ExpectedInputAddresses>;
        read: ReadOperation<ExpectedInputAddresses>;
        aggregate: {
            read: AggregateReadOperation<ExpectedInputAddresses>;
            query: AggregateQueryOperation<ExpectedInputAddresses>;
        };
        getDefaults: GetDefaultsOperation<ExpectedInputAddresses>;
    }
    export interface ExpectedInputLine extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        expectedInput: ExpectedInput;
        lineNumber: integer;
        referenceNumber: string;
        product: Product;
        inputContainer: ProductsContainer;
        supportNumber: string;
        reservationNumber: string;
        lotNumber: string;
        movementCode: MovementCode;
        source: Origin;
        stockStatus: StockNature;
        store: Store;
        isExclusiveStore: boolean;
        multipleProducts: string;
        isCustomerReturn: boolean;
        receiptDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        useByDate: string;
        shipByDate: string;
        fifoDate: string;
        status: ExpectedInputLineStatus;
        expectedQuantityInConsumptionUnit: string;
        remainingQuantityInConsumptionUnit: string;
        receivedQuantityInConsumptionUnit: string;
        disputedQuantityinConsumptionUnit: string;
    }
    export interface ExpectedInputLineInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        expectedInput?: string;
        lineNumber?: integer | string;
        referenceNumber?: string;
        product?: string;
        inputContainer?: string;
        supportNumber?: string;
        reservationNumber?: string;
        lotNumber?: string;
        movementCode?: string;
        source?: string;
        stockStatus?: string;
        store?: string;
        isExclusiveStore?: boolean | string;
        multipleProducts?: string;
        isCustomerReturn?: boolean | string;
        receiptDate?: string;
        manufacturedDate?: string;
        detentionDate?: string;
        sellByDate?: string;
        useByDate?: string;
        shipByDate?: string;
        fifoDate?: string;
        status?: ExpectedInputLineStatus;
        expectedQuantityInConsumptionUnit?: decimal | string;
        remainingQuantityInConsumptionUnit?: decimal | string;
        receivedQuantityInConsumptionUnit?: decimal | string;
        disputedQuantityinConsumptionUnit?: decimal | string;
    }
    export interface ExpectedInputLineBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        expectedInput: ExpectedInput;
        lineNumber: integer;
        referenceNumber: string;
        product: Product;
        inputContainer: ProductsContainer;
        supportNumber: string;
        reservationNumber: string;
        lotNumber: string;
        movementCode: MovementCode;
        source: Origin;
        stockStatus: StockNature;
        store: Store;
        isExclusiveStore: boolean;
        multipleProducts: string;
        isCustomerReturn: boolean;
        receiptDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        useByDate: string;
        shipByDate: string;
        fifoDate: string;
        status: ExpectedInputLineStatus;
        expectedQuantityInConsumptionUnit: string;
        remainingQuantityInConsumptionUnit: string;
        receivedQuantityInConsumptionUnit: string;
        disputedQuantityinConsumptionUnit: string;
    }
    export interface ExpectedInputLine$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        expectedInput: QueryOperation<ExpectedInput>;
        product: QueryOperation<Product>;
        inputContainer: QueryOperation<ProductsContainer>;
        movementCode: QueryOperation<MovementCode>;
        source: QueryOperation<Origin>;
        stockStatus: QueryOperation<StockNature>;
        store: QueryOperation<Store>;
    }
    export interface ExpectedInputLine$Operations {
        query: QueryOperation<ExpectedInputLine>;
        read: ReadOperation<ExpectedInputLine>;
        aggregate: {
            read: AggregateReadOperation<ExpectedInputLine>;
            query: AggregateQueryOperation<ExpectedInputLine>;
        };
        lookups(dataOrId: string | { data: ExpectedInputLineInput }): ExpectedInputLine$Lookups;
        getDefaults: GetDefaultsOperation<ExpectedInputLine>;
    }
    export interface ExpectedInputSupplierNames extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        supplierName: string;
    }
    export interface ExpectedInputSupplierNamesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        supplierName?: string;
    }
    export interface ExpectedInputSupplierNamesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        supplierName: string;
    }
    export interface ExpectedInputSupplierNames$Operations {
        query: QueryOperation<ExpectedInputSupplierNames>;
        read: ReadOperation<ExpectedInputSupplierNames>;
        aggregate: {
            read: AggregateReadOperation<ExpectedInputSupplierNames>;
            query: AggregateQueryOperation<ExpectedInputSupplierNames>;
        };
        getDefaults: GetDefaultsOperation<ExpectedInputSupplierNames>;
    }
    export interface ExpectedInput extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        date: string;
        time: string;
        receiptMode: ReceiptMode;
        movementCode: MovementCode;
        referenceNumber: string;
        carrierAppointment: AppointmentManagement;
        appointmentDate: string;
        appointmentTime: string;
        supplier: Supplier;
        postalCode: string;
        countryCode: Country;
        countryName: string;
        city: string;
        region: string;
        telephone: string;
        fax: string;
        carrier: Carrier;
        carrierName: string;
        carriageReference: string;
        transportationMethod: TransportMode;
        status: ExpectedInputStatus;
        lastReceipt: AdministrativeReceipt;
        previousReceipt: AdministrativeReceipt;
        transmittedFromL3: TransmissionL3;
        isQualityControlManagement: boolean;
        orderNumber: string;
        orderReference: string;
        lines: ClientCollection<ExpectedInputLine>;
        addresses: ClientCollection<ExpectedInputAddresses>;
        supplierNames: ClientCollection<ExpectedInputSupplierNames>;
    }
    export interface ExpectedInputInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        date?: string;
        time?: string;
        receiptMode?: string;
        movementCode?: string;
        referenceNumber?: string;
        carrierAppointment?: string;
        appointmentDate?: string;
        appointmentTime?: string;
        supplier?: string;
        postalCode?: string;
        countryCode?: string;
        countryName?: string;
        city?: string;
        region?: string;
        telephone?: string;
        fax?: string;
        carrier?: string;
        carrierName?: string;
        carriageReference?: string;
        transportationMethod?: string;
        status?: ExpectedInputStatus;
        lastReceipt?: string;
        previousReceipt?: string;
        transmittedFromL3?: TransmissionL3;
        isQualityControlManagement?: boolean | string;
        orderNumber?: string;
        orderReference?: string;
        lines?: Partial<ExpectedInputLineInput>[];
        addresses?: Partial<ExpectedInputAddressesInput>[];
        supplierNames?: Partial<ExpectedInputSupplierNamesInput>[];
    }
    export interface ExpectedInputBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        date: string;
        time: string;
        receiptMode: ReceiptMode;
        movementCode: MovementCode;
        referenceNumber: string;
        carrierAppointment: AppointmentManagement;
        appointmentDate: string;
        appointmentTime: string;
        supplier: Supplier;
        postalCode: string;
        countryCode: Country;
        countryName: string;
        city: string;
        region: string;
        telephone: string;
        fax: string;
        carrier: Carrier;
        carrierName: string;
        carriageReference: string;
        transportationMethod: TransportMode;
        status: ExpectedInputStatus;
        lastReceipt: AdministrativeReceipt;
        previousReceipt: AdministrativeReceipt;
        transmittedFromL3: TransmissionL3;
        isQualityControlManagement: boolean;
        orderNumber: string;
        orderReference: string;
        lines: ClientCollection<ExpectedInputLine>;
        addresses: ClientCollection<ExpectedInputAddressesBinding>;
        supplierNames: ClientCollection<ExpectedInputSupplierNamesBinding>;
    }
    export interface ExpectedInput$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        receiptMode: QueryOperation<ReceiptMode>;
        movementCode: QueryOperation<MovementCode>;
        carrierAppointment: QueryOperation<AppointmentManagement>;
        supplier: QueryOperation<Supplier>;
        countryCode: QueryOperation<Country>;
        carrier: QueryOperation<Carrier>;
        transportationMethod: QueryOperation<TransportMode>;
        lastReceipt: QueryOperation<AdministrativeReceipt>;
        previousReceipt: QueryOperation<AdministrativeReceipt>;
    }
    export interface ExpectedInput$Operations {
        query: QueryOperation<ExpectedInput>;
        read: ReadOperation<ExpectedInput>;
        aggregate: {
            read: AggregateReadOperation<ExpectedInput>;
            query: AggregateQueryOperation<ExpectedInput>;
        };
        lookups(dataOrId: string | { data: ExpectedInputInput }): ExpectedInput$Lookups;
        getDefaults: GetDefaultsOperation<ExpectedInput>;
    }
    export interface KitDeclaration extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        assemblyOrder: AssemblingOrder;
        assemblyOrderLine: AssemblingOrderLine;
        kit: Product;
        quantity: string;
        assemblyWave: AssemblingWave;
        status: AssemblyMovementStatus;
        type: Type;
        postingDate: string;
        validatingUser: string;
        validatingOperator: Operand;
    }
    export interface KitDeclarationInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        assemblyOrder?: string;
        assemblyOrderLine?: integer | string;
        kit?: string;
        quantity?: decimal | string;
        assemblyWave?: string;
        status?: AssemblyMovementStatus;
        type?: Type;
        postingDate?: string;
        validatingUser?: string;
        validatingOperator?: string;
    }
    export interface KitDeclarationBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        assemblyOrder: AssemblingOrder;
        assemblyOrderLine: AssemblingOrderLine;
        kit: Product;
        quantity: string;
        assemblyWave: AssemblingWave;
        status: AssemblyMovementStatus;
        type: Type;
        postingDate: string;
        validatingUser: string;
        validatingOperator: Operand;
    }
    export interface KitDeclaration$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        assemblyOrder: QueryOperation<AssemblingOrder>;
        assemblyOrderLine: QueryOperation<AssemblingOrderLine>;
        kit: QueryOperation<Product>;
        assemblyWave: QueryOperation<AssemblingWave>;
        validatingOperator: QueryOperation<Operand>;
    }
    export interface KitDeclaration$Operations {
        query: QueryOperation<KitDeclaration>;
        read: ReadOperation<KitDeclaration>;
        aggregate: {
            read: AggregateReadOperation<KitDeclaration>;
            query: AggregateQueryOperation<KitDeclaration>;
        };
        lookups(dataOrId: string | { data: KitDeclarationInput }): KitDeclaration$Lookups;
        getDefaults: GetDefaultsOperation<KitDeclaration>;
    }
    export interface OutputMovementContainerLevels extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        containerLevel: ProductsContainer;
        quantityOfConsumptionUnitPerLevel: string;
    }
    export interface OutputMovementContainerLevelsInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        containerLevel?: string;
        quantityOfConsumptionUnitPerLevel?: decimal | string;
    }
    export interface OutputMovementContainerLevelsBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        containerLevel: ProductsContainer;
        quantityOfConsumptionUnitPerLevel: string;
    }
    export interface OutputMovementContainerLevels$Lookups {
        containerLevel: QueryOperation<ProductsContainer>;
    }
    export interface OutputMovementContainerLevels$Operations {
        query: QueryOperation<OutputMovementContainerLevels>;
        read: ReadOperation<OutputMovementContainerLevels>;
        aggregate: {
            read: AggregateReadOperation<OutputMovementContainerLevels>;
            query: AggregateQueryOperation<OutputMovementContainerLevels>;
        };
        lookups(dataOrId: string | { data: OutputMovementContainerLevelsInput }): OutputMovementContainerLevels$Lookups;
        getDefaults: GetDefaultsOperation<OutputMovementContainerLevels>;
    }
    export interface OutputMovement extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        deliveryOrder: DeliveryOrder;
        deliveryLineNumber: integer;
        wave: Wave;
        subWaveNumber: integer;
        pickingOrder: PickingOrder;
        pickingOrderSorting: string;
        lineType: DoLineType;
        product: Product;
        numberOfContainers: string;
        container: ProductsContainer;
        homogeneousContainerCoefficient: string;
        numberOfConsumptionUnit: string;
        numberOfKit: string;
        movementCode: MovementCode;
        lotNumber: string;
        stockStatus: StockNature;
        reservationNumber: string;
        supportNumber: string;
        status: OutputMovementStatus;
        source: Origin;
        fifoDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        shipByDate: string;
        useByDate: string;
        pickingMode: PickingMode;
        store: Store;
        location: Location;
        locationType: LocationType;
        stockObject: StockObject;
        containerNumber: string;
        homogeneousContainer: ProductsContainer;
        homogeneousQuantity: string;
        originContainer: ProductsContainer;
        sourceQuantity: string;
        parcel: Parcel;
        shippingUnit: ShippingUnit;
        parcelSequence: integer;
        deliveryNote: DeliveryNote;
        round: Round;
        roundSite: Site;
        travelSequence: string;
        rowByLevel: string;
        isInTransit: boolean;
        destinationSite: Site;
        validatingOperator: Operand;
        validatingUser: string;
        postingDate: string;
        postingTime: integer;
        groupingCode: string;
        isContractDate: boolean;
        parcels: ClientCollection<Parcel>;
        containerLevels: ClientCollection<OutputMovementContainerLevels>;
    }
    export interface OutputMovementInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        deliveryOrder?: string;
        deliveryLineNumber?: integer | string;
        wave?: string;
        subWaveNumber?: integer | string;
        pickingOrder?: string;
        pickingOrderSorting?: string;
        lineType?: DoLineType;
        product?: string;
        numberOfContainers?: decimal | string;
        container?: string;
        homogeneousContainerCoefficient?: decimal | string;
        numberOfConsumptionUnit?: decimal | string;
        numberOfKit?: decimal | string;
        movementCode?: string;
        lotNumber?: string;
        stockStatus?: string;
        reservationNumber?: string;
        supportNumber?: string;
        status?: OutputMovementStatus;
        source?: string;
        fifoDate?: string;
        manufacturedDate?: string;
        detentionDate?: string;
        sellByDate?: string;
        shipByDate?: string;
        useByDate?: string;
        pickingMode?: string;
        store?: string;
        location?: string;
        locationType?: LocationType;
        stockObject?: string;
        containerNumber?: string;
        homogeneousContainer?: string;
        homogeneousQuantity?: decimal | string;
        originContainer?: string;
        sourceQuantity?: decimal | string;
        parcel?: string;
        shippingUnit?: string;
        parcelSequence?: integer | string;
        deliveryNote?: string;
        round?: string;
        roundSite?: string;
        travelSequence?: string;
        rowByLevel?: string;
        isInTransit?: boolean | string;
        destinationSite?: string;
        validatingOperator?: string;
        validatingUser?: string;
        postingDate?: string;
        postingTime?: integer | string;
        groupingCode?: string;
        isContractDate?: boolean | string;
        parcels?: Partial<ParcelInput>[];
        containerLevels?: Partial<OutputMovementContainerLevelsInput>[];
    }
    export interface OutputMovementBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        deliveryOrder: DeliveryOrder;
        deliveryLineNumber: integer;
        wave: Wave;
        subWaveNumber: integer;
        pickingOrder: PickingOrder;
        pickingOrderSorting: string;
        lineType: DoLineType;
        product: Product;
        numberOfContainers: string;
        container: ProductsContainer;
        homogeneousContainerCoefficient: string;
        numberOfConsumptionUnit: string;
        numberOfKit: string;
        movementCode: MovementCode;
        lotNumber: string;
        stockStatus: StockNature;
        reservationNumber: string;
        supportNumber: string;
        status: OutputMovementStatus;
        source: Origin;
        fifoDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        shipByDate: string;
        useByDate: string;
        pickingMode: PickingMode;
        store: Store;
        location: Location;
        locationType: LocationType;
        stockObject: StockObject;
        containerNumber: string;
        homogeneousContainer: ProductsContainer;
        homogeneousQuantity: string;
        originContainer: ProductsContainer;
        sourceQuantity: string;
        parcel: Parcel;
        shippingUnit: ShippingUnit;
        parcelSequence: integer;
        deliveryNote: DeliveryNote;
        round: Round;
        roundSite: Site;
        travelSequence: string;
        rowByLevel: string;
        isInTransit: boolean;
        destinationSite: Site;
        validatingOperator: Operand;
        validatingUser: string;
        postingDate: string;
        postingTime: integer;
        groupingCode: string;
        isContractDate: boolean;
        parcels: ClientCollection<Parcel>;
        containerLevels: ClientCollection<OutputMovementContainerLevelsBinding>;
    }
    export interface OutputMovement$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        deliveryOrder: QueryOperation<DeliveryOrder>;
        wave: QueryOperation<Wave>;
        pickingOrder: QueryOperation<PickingOrder>;
        product: QueryOperation<Product>;
        container: QueryOperation<ProductsContainer>;
        movementCode: QueryOperation<MovementCode>;
        stockStatus: QueryOperation<StockNature>;
        source: QueryOperation<Origin>;
        pickingMode: QueryOperation<PickingMode>;
        store: QueryOperation<Store>;
        location: QueryOperation<Location>;
        stockObject: QueryOperation<StockObject>;
        homogeneousContainer: QueryOperation<ProductsContainer>;
        originContainer: QueryOperation<ProductsContainer>;
        parcel: QueryOperation<Parcel>;
        shippingUnit: QueryOperation<ShippingUnit>;
        deliveryNote: QueryOperation<DeliveryNote>;
        round: QueryOperation<Round>;
        roundSite: QueryOperation<Site>;
        destinationSite: QueryOperation<Site>;
        validatingOperator: QueryOperation<Operand>;
    }
    export interface OutputMovement$Operations {
        query: QueryOperation<OutputMovement>;
        read: ReadOperation<OutputMovement>;
        aggregate: {
            read: AggregateReadOperation<OutputMovement>;
            query: AggregateQueryOperation<OutputMovement>;
        };
        lookups(dataOrId: string | { data: OutputMovementInput }): OutputMovement$Lookups;
        getDefaults: GetDefaultsOperation<OutputMovement>;
    }
    export interface Parcel extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        wave: Wave;
        deliveryOrder: DeliveryOrder;
        pickingOrder: PickingOrder;
        palletisationOrder: AutoPalletizationOrder;
        status: ParcelStatus;
        preparationArea: PreparationArea;
        pickingMode: PickingMode;
        parcelRange: RangeOfParcel;
        parcelType: ParcelType;
        height: string;
        width: string;
        depth: string;
        volume: string;
        estimatedWeight: string;
        realWeight: string;
        isDispatchableInState: boolean;
        isPalettizableAsIs: boolean;
        carrierParcelNumber: string;
        carrier: Carrier;
        transportationMethod: TransportMode;
        deliveryNote: DeliveryNote;
        shippingUnit: ShippingUnit;
        isPostponed: boolean;
        validatingOperator: Operand;
        validatingUser: string;
        postingDate: string;
        postingTime: integer;
        pickingOrderSorting: string;
        ssccParcelCode: string;
        dockStore: Store;
        dockAddress: Location;
        originDockStore: Store;
        originDockAddress: Location;
        stockOnDockStatus: Colis;
        isStockOnDockControl: boolean;
        pickingOrderType: PoType;
        shippingUnits: ClientCollection<ShippingUnit>;
        outputMovements: ClientCollection<OutputMovement>;
    }
    export interface ParcelInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        wave?: string;
        deliveryOrder?: string;
        pickingOrder?: string;
        palletisationOrder?: string;
        status?: ParcelStatus;
        preparationArea?: string;
        pickingMode?: string;
        parcelRange?: string;
        parcelType?: string;
        height?: decimal | string;
        width?: decimal | string;
        depth?: decimal | string;
        volume?: decimal | string;
        estimatedWeight?: decimal | string;
        realWeight?: decimal | string;
        isDispatchableInState?: boolean | string;
        isPalettizableAsIs?: boolean | string;
        carrierParcelNumber?: string;
        carrier?: string;
        transportationMethod?: string;
        deliveryNote?: string;
        shippingUnit?: string;
        isPostponed?: boolean | string;
        validatingOperator?: string;
        validatingUser?: string;
        postingDate?: string;
        postingTime?: integer | string;
        pickingOrderSorting?: string;
        ssccParcelCode?: string;
        dockStore?: string;
        dockAddress?: string;
        originDockStore?: string;
        originDockAddress?: string;
        stockOnDockStatus?: Colis;
        isStockOnDockControl?: boolean | string;
        pickingOrderType?: PoType;
        shippingUnits?: Partial<ShippingUnitInput>[];
        outputMovements?: Partial<OutputMovementInput>[];
    }
    export interface ParcelBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        wave: Wave;
        deliveryOrder: DeliveryOrder;
        pickingOrder: PickingOrder;
        palletisationOrder: AutoPalletizationOrder;
        status: ParcelStatus;
        preparationArea: PreparationArea;
        pickingMode: PickingMode;
        parcelRange: RangeOfParcel;
        parcelType: ParcelType;
        height: string;
        width: string;
        depth: string;
        volume: string;
        estimatedWeight: string;
        realWeight: string;
        isDispatchableInState: boolean;
        isPalettizableAsIs: boolean;
        carrierParcelNumber: string;
        carrier: Carrier;
        transportationMethod: TransportMode;
        deliveryNote: DeliveryNote;
        shippingUnit: ShippingUnit;
        isPostponed: boolean;
        validatingOperator: Operand;
        validatingUser: string;
        postingDate: string;
        postingTime: integer;
        pickingOrderSorting: string;
        ssccParcelCode: string;
        dockStore: Store;
        dockAddress: Location;
        originDockStore: Store;
        originDockAddress: Location;
        stockOnDockStatus: Colis;
        isStockOnDockControl: boolean;
        pickingOrderType: PoType;
        shippingUnits: ClientCollection<ShippingUnit>;
        outputMovements: ClientCollection<OutputMovement>;
    }
    export interface Parcel$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        wave: QueryOperation<Wave>;
        deliveryOrder: QueryOperation<DeliveryOrder>;
        pickingOrder: QueryOperation<PickingOrder>;
        palletisationOrder: QueryOperation<AutoPalletizationOrder>;
        preparationArea: QueryOperation<PreparationArea>;
        pickingMode: QueryOperation<PickingMode>;
        parcelRange: QueryOperation<RangeOfParcel>;
        parcelType: QueryOperation<ParcelType>;
        carrier: QueryOperation<Carrier>;
        transportationMethod: QueryOperation<TransportMode>;
        deliveryNote: QueryOperation<DeliveryNote>;
        shippingUnit: QueryOperation<ShippingUnit>;
        validatingOperator: QueryOperation<Operand>;
        dockStore: QueryOperation<Store>;
        dockAddress: QueryOperation<Location>;
        originDockStore: QueryOperation<Store>;
        originDockAddress: QueryOperation<Location>;
    }
    export interface Parcel$Operations {
        query: QueryOperation<Parcel>;
        read: ReadOperation<Parcel>;
        aggregate: {
            read: AggregateReadOperation<Parcel>;
            query: AggregateQueryOperation<Parcel>;
        };
        lookups(dataOrId: string | { data: ParcelInput }): Parcel$Lookups;
        getDefaults: GetDefaultsOperation<Parcel>;
    }
    export interface PickingOrder extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        status: StoringListPurchaseOrderStatus;
        pickingOrderType: PoType;
        pickingMode: PickingMode;
        preparationArea: PreparationArea;
        deliveryOrder: DeliveryOrder;
        round: Round;
        level: ContainerLevel;
        isPreparationOrderKit: boolean;
        date: string;
        time: string;
        totalMovements: integer;
        totalConsumptionUnit: string;
        totalWeight: string;
        totalVolume: string;
        preparationTime: string;
        equivalentSurface: string;
        numberOfParcels: integer;
        numberOfShippingUnits: integer;
        wave: Wave;
        subWaveNumber: integer;
        shipTo: Customer;
        validatingOperator: Operand;
        postingDate: string;
        postingTime: integer;
        validatingUser: string;
        outputMovements: ClientCollection<OutputMovement>;
    }
    export interface PickingOrderInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        status?: StoringListPurchaseOrderStatus;
        pickingOrderType?: PoType;
        pickingMode?: string;
        preparationArea?: string;
        deliveryOrder?: string;
        round?: string;
        level?: ContainerLevel;
        isPreparationOrderKit?: boolean | string;
        date?: string;
        time?: string;
        totalMovements?: integer | string;
        totalConsumptionUnit?: decimal | string;
        totalWeight?: decimal | string;
        totalVolume?: decimal | string;
        preparationTime?: decimal | string;
        equivalentSurface?: decimal | string;
        numberOfParcels?: integer | string;
        numberOfShippingUnits?: integer | string;
        wave?: string;
        subWaveNumber?: integer | string;
        shipTo?: string;
        validatingOperator?: string;
        postingDate?: string;
        postingTime?: integer | string;
        validatingUser?: string;
        outputMovements?: Partial<OutputMovementInput>[];
    }
    export interface PickingOrderBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        status: StoringListPurchaseOrderStatus;
        pickingOrderType: PoType;
        pickingMode: PickingMode;
        preparationArea: PreparationArea;
        deliveryOrder: DeliveryOrder;
        round: Round;
        level: ContainerLevel;
        isPreparationOrderKit: boolean;
        date: string;
        time: string;
        totalMovements: integer;
        totalConsumptionUnit: string;
        totalWeight: string;
        totalVolume: string;
        preparationTime: string;
        equivalentSurface: string;
        numberOfParcels: integer;
        numberOfShippingUnits: integer;
        wave: Wave;
        subWaveNumber: integer;
        shipTo: Customer;
        validatingOperator: Operand;
        postingDate: string;
        postingTime: integer;
        validatingUser: string;
        outputMovements: ClientCollection<OutputMovement>;
    }
    export interface PickingOrder$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        pickingMode: QueryOperation<PickingMode>;
        preparationArea: QueryOperation<PreparationArea>;
        deliveryOrder: QueryOperation<DeliveryOrder>;
        round: QueryOperation<Round>;
        wave: QueryOperation<Wave>;
        shipTo: QueryOperation<Customer>;
        validatingOperator: QueryOperation<Operand>;
    }
    export interface PickingOrder$Operations {
        query: QueryOperation<PickingOrder>;
        read: ReadOperation<PickingOrder>;
        aggregate: {
            read: AggregateReadOperation<PickingOrder>;
            query: AggregateQueryOperation<PickingOrder>;
        };
        lookups(dataOrId: string | { data: PickingOrderInput }): PickingOrder$Lookups;
        getDefaults: GetDefaultsOperation<PickingOrder>;
    }
    export interface ReceiptMovementContainerLevels extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        directInput: string;
        directInputLine: integer;
        code: string;
        containerLevel: ProductsContainer;
        quantityOfConsumptionUnitPerLevel: string;
    }
    export interface ReceiptMovementContainerLevelsInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        directInput?: string;
        directInputLine?: integer | string;
        code?: string;
        containerLevel?: string;
        quantityOfConsumptionUnitPerLevel?: decimal | string;
    }
    export interface ReceiptMovementContainerLevelsBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        directInput: string;
        directInputLine: integer;
        code: string;
        containerLevel: ProductsContainer;
        quantityOfConsumptionUnitPerLevel: string;
    }
    export interface ReceiptMovementContainerLevels$Lookups {
        containerLevel: QueryOperation<ProductsContainer>;
    }
    export interface ReceiptMovementContainerLevels$Operations {
        query: QueryOperation<ReceiptMovementContainerLevels>;
        read: ReadOperation<ReceiptMovementContainerLevels>;
        aggregate: {
            read: AggregateReadOperation<ReceiptMovementContainerLevels>;
            query: AggregateQueryOperation<ReceiptMovementContainerLevels>;
        };
        lookups(
            dataOrId: string | { data: ReceiptMovementContainerLevelsInput },
        ): ReceiptMovementContainerLevels$Lookups;
        getDefaults: GetDefaultsOperation<ReceiptMovementContainerLevels>;
    }
    export interface ReceiptMovement extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        directInput: DirectInput;
        directInputLine: DirectInputLine;
        code: string;
        store: Store;
        imposedStore: Store;
        isExclusiveStore: boolean;
        location: Location;
        locationType: LocationType;
        stockObject: StockObject;
        containerNumber: string;
        product: Product;
        stockStatus: StockNature;
        source: Origin;
        lotNumber: string;
        reservationNumber: string;
        supportNumber: string;
        numberOfContainers: string;
        container: ProductsContainer;
        quantityInConsumptionUnit: string;
        level: ContainerLevel;
        standardizedQuantity: string;
        homogeneousContainer: ProductsContainer;
        homogeneousContainerCoefficient: string;
        movementCode: MovementCode;
        status: InputMovementStatus;
        fifoDate: string;
        receiptDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        useByDte: string;
        shipByDate: string;
        storingList: StoringList;
        storingListLineNumber: integer;
        movementType: MovementType;
        containerLevels: ClientCollection<ReceiptMovementContainerLevels>;
    }
    export interface ReceiptMovementInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        directInput?: string;
        directInputLine?: integer | string;
        code?: string;
        store?: string;
        imposedStore?: string;
        isExclusiveStore?: boolean | string;
        location?: string;
        locationType?: LocationType;
        stockObject?: string;
        containerNumber?: string;
        product?: string;
        stockStatus?: string;
        source?: string;
        lotNumber?: string;
        reservationNumber?: string;
        supportNumber?: string;
        numberOfContainers?: decimal | string;
        container?: string;
        quantityInConsumptionUnit?: decimal | string;
        level?: ContainerLevel;
        standardizedQuantity?: decimal | string;
        homogeneousContainer?: string;
        homogeneousContainerCoefficient?: decimal | string;
        movementCode?: string;
        status?: InputMovementStatus;
        fifoDate?: string;
        receiptDate?: string;
        manufacturedDate?: string;
        detentionDate?: string;
        sellByDate?: string;
        useByDte?: string;
        shipByDate?: string;
        storingList?: string;
        storingListLineNumber?: integer | string;
        movementType?: MovementType;
        containerLevels?: Partial<ReceiptMovementContainerLevelsInput>[];
    }
    export interface ReceiptMovementBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        directInput: DirectInput;
        directInputLine: DirectInputLine;
        code: string;
        store: Store;
        imposedStore: Store;
        isExclusiveStore: boolean;
        location: Location;
        locationType: LocationType;
        stockObject: StockObject;
        containerNumber: string;
        product: Product;
        stockStatus: StockNature;
        source: Origin;
        lotNumber: string;
        reservationNumber: string;
        supportNumber: string;
        numberOfContainers: string;
        container: ProductsContainer;
        quantityInConsumptionUnit: string;
        level: ContainerLevel;
        standardizedQuantity: string;
        homogeneousContainer: ProductsContainer;
        homogeneousContainerCoefficient: string;
        movementCode: MovementCode;
        status: InputMovementStatus;
        fifoDate: string;
        receiptDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        useByDte: string;
        shipByDate: string;
        storingList: StoringList;
        storingListLineNumber: integer;
        movementType: MovementType;
        containerLevels: ClientCollection<ReceiptMovementContainerLevelsBinding>;
    }
    export interface ReceiptMovement$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        directInput: QueryOperation<DirectInput>;
        directInputLine: QueryOperation<DirectInputLine>;
        store: QueryOperation<Store>;
        imposedStore: QueryOperation<Store>;
        location: QueryOperation<Location>;
        stockObject: QueryOperation<StockObject>;
        product: QueryOperation<Product>;
        stockStatus: QueryOperation<StockNature>;
        source: QueryOperation<Origin>;
        container: QueryOperation<ProductsContainer>;
        homogeneousContainer: QueryOperation<ProductsContainer>;
        movementCode: QueryOperation<MovementCode>;
        storingList: QueryOperation<StoringList>;
    }
    export interface ReceiptMovement$Operations {
        query: QueryOperation<ReceiptMovement>;
        read: ReadOperation<ReceiptMovement>;
        aggregate: {
            read: AggregateReadOperation<ReceiptMovement>;
            query: AggregateQueryOperation<ReceiptMovement>;
        };
        lookups(dataOrId: string | { data: ReceiptMovementInput }): ReceiptMovement$Lookups;
        getDefaults: GetDefaultsOperation<ReceiptMovement>;
    }
    export interface Round extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        dockType: DockManagement;
        code: string;
        appointment: AppointmentManagement;
        date: string;
        time: string;
        duration: string;
        status: RoundStatus;
        carrier: Carrier;
        carrierName: string;
        transportationMethod: TransportMode;
        carriageReference: string;
        dockStore: Store;
        dockAddress: Location;
        genericRound: GenericRound;
        volume: string;
        weight: string;
        linearMeters: string;
        numberOfDeliveryOrders: integer;
        numberOfLines: integer;
        deliveryOrderNumber: integer;
        numberOfConsumptionUnit: integer;
        numberOfShippingUnits: integer;
        transportType: TransportType;
        shipTo: Customer;
        isInterSiteRound: boolean;
        destinationSite: Site;
        deliveryOrders: ClientCollection<DeliveryOrder>;
    }
    export interface RoundInput extends ClientNodeInput {
        site?: string;
        dockType?: DockManagement;
        code?: string;
        appointment?: string;
        date?: string;
        time?: string;
        duration?: string;
        status?: RoundStatus;
        carrier?: string;
        carrierName?: string;
        transportationMethod?: string;
        carriageReference?: string;
        dockStore?: string;
        dockAddress?: string;
        genericRound?: string;
        volume?: decimal | string;
        weight?: decimal | string;
        linearMeters?: decimal | string;
        numberOfDeliveryOrders?: integer | string;
        numberOfLines?: integer | string;
        deliveryOrderNumber?: integer | string;
        numberOfConsumptionUnit?: integer | string;
        numberOfShippingUnits?: integer | string;
        transportType?: string;
        shipTo?: string;
        isInterSiteRound?: boolean | string;
        destinationSite?: string;
        deliveryOrders?: Partial<DeliveryOrderInput>[];
    }
    export interface RoundBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        dockType: DockManagement;
        code: string;
        appointment: AppointmentManagement;
        date: string;
        time: string;
        duration: string;
        status: RoundStatus;
        carrier: Carrier;
        carrierName: string;
        transportationMethod: TransportMode;
        carriageReference: string;
        dockStore: Store;
        dockAddress: Location;
        genericRound: GenericRound;
        volume: string;
        weight: string;
        linearMeters: string;
        numberOfDeliveryOrders: integer;
        numberOfLines: integer;
        deliveryOrderNumber: integer;
        numberOfConsumptionUnit: integer;
        numberOfShippingUnits: integer;
        transportType: TransportType;
        shipTo: Customer;
        isInterSiteRound: boolean;
        destinationSite: Site;
        deliveryOrders: ClientCollection<DeliveryOrder>;
    }
    export interface Round$Lookups {
        site: QueryOperation<Site>;
        appointment: QueryOperation<AppointmentManagement>;
        carrier: QueryOperation<Carrier>;
        transportationMethod: QueryOperation<TransportMode>;
        dockStore: QueryOperation<Store>;
        dockAddress: QueryOperation<Location>;
        genericRound: QueryOperation<GenericRound>;
        transportType: QueryOperation<TransportType>;
        shipTo: QueryOperation<Customer>;
        destinationSite: QueryOperation<Site>;
    }
    export interface Round$Operations {
        query: QueryOperation<Round>;
        read: ReadOperation<Round>;
        aggregate: {
            read: AggregateReadOperation<Round>;
            query: AggregateQueryOperation<Round>;
        };
        lookups(dataOrId: string | { data: RoundInput }): Round$Lookups;
        getDefaults: GetDefaultsOperation<Round>;
    }
    export interface SerialNumberCountingLine extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        stockCount: StockCount;
        counting: Counting;
        lineNumber: integer;
        serialNumber: string;
        double: integer;
        depositor: Depositor;
        product: Product;
        store: Store;
        location: Location;
        serialGroup: string;
        parentGroup: string;
        free1: string;
        free2: string;
        free3: string;
        free4: string;
        free5: string;
        isNonExistentSerialNumber: boolean;
    }
    export interface SerialNumberCountingLineInput extends ClientNodeInput {
        site?: string;
        stockCount?: string;
        counting?: integer | string;
        lineNumber?: integer | string;
        serialNumber?: string;
        double?: integer | string;
        depositor?: string;
        product?: string;
        store?: string;
        location?: string;
        serialGroup?: string;
        parentGroup?: string;
        free1?: string;
        free2?: string;
        free3?: string;
        free4?: string;
        free5?: string;
        isNonExistentSerialNumber?: boolean | string;
    }
    export interface SerialNumberCountingLineBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        stockCount: StockCount;
        counting: Counting;
        lineNumber: integer;
        serialNumber: string;
        double: integer;
        depositor: Depositor;
        product: Product;
        store: Store;
        location: Location;
        serialGroup: string;
        parentGroup: string;
        free1: string;
        free2: string;
        free3: string;
        free4: string;
        free5: string;
        isNonExistentSerialNumber: boolean;
    }
    export interface SerialNumberCountingLine$Lookups {
        site: QueryOperation<Site>;
        stockCount: QueryOperation<StockCount>;
        counting: QueryOperation<Counting>;
        depositor: QueryOperation<Depositor>;
        product: QueryOperation<Product>;
        store: QueryOperation<Store>;
        location: QueryOperation<Location>;
    }
    export interface SerialNumberCountingLine$Operations {
        query: QueryOperation<SerialNumberCountingLine>;
        read: ReadOperation<SerialNumberCountingLine>;
        aggregate: {
            read: AggregateReadOperation<SerialNumberCountingLine>;
            query: AggregateQueryOperation<SerialNumberCountingLine>;
        };
        lookups(dataOrId: string | { data: SerialNumberCountingLineInput }): SerialNumberCountingLine$Lookups;
        getDefaults: GetDefaultsOperation<SerialNumberCountingLine>;
    }
    export interface SerialNumber extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        product: Product;
        code: string;
        double: integer;
        occurrence: integer;
        directInput: DirectInput;
        inputLineNumber: integer;
        receiptDate: string;
        deliveryOrder: DeliveryOrder;
        deliveryOrderLineNumber: integer;
        outputDate: string;
        inputAdjustment: AdjustmentMovement;
        outputAdjustment: AdjustmentMovement;
        transmittedToL3: integer;
        inputMovement: ReceiptMovement;
        outputMovement: OutputMovement;
        transfer: TransferMovement;
        transferMovement: TransferMovement;
        stockObject: StockObject;
        serialGroup: SerialGroup;
        validatedStoringList: integer;
        validatedPreparationOrder: integer;
        serialParentGroup: SerialGroup;
        transferDate: string;
        free1: string;
        free2: string;
        free3: string;
        free4: string;
        free5: string;
        voided: integer;
        postponed: integer;
        keyCodeForDuplicates: string;
    }
    export interface SerialNumberInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        product?: string;
        code?: string;
        double?: integer | string;
        occurrence?: integer | string;
        directInput?: string;
        inputLineNumber?: integer | string;
        receiptDate?: string;
        deliveryOrder?: string;
        deliveryOrderLineNumber?: integer | string;
        outputDate?: string;
        inputAdjustment?: string;
        outputAdjustment?: string;
        transmittedToL3?: integer | string;
        inputMovement?: string;
        outputMovement?: string;
        transfer?: string;
        transferMovement?: string;
        stockObject?: string;
        serialGroup?: string;
        validatedStoringList?: integer | string;
        validatedPreparationOrder?: integer | string;
        serialParentGroup?: string;
        transferDate?: string;
        free1?: string;
        free2?: string;
        free3?: string;
        free4?: string;
        free5?: string;
        voided?: integer | string;
        postponed?: integer | string;
    }
    export interface SerialNumberBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        product: Product;
        code: string;
        double: integer;
        occurrence: integer;
        directInput: DirectInput;
        inputLineNumber: integer;
        receiptDate: string;
        deliveryOrder: DeliveryOrder;
        deliveryOrderLineNumber: integer;
        outputDate: string;
        inputAdjustment: AdjustmentMovement;
        outputAdjustment: AdjustmentMovement;
        transmittedToL3: integer;
        inputMovement: ReceiptMovement;
        outputMovement: OutputMovement;
        transfer: TransferMovement;
        transferMovement: TransferMovement;
        stockObject: StockObject;
        serialGroup: SerialGroup;
        validatedStoringList: integer;
        validatedPreparationOrder: integer;
        serialParentGroup: SerialGroup;
        transferDate: string;
        free1: string;
        free2: string;
        free3: string;
        free4: string;
        free5: string;
        voided: integer;
        postponed: integer;
        keyCodeForDuplicates: string;
    }
    export interface SerialNumber$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        product: QueryOperation<Product>;
        directInput: QueryOperation<DirectInput>;
        deliveryOrder: QueryOperation<DeliveryOrder>;
        inputAdjustment: QueryOperation<AdjustmentMovement>;
        outputAdjustment: QueryOperation<AdjustmentMovement>;
        inputMovement: QueryOperation<ReceiptMovement>;
        outputMovement: QueryOperation<OutputMovement>;
        transfer: QueryOperation<TransferMovement>;
        transferMovement: QueryOperation<TransferMovement>;
        stockObject: QueryOperation<StockObject>;
        serialGroup: QueryOperation<SerialGroup>;
        serialParentGroup: QueryOperation<SerialGroup>;
    }
    export interface SerialNumber$Operations {
        query: QueryOperation<SerialNumber>;
        read: ReadOperation<SerialNumber>;
        aggregate: {
            read: AggregateReadOperation<SerialNumber>;
            query: AggregateQueryOperation<SerialNumber>;
        };
        lookups(dataOrId: string | { data: SerialNumberInput }): SerialNumber$Lookups;
        getDefaults: GetDefaultsOperation<SerialNumber>;
    }
    export interface SerialTraceability extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        product: string;
        serialNumber: string;
        double: integer;
        occurrence: integer;
        code: string;
        operationType: SerialAction;
        directInputNumber: string;
        directInputLineNumber: integer;
        receiptDate: string;
        deliveryOrderNumber: string;
        deliveryOrderLineNumber: integer;
        outputDate: string;
        inputAdjustmentNumber: string;
        outputAdjustmentNumber: string;
        inputMovementNumber: string;
        outputMovementNumber: string;
        replenishmentNumber: string;
        transferMovementNumber: string;
        stockObjectNumber: string;
        originStockObject: string;
        serialGroup: string;
        parentGroup: string;
        replenishmentDate: string;
        free1: string;
        free2: string;
        free3: string;
        free4: string;
        free5: string;
    }
    export interface SerialTraceabilityInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        product?: string;
        serialNumber?: string;
        double?: integer | string;
        occurrence?: integer | string;
        code?: string;
        operationType?: SerialAction;
        directInputNumber?: string;
        directInputLineNumber?: integer | string;
        receiptDate?: string;
        deliveryOrderNumber?: string;
        deliveryOrderLineNumber?: integer | string;
        outputDate?: string;
        inputAdjustmentNumber?: string;
        outputAdjustmentNumber?: string;
        inputMovementNumber?: string;
        outputMovementNumber?: string;
        replenishmentNumber?: string;
        transferMovementNumber?: string;
        stockObjectNumber?: string;
        originStockObject?: string;
        serialGroup?: string;
        parentGroup?: string;
        replenishmentDate?: string;
        free1?: string;
        free2?: string;
        free3?: string;
        free4?: string;
        free5?: string;
    }
    export interface SerialTraceabilityBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        product: string;
        serialNumber: string;
        double: integer;
        occurrence: integer;
        code: string;
        operationType: SerialAction;
        directInputNumber: string;
        directInputLineNumber: integer;
        receiptDate: string;
        deliveryOrderNumber: string;
        deliveryOrderLineNumber: integer;
        outputDate: string;
        inputAdjustmentNumber: string;
        outputAdjustmentNumber: string;
        inputMovementNumber: string;
        outputMovementNumber: string;
        replenishmentNumber: string;
        transferMovementNumber: string;
        stockObjectNumber: string;
        originStockObject: string;
        serialGroup: string;
        parentGroup: string;
        replenishmentDate: string;
        free1: string;
        free2: string;
        free3: string;
        free4: string;
        free5: string;
    }
    export interface SerialTraceability$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
    }
    export interface SerialTraceability$Operations {
        query: QueryOperation<SerialTraceability>;
        read: ReadOperation<SerialTraceability>;
        aggregate: {
            read: AggregateReadOperation<SerialTraceability>;
            query: AggregateQueryOperation<SerialTraceability>;
        };
        lookups(dataOrId: string | { data: SerialTraceabilityInput }): SerialTraceability$Lookups;
        getDefaults: GetDefaultsOperation<SerialTraceability>;
    }
    export interface ShippingUnitCompanyNames extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        companyName: string;
    }
    export interface ShippingUnitCompanyNamesInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        code?: string;
        companyName?: string;
    }
    export interface ShippingUnitCompanyNamesBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        code: string;
        companyName: string;
    }
    export interface ShippingUnitCompanyNames$Operations {
        query: QueryOperation<ShippingUnitCompanyNames>;
        read: ReadOperation<ShippingUnitCompanyNames>;
        aggregate: {
            read: AggregateReadOperation<ShippingUnitCompanyNames>;
            query: AggregateQueryOperation<ShippingUnitCompanyNames>;
        };
        getDefaults: GetDefaultsOperation<ShippingUnitCompanyNames>;
    }
    export interface ShippingUnit extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        status: ShippingUnitStatus;
        shippingUnitType: ShippingUnitType;
        deliveryOrder: DeliveryOrder;
        isShippingUnitSingleDeliveryOrder: boolean;
        isShippingUnitSingleCustomer: boolean;
        pickingOrder: PickingOrder;
        wave: Wave;
        preparationArea: PreparationArea;
        pickingMode: PickingMode;
        palletisationOrder: AutoPalletizationOrder;
        shipTo: Customer;
        postalCode: string;
        isPostponed: boolean;
        height: string;
        width: string;
        depth: string;
        volume: string;
        weight: string;
        estimatedWeight: string;
        numberOfParcels: integer;
        parcel: Parcel;
        ssccShippingUnitCode: string;
        dockStore: Store;
        dockAddress: Location;
        originDockStore: Store;
        originDockAddress: Location;
        stockOnDockStatus: Colis;
        isStockOnDockControl: boolean;
        isWrappedShippingUnit: boolean;
        creationType: SuCreationType;
        subWaveNumber: integer;
        isDispatchableInState: boolean;
        parcels: ClientCollection<Parcel>;
        companyNames: ClientCollection<ShippingUnitCompanyNames>;
    }
    export interface ShippingUnitInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        status?: ShippingUnitStatus;
        shippingUnitType?: string;
        deliveryOrder?: string;
        isShippingUnitSingleDeliveryOrder?: boolean | string;
        isShippingUnitSingleCustomer?: boolean | string;
        pickingOrder?: string;
        wave?: string;
        preparationArea?: string;
        pickingMode?: string;
        palletisationOrder?: string;
        shipTo?: string;
        postalCode?: string;
        isPostponed?: boolean | string;
        height?: decimal | string;
        width?: decimal | string;
        depth?: decimal | string;
        volume?: decimal | string;
        weight?: decimal | string;
        estimatedWeight?: decimal | string;
        numberOfParcels?: integer | string;
        parcel?: string;
        ssccShippingUnitCode?: string;
        dockStore?: string;
        dockAddress?: string;
        originDockStore?: string;
        originDockAddress?: string;
        stockOnDockStatus?: Colis;
        isStockOnDockControl?: boolean | string;
        isWrappedShippingUnit?: boolean | string;
        creationType?: SuCreationType;
        subWaveNumber?: integer | string;
        isDispatchableInState?: boolean | string;
        parcels?: Partial<ParcelInput>[];
        companyNames?: Partial<ShippingUnitCompanyNamesInput>[];
    }
    export interface ShippingUnitBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        status: ShippingUnitStatus;
        shippingUnitType: ShippingUnitType;
        deliveryOrder: DeliveryOrder;
        isShippingUnitSingleDeliveryOrder: boolean;
        isShippingUnitSingleCustomer: boolean;
        pickingOrder: PickingOrder;
        wave: Wave;
        preparationArea: PreparationArea;
        pickingMode: PickingMode;
        palletisationOrder: AutoPalletizationOrder;
        shipTo: Customer;
        postalCode: string;
        isPostponed: boolean;
        height: string;
        width: string;
        depth: string;
        volume: string;
        weight: string;
        estimatedWeight: string;
        numberOfParcels: integer;
        parcel: Parcel;
        ssccShippingUnitCode: string;
        dockStore: Store;
        dockAddress: Location;
        originDockStore: Store;
        originDockAddress: Location;
        stockOnDockStatus: Colis;
        isStockOnDockControl: boolean;
        isWrappedShippingUnit: boolean;
        creationType: SuCreationType;
        subWaveNumber: integer;
        isDispatchableInState: boolean;
        parcels: ClientCollection<Parcel>;
        companyNames: ClientCollection<ShippingUnitCompanyNamesBinding>;
    }
    export interface ShippingUnit$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        shippingUnitType: QueryOperation<ShippingUnitType>;
        deliveryOrder: QueryOperation<DeliveryOrder>;
        pickingOrder: QueryOperation<PickingOrder>;
        wave: QueryOperation<Wave>;
        preparationArea: QueryOperation<PreparationArea>;
        pickingMode: QueryOperation<PickingMode>;
        palletisationOrder: QueryOperation<AutoPalletizationOrder>;
        shipTo: QueryOperation<Customer>;
        parcel: QueryOperation<Parcel>;
        dockStore: QueryOperation<Store>;
        dockAddress: QueryOperation<Location>;
        originDockStore: QueryOperation<Store>;
        originDockAddress: QueryOperation<Location>;
    }
    export interface ShippingUnit$Operations {
        query: QueryOperation<ShippingUnit>;
        read: ReadOperation<ShippingUnit>;
        aggregate: {
            read: AggregateReadOperation<ShippingUnit>;
            query: AggregateQueryOperation<ShippingUnit>;
        };
        lookups(dataOrId: string | { data: ShippingUnitInput }): ShippingUnit$Lookups;
        getDefaults: GetDefaultsOperation<ShippingUnit>;
    }
    export interface StockCountCampaign extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        reference: string;
        startDate: string;
        endDate: string;
        status: InventoryStatus;
        closingDate: string;
        numberOfStockCountsInProgress: integer;
        numberOfStockCountsClosed: integer;
    }
    export interface StockCountCampaignInput extends ClientNodeInput {
        site?: string;
        code?: string;
        reference?: string;
        startDate?: string;
        endDate?: string;
        status?: InventoryStatus;
        closingDate?: string;
        numberOfStockCountsInProgress?: integer | string;
        numberOfStockCountsClosed?: integer | string;
    }
    export interface StockCountCampaignBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        reference: string;
        startDate: string;
        endDate: string;
        status: InventoryStatus;
        closingDate: string;
        numberOfStockCountsInProgress: integer;
        numberOfStockCountsClosed: integer;
    }
    export interface StockCountCampaign$Lookups {
        site: QueryOperation<Site>;
    }
    export interface StockCountCampaign$Operations {
        query: QueryOperation<StockCountCampaign>;
        read: ReadOperation<StockCountCampaign>;
        aggregate: {
            read: AggregateReadOperation<StockCountCampaign>;
            query: AggregateQueryOperation<StockCountCampaign>;
        };
        lookups(dataOrId: string | { data: StockCountCampaignInput }): StockCountCampaign$Lookups;
        getDefaults: GetDefaultsOperation<StockCountCampaign>;
    }
    export interface StockCountLinesByLocation extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        stockCount: StockCount;
        selection: integer;
        store: Store;
        location: Location;
        status: InventoryLineType;
        numberOfProducts: integer;
    }
    export interface StockCountLinesByLocationInput extends ClientNodeInput {
        site?: string;
        stockCount?: string;
        selection?: integer | string;
        store?: string;
        location?: string;
        status?: InventoryLineType;
        numberOfProducts?: integer | string;
    }
    export interface StockCountLinesByLocationBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        stockCount: StockCount;
        selection: integer;
        store: Store;
        location: Location;
        status: InventoryLineType;
        numberOfProducts: integer;
    }
    export interface StockCountLinesByLocation$Lookups {
        site: QueryOperation<Site>;
        stockCount: QueryOperation<StockCount>;
        store: QueryOperation<Store>;
        location: QueryOperation<Location>;
    }
    export interface StockCountLinesByLocation$Operations {
        query: QueryOperation<StockCountLinesByLocation>;
        read: ReadOperation<StockCountLinesByLocation>;
        aggregate: {
            read: AggregateReadOperation<StockCountLinesByLocation>;
            query: AggregateQueryOperation<StockCountLinesByLocation>;
        };
        lookups(dataOrId: string | { data: StockCountLinesByLocationInput }): StockCountLinesByLocation$Lookups;
        getDefaults: GetDefaultsOperation<StockCountLinesByLocation>;
    }
    export interface StockCountLinesByProduct extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        stockCount: StockCount;
        selection: integer;
        depositor: Depositor;
        product: Product;
        status: InventoryLineType;
        numberOfLocations: integer;
    }
    export interface StockCountLinesByProductInput extends ClientNodeInput {
        site?: string;
        stockCount?: string;
        selection?: integer | string;
        depositor?: string;
        product?: string;
        status?: InventoryLineType;
        numberOfLocations?: integer | string;
    }
    export interface StockCountLinesByProductBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        stockCount: StockCount;
        selection: integer;
        depositor: Depositor;
        product: Product;
        status: InventoryLineType;
        numberOfLocations: integer;
    }
    export interface StockCountLinesByProduct$Lookups {
        site: QueryOperation<Site>;
        stockCount: QueryOperation<StockCount>;
        depositor: QueryOperation<Depositor>;
        product: QueryOperation<Product>;
    }
    export interface StockCountLinesByProduct$Operations {
        query: QueryOperation<StockCountLinesByProduct>;
        read: ReadOperation<StockCountLinesByProduct>;
        aggregate: {
            read: AggregateReadOperation<StockCountLinesByProduct>;
            query: AggregateQueryOperation<StockCountLinesByProduct>;
        };
        lookups(dataOrId: string | { data: StockCountLinesByProductInput }): StockCountLinesByProduct$Lookups;
        getDefaults: GetDefaultsOperation<StockCountLinesByProduct>;
    }
    export interface StockCount extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        reference: string;
        status: InventoryStatus;
        isCreatedByOneCampaign: boolean;
        stockCountCampaign: StockCountCampaign;
        closingDate: string;
        stockCountType: InventoryType;
        isKeyInSerialNumber: boolean;
        isPendingStockCount: boolean;
        maximumContainerLevel: ContainerLevel;
        comments: string;
        logFileNumber: string;
        numberOfCounting: integer;
        stockCountCreationOrigin: StockCountCreationOrigin;
    }
    export interface StockCountInput extends ClientNodeInput {
        site?: string;
        code?: string;
        reference?: string;
        status?: InventoryStatus;
        isCreatedByOneCampaign?: boolean | string;
        stockCountCampaign?: string;
        closingDate?: string;
        stockCountType?: InventoryType;
        isKeyInSerialNumber?: boolean | string;
        isPendingStockCount?: boolean | string;
        maximumContainerLevel?: ContainerLevel;
        comments?: string;
        logFileNumber?: string;
        numberOfCounting?: integer | string;
        stockCountCreationOrigin?: StockCountCreationOrigin;
    }
    export interface StockCountBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        reference: string;
        status: InventoryStatus;
        isCreatedByOneCampaign: boolean;
        stockCountCampaign: StockCountCampaign;
        closingDate: string;
        stockCountType: InventoryType;
        isKeyInSerialNumber: boolean;
        isPendingStockCount: boolean;
        maximumContainerLevel: ContainerLevel;
        comments: string;
        logFileNumber: string;
        numberOfCounting: integer;
        stockCountCreationOrigin: StockCountCreationOrigin;
    }
    export interface StockCount$Lookups {
        site: QueryOperation<Site>;
        stockCountCampaign: QueryOperation<StockCountCampaign>;
    }
    export interface StockCount$Operations {
        query: QueryOperation<StockCount>;
        read: ReadOperation<StockCount>;
        aggregate: {
            read: AggregateReadOperation<StockCount>;
            query: AggregateQueryOperation<StockCount>;
        };
        lookups(dataOrId: string | { data: StockCountInput }): StockCount$Lookups;
        getDefaults: GetDefaultsOperation<StockCount>;
    }
    export interface StockObjectContainerLevels extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        code: string;
        containerLevel: ProductsContainer;
        quantityOfConsumptionUnitPerLevel: string;
    }
    export interface StockObjectContainerLevelsInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        code?: string;
        containerLevel?: string;
        quantityOfConsumptionUnitPerLevel?: decimal | string;
    }
    export interface StockObjectContainerLevelsBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        code: string;
        containerLevel: ProductsContainer;
        quantityOfConsumptionUnitPerLevel: string;
    }
    export interface StockObjectContainerLevels$Lookups {
        containerLevel: QueryOperation<ProductsContainer>;
    }
    export interface StockObjectContainerLevels$Operations {
        query: QueryOperation<StockObjectContainerLevels>;
        read: ReadOperation<StockObjectContainerLevels>;
        aggregate: {
            read: AggregateReadOperation<StockObjectContainerLevels>;
            query: AggregateQueryOperation<StockObjectContainerLevels>;
        };
        lookups(dataOrId: string | { data: StockObjectContainerLevelsInput }): StockObjectContainerLevels$Lookups;
        getDefaults: GetDefaultsOperation<StockObjectContainerLevels>;
    }
    export interface StockObject extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        depositor: Depositor;
        product: Product;
        store: Store;
        location: Location;
        storeType: StoreType;
        locationType: LocationType;
        containerNumber: string;
        directInput: DirectInput;
        adjustment: AdjustmentMovement;
        lotNumber: string;
        supportNumber: string;
        container: ProductsContainer;
        containerCoefficient: string;
        numberOfConsumptionUnit: string;
        numberOfContainer: string;
        numberOfConsumptionUnitInPendingInput: string;
        numberOfConsumptionUnitInPendingOutput: string;
        stockStatus: StockNature;
        reservationNumber: string;
        source: Origin;
        stockObjectLinkNumber: string;
        fifoDate: string;
        receiptDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        useByDate: string;
        shipByDate: string;
        unStockingAllocationSequence: integer;
        storingDate: string;
        storingTime: integer;
        homogeneousContainer: ProductsContainer;
        homogeneousContainerCoefficient: string;
        homogeneousQuantity: string;
        quantityInContainerCorrespondence: string;
        serialNumbers: ClientCollection<SerialNumber>;
        containerLevels: ClientCollection<StockObjectContainerLevels>;
    }
    export interface StockObjectInput extends ClientNodeInput {
        site?: string;
        code?: string;
        depositor?: string;
        product?: string;
        store?: string;
        location?: string;
        storeType?: StoreType;
        locationType?: LocationType;
        containerNumber?: string;
        directInput?: string;
        adjustment?: string;
        lotNumber?: string;
        supportNumber?: string;
        container?: string;
        containerCoefficient?: decimal | string;
        numberOfConsumptionUnit?: decimal | string;
        numberOfContainer?: decimal | string;
        numberOfConsumptionUnitInPendingInput?: decimal | string;
        numberOfConsumptionUnitInPendingOutput?: decimal | string;
        stockStatus?: string;
        reservationNumber?: string;
        source?: string;
        stockObjectLinkNumber?: string;
        fifoDate?: string;
        receiptDate?: string;
        manufacturedDate?: string;
        detentionDate?: string;
        sellByDate?: string;
        useByDate?: string;
        shipByDate?: string;
        unStockingAllocationSequence?: integer | string;
        storingDate?: string;
        storingTime?: integer | string;
        homogeneousContainer?: string;
        homogeneousContainerCoefficient?: decimal | string;
        homogeneousQuantity?: decimal | string;
        quantityInContainerCorrespondence?: decimal | string;
        serialNumbers?: Partial<SerialNumberInput>[];
        containerLevels?: Partial<StockObjectContainerLevelsInput>[];
    }
    export interface StockObjectBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        code: string;
        depositor: Depositor;
        product: Product;
        store: Store;
        location: Location;
        storeType: StoreType;
        locationType: LocationType;
        containerNumber: string;
        directInput: DirectInput;
        adjustment: AdjustmentMovement;
        lotNumber: string;
        supportNumber: string;
        container: ProductsContainer;
        containerCoefficient: string;
        numberOfConsumptionUnit: string;
        numberOfContainer: string;
        numberOfConsumptionUnitInPendingInput: string;
        numberOfConsumptionUnitInPendingOutput: string;
        stockStatus: StockNature;
        reservationNumber: string;
        source: Origin;
        stockObjectLinkNumber: string;
        fifoDate: string;
        receiptDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        useByDate: string;
        shipByDate: string;
        unStockingAllocationSequence: integer;
        storingDate: string;
        storingTime: integer;
        homogeneousContainer: ProductsContainer;
        homogeneousContainerCoefficient: string;
        homogeneousQuantity: string;
        quantityInContainerCorrespondence: string;
        serialNumbers: ClientCollection<SerialNumber>;
        containerLevels: ClientCollection<StockObjectContainerLevelsBinding>;
    }
    export interface StockObject$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        product: QueryOperation<Product>;
        store: QueryOperation<Store>;
        location: QueryOperation<Location>;
        directInput: QueryOperation<DirectInput>;
        adjustment: QueryOperation<AdjustmentMovement>;
        container: QueryOperation<ProductsContainer>;
        stockStatus: QueryOperation<StockNature>;
        source: QueryOperation<Origin>;
        homogeneousContainer: QueryOperation<ProductsContainer>;
    }
    export interface StockObject$Operations {
        query: QueryOperation<StockObject>;
        read: ReadOperation<StockObject>;
        aggregate: {
            read: AggregateReadOperation<StockObject>;
            query: AggregateQueryOperation<StockObject>;
        };
        lookups(dataOrId: string | { data: StockObjectInput }): StockObject$Lookups;
        getDefaults: GetDefaultsOperation<StockObject>;
    }
    export interface StoringList extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        status: StoringListPurchaseOrderStatus;
        date: string;
        store: Store;
        directInput: DirectInput;
        identifier: string;
        order: PrintingSequence;
        validationType: ValidationType;
        validatingOperator: Operand;
        validatingUser: string;
        postingDate: string;
        receiptMovements: ClientCollection<ReceiptMovement>;
    }
    export interface StoringListInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        status?: StoringListPurchaseOrderStatus;
        date?: string;
        store?: string;
        directInput?: string;
        identifier?: string;
        order?: PrintingSequence;
        validationType?: ValidationType;
        validatingOperator?: string;
        validatingUser?: string;
        postingDate?: string;
        receiptMovements?: Partial<ReceiptMovementInput>[];
    }
    export interface StoringListBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        status: StoringListPurchaseOrderStatus;
        date: string;
        store: Store;
        directInput: DirectInput;
        identifier: string;
        order: PrintingSequence;
        validationType: ValidationType;
        validatingOperator: Operand;
        validatingUser: string;
        postingDate: string;
        receiptMovements: ClientCollection<ReceiptMovement>;
    }
    export interface StoringList$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        store: QueryOperation<Store>;
        directInput: QueryOperation<DirectInput>;
        validatingOperator: QueryOperation<Operand>;
    }
    export interface StoringList$Operations {
        query: QueryOperation<StoringList>;
        read: ReadOperation<StoringList>;
        aggregate: {
            read: AggregateReadOperation<StoringList>;
            query: AggregateQueryOperation<StoringList>;
        };
        lookups(dataOrId: string | { data: StoringListInput }): StoringList$Lookups;
        getDefaults: GetDefaultsOperation<StoringList>;
    }
    export interface TransferMovementContainerLevels extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        transferNumber: string;
        code: string;
        containerLevel: ProductsContainer;
        quantityOfConsumptionUnitPerLevel: string;
    }
    export interface TransferMovementContainerLevelsInput extends VitalClientNodeInput {
        denormalizedIndex?: integer | string;
        site?: string;
        depositor?: string;
        transferNumber?: string;
        code?: string;
        containerLevel?: string;
        quantityOfConsumptionUnitPerLevel?: decimal | string;
    }
    export interface TransferMovementContainerLevelsBinding extends VitalClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        denormalizedIndex: integer;
        site: string;
        depositor: string;
        transferNumber: string;
        code: string;
        containerLevel: ProductsContainer;
        quantityOfConsumptionUnitPerLevel: string;
    }
    export interface TransferMovementContainerLevels$Lookups {
        containerLevel: QueryOperation<ProductsContainer>;
    }
    export interface TransferMovementContainerLevels$Operations {
        query: QueryOperation<TransferMovementContainerLevels>;
        read: ReadOperation<TransferMovementContainerLevels>;
        aggregate: {
            read: AggregateReadOperation<TransferMovementContainerLevels>;
            query: AggregateQueryOperation<TransferMovementContainerLevels>;
        };
        lookups(
            dataOrId: string | { data: TransferMovementContainerLevelsInput },
        ): TransferMovementContainerLevels$Lookups;
        getDefaults: GetDefaultsOperation<TransferMovementContainerLevels>;
    }
    export interface TransferMovement extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        transferNumber: string;
        code: string;
        movementCode: MovementCode;
        wave: Wave;
        assemblingWave: AssemblingWave;
        subWaveNumber: integer;
        adjustment: AdjustmentMovement;
        store: Store;
        location: Location;
        stockObject: StockObject;
        containerNumber: string;
        originStore: Store;
        originAddress: Location;
        locationType: LocationType;
        sourceProduct: Product;
        originStockObject: StockObject;
        originContainer: ProductsContainer;
        originQuantity: string;
        originSource: Origin;
        numberOfContainer: string;
        container: ProductsContainer;
        numberOfConsumptionUnit: string;
        level: ContainerLevel;
        status: ReplenishmentMovementType;
        movementType: MovementType;
        masterStockObject: StockObject;
        masterContainerNumber: string;
        masterProduct: Product;
        date: string;
        time: string;
        homogeneousQuantity: string;
        homogeneousContainer: ProductsContainer;
        homogeneousContainerCoefficient: string;
        receiptDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        shipByDate: string;
        useByDate: string;
        fifoDate: string;
        lotNumber: string;
        supportNumber: string;
        reservationNumber: string;
        stockStatus: StockNature;
        sortPreparationOrder: string;
        rowLevel: string;
        travelSequence: string;
        transferObject: StockObject;
        transferStore: Store;
        transferAddress: Location;
        position: integer;
        validatingOperator: Operand;
        validatingUser: string;
        postingDate: string;
        postingTime: integer;
        flowNumber: integer;
        pickingOperator: Operand;
        pickingUser: string;
        pickingDate: string;
        pickingTime: integer;
        groupingCode: string;
        depositObject: StockObject;
        depositStore: Store;
        depositLocation: Location;
        containerLevels: ClientCollection<TransferMovementContainerLevels>;
    }
    export interface TransferMovementInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        transferNumber?: string;
        code?: string;
        movementCode?: string;
        wave?: string;
        assemblingWave?: string;
        subWaveNumber?: integer | string;
        adjustment?: string;
        store?: string;
        location?: string;
        stockObject?: string;
        containerNumber?: string;
        originStore?: string;
        originAddress?: string;
        locationType?: LocationType;
        sourceProduct?: string;
        originStockObject?: string;
        originContainer?: string;
        originQuantity?: decimal | string;
        originSource?: string;
        numberOfContainer?: decimal | string;
        container?: string;
        numberOfConsumptionUnit?: decimal | string;
        level?: ContainerLevel;
        status?: ReplenishmentMovementType;
        movementType?: MovementType;
        masterStockObject?: string;
        masterContainerNumber?: string;
        masterProduct?: string;
        date?: string;
        time?: string;
        homogeneousQuantity?: decimal | string;
        homogeneousContainer?: string;
        homogeneousContainerCoefficient?: decimal | string;
        receiptDate?: string;
        manufacturedDate?: string;
        detentionDate?: string;
        sellByDate?: string;
        shipByDate?: string;
        useByDate?: string;
        fifoDate?: string;
        lotNumber?: string;
        supportNumber?: string;
        reservationNumber?: string;
        stockStatus?: string;
        sortPreparationOrder?: string;
        rowLevel?: string;
        travelSequence?: string;
        transferObject?: string;
        transferStore?: string;
        transferAddress?: string;
        position?: integer | string;
        validatingOperator?: string;
        validatingUser?: string;
        postingDate?: string;
        postingTime?: integer | string;
        flowNumber?: integer | string;
        pickingOperator?: string;
        pickingUser?: string;
        pickingDate?: string;
        pickingTime?: integer | string;
        groupingCode?: string;
        depositObject?: string;
        depositStore?: string;
        depositLocation?: string;
        containerLevels?: Partial<TransferMovementContainerLevelsInput>[];
    }
    export interface TransferMovementBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        transferNumber: string;
        code: string;
        movementCode: MovementCode;
        wave: Wave;
        assemblingWave: AssemblingWave;
        subWaveNumber: integer;
        adjustment: AdjustmentMovement;
        store: Store;
        location: Location;
        stockObject: StockObject;
        containerNumber: string;
        originStore: Store;
        originAddress: Location;
        locationType: LocationType;
        sourceProduct: Product;
        originStockObject: StockObject;
        originContainer: ProductsContainer;
        originQuantity: string;
        originSource: Origin;
        numberOfContainer: string;
        container: ProductsContainer;
        numberOfConsumptionUnit: string;
        level: ContainerLevel;
        status: ReplenishmentMovementType;
        movementType: MovementType;
        masterStockObject: StockObject;
        masterContainerNumber: string;
        masterProduct: Product;
        date: string;
        time: string;
        homogeneousQuantity: string;
        homogeneousContainer: ProductsContainer;
        homogeneousContainerCoefficient: string;
        receiptDate: string;
        manufacturedDate: string;
        detentionDate: string;
        sellByDate: string;
        shipByDate: string;
        useByDate: string;
        fifoDate: string;
        lotNumber: string;
        supportNumber: string;
        reservationNumber: string;
        stockStatus: StockNature;
        sortPreparationOrder: string;
        rowLevel: string;
        travelSequence: string;
        transferObject: StockObject;
        transferStore: Store;
        transferAddress: Location;
        position: integer;
        validatingOperator: Operand;
        validatingUser: string;
        postingDate: string;
        postingTime: integer;
        flowNumber: integer;
        pickingOperator: Operand;
        pickingUser: string;
        pickingDate: string;
        pickingTime: integer;
        groupingCode: string;
        depositObject: StockObject;
        depositStore: Store;
        depositLocation: Location;
        containerLevels: ClientCollection<TransferMovementContainerLevelsBinding>;
    }
    export interface TransferMovement$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        movementCode: QueryOperation<MovementCode>;
        wave: QueryOperation<Wave>;
        assemblingWave: QueryOperation<AssemblingWave>;
        adjustment: QueryOperation<AdjustmentMovement>;
        store: QueryOperation<Store>;
        location: QueryOperation<Location>;
        stockObject: QueryOperation<StockObject>;
        originStore: QueryOperation<Store>;
        originAddress: QueryOperation<Location>;
        sourceProduct: QueryOperation<Product>;
        originStockObject: QueryOperation<StockObject>;
        originContainer: QueryOperation<ProductsContainer>;
        originSource: QueryOperation<Origin>;
        container: QueryOperation<ProductsContainer>;
        masterStockObject: QueryOperation<StockObject>;
        masterProduct: QueryOperation<Product>;
        homogeneousContainer: QueryOperation<ProductsContainer>;
        stockStatus: QueryOperation<StockNature>;
        transferObject: QueryOperation<StockObject>;
        transferStore: QueryOperation<Store>;
        transferAddress: QueryOperation<Location>;
        validatingOperator: QueryOperation<Operand>;
        pickingOperator: QueryOperation<Operand>;
        depositObject: QueryOperation<StockObject>;
        depositStore: QueryOperation<Store>;
        depositLocation: QueryOperation<Location>;
    }
    export interface TransferMovement$Operations {
        query: QueryOperation<TransferMovement>;
        read: ReadOperation<TransferMovement>;
        aggregate: {
            read: AggregateReadOperation<TransferMovement>;
            query: AggregateQueryOperation<TransferMovement>;
        };
        lookups(dataOrId: string | { data: TransferMovementInput }): TransferMovement$Lookups;
        getDefaults: GetDefaultsOperation<TransferMovement>;
    }
    export interface Wave extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        waveType: WaveType;
        launchDate: string;
        launchTime: string;
        numberOfDeliveryOrders: integer;
        numberOfDeliveryOrdersLines: integer;
        numberOfReserveMovements: integer;
        numberOfPickingMovements: integer;
        numberOfCrossDockingMovements: integer;
        numberOfIncompletesLines: integer;
        numberOfReplenishmentMovements: integer;
        numberOfParcelInState: integer;
        numberOfParcelinBulk: integer;
        numberOfShippingUnitInstate: integer;
        numberOfShippingUnitinBulk: integer;
        numberOfPickingOrderForReserve: integer;
        numberOfPickingOrderForPicking: integer;
        numberOfPickingOrderForMixed: integer;
        numberOfTransferOrder: integer;
        status: WaveStatus;
        volume: string;
        weight: string;
        numberOfTransferMovements: integer;
        carrier: Carrier;
        transportationMethod: TransportMode;
        round: Round;
        genericWave: GenericWave;
        workCenter: WorkCenter;
        unit: UnitOfMeasure;
        estimatedLoad: string;
        isAutoLaunch: boolean;
        isMissionToBlock: boolean;
        missionPriority: integer;
        transactionInProgress: string;
    }
    export interface WaveInput extends ClientNodeInput {
        site?: string;
        depositor?: string;
        code?: string;
        waveType?: WaveType;
        launchDate?: string;
        launchTime?: string;
        numberOfDeliveryOrders?: integer | string;
        numberOfDeliveryOrdersLines?: integer | string;
        numberOfReserveMovements?: integer | string;
        numberOfPickingMovements?: integer | string;
        numberOfCrossDockingMovements?: integer | string;
        numberOfIncompletesLines?: integer | string;
        numberOfReplenishmentMovements?: integer | string;
        numberOfParcelInState?: integer | string;
        numberOfParcelinBulk?: integer | string;
        numberOfShippingUnitInstate?: integer | string;
        numberOfShippingUnitinBulk?: integer | string;
        numberOfPickingOrderForReserve?: integer | string;
        numberOfPickingOrderForPicking?: integer | string;
        numberOfPickingOrderForMixed?: integer | string;
        numberOfTransferOrder?: integer | string;
        status?: WaveStatus;
        volume?: decimal | string;
        weight?: decimal | string;
        numberOfTransferMovements?: integer | string;
        carrier?: string;
        transportationMethod?: string;
        round?: string;
        genericWave?: string;
        workCenter?: string;
        unit?: string;
        estimatedLoad?: decimal | string;
        isAutoLaunch?: boolean | string;
        isMissionToBlock?: boolean | string;
        missionPriority?: integer | string;
        transactionInProgress?: string;
    }
    export interface WaveBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        waveType: WaveType;
        launchDate: string;
        launchTime: string;
        numberOfDeliveryOrders: integer;
        numberOfDeliveryOrdersLines: integer;
        numberOfReserveMovements: integer;
        numberOfPickingMovements: integer;
        numberOfCrossDockingMovements: integer;
        numberOfIncompletesLines: integer;
        numberOfReplenishmentMovements: integer;
        numberOfParcelInState: integer;
        numberOfParcelinBulk: integer;
        numberOfShippingUnitInstate: integer;
        numberOfShippingUnitinBulk: integer;
        numberOfPickingOrderForReserve: integer;
        numberOfPickingOrderForPicking: integer;
        numberOfPickingOrderForMixed: integer;
        numberOfTransferOrder: integer;
        status: WaveStatus;
        volume: string;
        weight: string;
        numberOfTransferMovements: integer;
        carrier: Carrier;
        transportationMethod: TransportMode;
        round: Round;
        genericWave: GenericWave;
        workCenter: WorkCenter;
        unit: UnitOfMeasure;
        estimatedLoad: string;
        isAutoLaunch: boolean;
        isMissionToBlock: boolean;
        missionPriority: integer;
        transactionInProgress: string;
    }
    export interface Wave$Lookups {
        site: QueryOperation<Site>;
        depositor: QueryOperation<Depositor>;
        carrier: QueryOperation<Carrier>;
        transportationMethod: QueryOperation<TransportMode>;
        round: QueryOperation<Round>;
        genericWave: QueryOperation<GenericWave>;
        workCenter: QueryOperation<WorkCenter>;
        unit: QueryOperation<UnitOfMeasure>;
    }
    export interface Wave$Operations {
        query: QueryOperation<Wave>;
        read: ReadOperation<Wave>;
        aggregate: {
            read: AggregateReadOperation<Wave>;
            query: AggregateQueryOperation<Wave>;
        };
        lookups(dataOrId: string | { data: WaveInput }): Wave$Lookups;
        getDefaults: GetDefaultsOperation<Wave>;
    }
    export interface LocationExtension {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        store: Store;
        code: string;
        storageType: string;
        storage: StorageType;
        storeType: StoreType;
        locationType: LocationType;
        dockType: DockType;
        depositor: Depositor;
        lotNumber: string;
        reservationNumber: string;
        stockStatus: StockNature;
        numberOfConsumptionUnitPerContainer: string;
        rotationClass: RotationClass;
        assignmentClass: AssignmentClass;
        prohibitedClass: AssignmentClass;
        height: string;
        width: string;
        depth: string;
        volume: string;
        maxVolume: string;
        maxWeightAuthorized: string;
        maxMeters: string;
        maximumLoad: string;
        dockHeight: string;
        storingTime: string;
        unStockingTime: string;
        presentContainerMaximumQuantity: string;
        referenceContainerLevel: integer;
        maximumQuantityInReferenceContainer: string;
        quantityInStock: string;
        lastStockCount: string;
        lastReceipt: string;
        firstArrival: string;
        fifoDate: string;
        quantityInPendingInput: string;
        quantityInPendingOutput: string;
        quantityInPendingReplenish: string;
        isBlockedInInput: boolean;
        isBlockedInOutput: boolean;
        isBlockedInInput2: boolean;
        isBlockedInOutput2: boolean;
        isAutoAddressing: boolean;
        isKeyInControlCode: boolean;
        controlCode: string;
        reorderPoint: string;
        replenishmentType: LocationType;
        replenishmentLevel: ContainerLevel;
        percentageOccupied: integer;
        parity: Parity;
        isTemporaryPicking: boolean;
        isPickingPivot: boolean;
        wavePivot: string;
        pickingPriority: integer;
        isUsed: boolean;
        controlDimension: ControlOfDimensions;
        isActive: boolean;
        isDockLeveler: boolean;
        completeObjectsAddressingThreshold: string;
        storeLocationCode: string;
        storeLocationKey: string;
        splitAddresses: ClientCollection<LocationSplitAddresses>;
        product: Product;
        container: Container;
        source: Origin;
        referenceContainer: Container;
        presentContainer: Container;
        superiorContainer: ProductsContainer;
        stockCount: StockCount;
        deliveryOrderPivot: DeliveryOrder;
    }
    export interface LocationInputExtension {
        site?: string;
        store?: string;
        code?: string;
        storageType?: string;
        storage?: string;
        storeType?: StoreType;
        locationType?: LocationType;
        dockType?: DockType;
        depositor?: string;
        lotNumber?: string;
        reservationNumber?: string;
        stockStatus?: string;
        numberOfConsumptionUnitPerContainer?: decimal | string;
        rotationClass?: string;
        assignmentClass?: string;
        prohibitedClass?: string;
        height?: decimal | string;
        width?: decimal | string;
        depth?: decimal | string;
        volume?: decimal | string;
        maxVolume?: decimal | string;
        maxWeightAuthorized?: decimal | string;
        maxMeters?: decimal | string;
        maximumLoad?: decimal | string;
        dockHeight?: decimal | string;
        storingTime?: decimal | string;
        unStockingTime?: decimal | string;
        presentContainerMaximumQuantity?: decimal | string;
        referenceContainerLevel?: integer | string;
        maximumQuantityInReferenceContainer?: decimal | string;
        quantityInStock?: decimal | string;
        lastStockCount?: string;
        lastReceipt?: string;
        firstArrival?: string;
        fifoDate?: string;
        quantityInPendingInput?: decimal | string;
        quantityInPendingOutput?: decimal | string;
        quantityInPendingReplenish?: decimal | string;
        isBlockedInInput?: boolean | string;
        isBlockedInOutput?: boolean | string;
        isBlockedInInput2?: boolean | string;
        isBlockedInOutput2?: boolean | string;
        isAutoAddressing?: boolean | string;
        isKeyInControlCode?: boolean | string;
        controlCode?: string;
        reorderPoint?: decimal | string;
        replenishmentType?: LocationType;
        replenishmentLevel?: ContainerLevel;
        percentageOccupied?: integer | string;
        parity?: Parity;
        isTemporaryPicking?: boolean | string;
        isPickingPivot?: boolean | string;
        wavePivot?: string;
        pickingPriority?: integer | string;
        isUsed?: boolean | string;
        controlDimension?: ControlOfDimensions;
        isActive?: boolean | string;
        isDockLeveler?: boolean | string;
        completeObjectsAddressingThreshold?: decimal | string;
        splitAddresses?: Partial<LocationSplitAddressesInput>[];
        product?: string;
        container?: string;
        source?: string;
        referenceContainer?: string;
        presentContainer?: string;
        superiorContainer?: string;
        stockCount?: string;
        deliveryOrderPivot?: string;
    }
    export interface LocationBindingExtension {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        store: Store;
        code: string;
        storageType: string;
        storage: StorageType;
        storeType: StoreType;
        locationType: LocationType;
        dockType: DockType;
        depositor: Depositor;
        lotNumber: string;
        reservationNumber: string;
        stockStatus: StockNature;
        numberOfConsumptionUnitPerContainer: string;
        rotationClass: RotationClass;
        assignmentClass: AssignmentClass;
        prohibitedClass: AssignmentClass;
        height: string;
        width: string;
        depth: string;
        volume: string;
        maxVolume: string;
        maxWeightAuthorized: string;
        maxMeters: string;
        maximumLoad: string;
        dockHeight: string;
        storingTime: string;
        unStockingTime: string;
        presentContainerMaximumQuantity: string;
        referenceContainerLevel: integer;
        maximumQuantityInReferenceContainer: string;
        quantityInStock: string;
        lastStockCount: string;
        lastReceipt: string;
        firstArrival: string;
        fifoDate: string;
        quantityInPendingInput: string;
        quantityInPendingOutput: string;
        quantityInPendingReplenish: string;
        isBlockedInInput: boolean;
        isBlockedInOutput: boolean;
        isBlockedInInput2: boolean;
        isBlockedInOutput2: boolean;
        isAutoAddressing: boolean;
        isKeyInControlCode: boolean;
        controlCode: string;
        reorderPoint: string;
        replenishmentType: LocationType;
        replenishmentLevel: ContainerLevel;
        percentageOccupied: integer;
        parity: Parity;
        isTemporaryPicking: boolean;
        isPickingPivot: boolean;
        wavePivot: string;
        pickingPriority: integer;
        isUsed: boolean;
        controlDimension: ControlOfDimensions;
        isActive: boolean;
        isDockLeveler: boolean;
        completeObjectsAddressingThreshold: string;
        storeLocationCode: string;
        storeLocationKey: string;
        splitAddresses: ClientCollection<LocationSplitAddressesBinding>;
        product: Product;
        container: Container;
        source: Origin;
        referenceContainer: Container;
        presentContainer: Container;
        superiorContainer: ProductsContainer;
        stockCount: StockCount;
        deliveryOrderPivot: DeliveryOrder;
    }
    export interface LocationExtension$Lookups {
        stockCount: QueryOperation<StockCount>;
        deliveryOrderPivot: QueryOperation<DeliveryOrder>;
    }
    export interface LocationExtension$Operations {
        lookups(dataOrId: string | { data: LocationInput }): LocationExtension$Lookups;
    }
    export interface ProductExtension {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        otherCode: string;
        localizedDescription: string;
        localizedDescription2: string;
        localizedShortDescription: string;
        family: Family;
        subFamily: SubFamily;
        group: Group;
        subGroup: SubGroup;
        isKeyInSerialNumber: boolean;
        stockCountClass: StockCountClass;
        numberStockCount: integer;
        isBlockedInInput: boolean;
        isBlockedInOutput: boolean;
        isBlockedInInput2: boolean;
        isBlockedInOutput2: boolean;
        isKeyInLotNumber: boolean;
        isSingleLot: boolean;
        isCrossDocking: boolean;
        isHazardousMaterials: boolean;
        isKeyInControlCode: boolean;
        fifoDateNature: FifoDate;
        source: Origin;
        inputMode: InputMode;
        outputMode: OutputMode;
        autoTransferMode: MovementType;
        detentionLength: integer;
        detentionUnit: UnitLength;
        useByDateLength: integer;
        useByDateUnit: UnitLength;
        sendByDateLength: integer;
        sendByDateUnit: UnitLength;
        sellByDateLength: integer;
        sellByDateUnit: UnitLength;
        fifoTolerance: integer;
        fifoGapUnit: UnitLength;
        netWeight: string;
        netVolume: string;
        pureAlcoholVolume: string;
        price: string;
        material: Risk;
        minimumStock: string;
        alertStock: string;
        maximumStock: string;
        firstArrival: string;
        lastReceipt: string;
        lastOutput: string;
        lastStockCount: string;
        defaultContainer: ProductsContainer;
        defaultContainerLevel: ContainerLevel;
        transmittedFromL3: TransmissionL3;
        endOfLife: string;
        isQualityControlManagement: boolean;
        stockStatus: StockNature;
        isSingleLotControl: boolean;
        samplingType: SamplingType;
        generalLevelOfInspection: string;
        aql: string;
        freezingPoint: integer;
        freezingReversibility: ReversibleFreezing;
        ammNo: string;
        referredQuantity: string;
        referredUnit: UnitOfMeasure;
        icpeClass: IcpeClasses;
        flashPoint: integer;
        transportCategory: TransportCategory;
        hazardousMaterialClass: HazardousMaterialsClass;
        tunnelRestriction: string;
        classificationCode: string;
        packagingGroup: PackagingGroup;
        onuCodes: OnuCode;
        solventCode: string;
        technicalField: string;
        isActive: boolean;
        isStockUnitManagement: boolean;
        stockUnit: UnitOfMeasure;
        siteDepositorIdentifier: string;
        picture: BinaryStream;
        activeMatters: ClientCollection<ProductActiveMatters>;
        isPrintableDescriptions: ClientCollection<ProductIsPrintableDescriptions>;
        percentageActiveMatters: ClientCollection<ProductPercentageActiveMatters>;
        stockCount: StockCount;
        stockObjects: ClientCollection<StockObject>;
    }
    export interface ProductInputExtension {
        site?: string;
        depositor?: string;
        code?: string;
        otherCode?: string;
        localizedDescription?: string;
        localizedDescription2?: string;
        localizedShortDescription?: string;
        family?: string;
        subFamily?: string;
        group?: string;
        subGroup?: string;
        isKeyInSerialNumber?: boolean | string;
        stockCountClass?: string;
        numberStockCount?: integer | string;
        isBlockedInInput?: boolean | string;
        isBlockedInOutput?: boolean | string;
        isBlockedInInput2?: boolean | string;
        isBlockedInOutput2?: boolean | string;
        isKeyInLotNumber?: boolean | string;
        isSingleLot?: boolean | string;
        isCrossDocking?: boolean | string;
        isHazardousMaterials?: boolean | string;
        isKeyInControlCode?: boolean | string;
        fifoDateNature?: FifoDate;
        source?: string;
        inputMode?: string;
        outputMode?: string;
        autoTransferMode?: MovementType;
        detentionLength?: integer | string;
        detentionUnit?: UnitLength;
        useByDateLength?: integer | string;
        useByDateUnit?: UnitLength;
        sendByDateLength?: integer | string;
        sendByDateUnit?: UnitLength;
        sellByDateLength?: integer | string;
        sellByDateUnit?: UnitLength;
        fifoTolerance?: integer | string;
        fifoGapUnit?: UnitLength;
        netWeight?: decimal | string;
        netVolume?: decimal | string;
        pureAlcoholVolume?: decimal | string;
        price?: decimal | string;
        material?: string;
        minimumStock?: decimal | string;
        alertStock?: decimal | string;
        maximumStock?: decimal | string;
        firstArrival?: string;
        lastReceipt?: string;
        lastOutput?: string;
        lastStockCount?: string;
        defaultContainer?: string;
        defaultContainerLevel?: ContainerLevel;
        transmittedFromL3?: TransmissionL3;
        endOfLife?: string;
        isQualityControlManagement?: boolean | string;
        stockStatus?: string;
        isSingleLotControl?: boolean | string;
        samplingType?: SamplingType;
        generalLevelOfInspection?: string;
        aql?: decimal | string;
        freezingPoint?: integer | string;
        freezingReversibility?: ReversibleFreezing;
        ammNo?: string;
        referredQuantity?: decimal | string;
        referredUnit?: string;
        icpeClass?: string;
        flashPoint?: integer | string;
        transportCategory?: string;
        hazardousMaterialClass?: string;
        tunnelRestriction?: string;
        classificationCode?: string;
        packagingGroup?: PackagingGroup;
        onuCodes?: string;
        solventCode?: string;
        technicalField?: string;
        isActive?: boolean | string;
        isStockUnitManagement?: boolean | string;
        stockUnit?: string;
        siteDepositorIdentifier?: string;
        picture?: BinaryStream;
        activeMatters?: Partial<ProductActiveMattersInput>[];
        isPrintableDescriptions?: Partial<ProductIsPrintableDescriptionsInput>[];
        percentageActiveMatters?: Partial<ProductPercentageActiveMattersInput>[];
        stockCount?: string;
    }
    export interface ProductBindingExtension {
        _updateUser: SysUser;
        _createUser: SysUser;
        site: Site;
        depositor: Depositor;
        code: string;
        otherCode: string;
        localizedDescription: string;
        localizedDescription2: string;
        localizedShortDescription: string;
        family: Family;
        subFamily: SubFamily;
        group: Group;
        subGroup: SubGroup;
        isKeyInSerialNumber: boolean;
        stockCountClass: StockCountClass;
        numberStockCount: integer;
        isBlockedInInput: boolean;
        isBlockedInOutput: boolean;
        isBlockedInInput2: boolean;
        isBlockedInOutput2: boolean;
        isKeyInLotNumber: boolean;
        isSingleLot: boolean;
        isCrossDocking: boolean;
        isHazardousMaterials: boolean;
        isKeyInControlCode: boolean;
        fifoDateNature: FifoDate;
        source: Origin;
        inputMode: InputMode;
        outputMode: OutputMode;
        autoTransferMode: MovementType;
        detentionLength: integer;
        detentionUnit: UnitLength;
        useByDateLength: integer;
        useByDateUnit: UnitLength;
        sendByDateLength: integer;
        sendByDateUnit: UnitLength;
        sellByDateLength: integer;
        sellByDateUnit: UnitLength;
        fifoTolerance: integer;
        fifoGapUnit: UnitLength;
        netWeight: string;
        netVolume: string;
        pureAlcoholVolume: string;
        price: string;
        material: Risk;
        minimumStock: string;
        alertStock: string;
        maximumStock: string;
        firstArrival: string;
        lastReceipt: string;
        lastOutput: string;
        lastStockCount: string;
        defaultContainer: ProductsContainer;
        defaultContainerLevel: ContainerLevel;
        transmittedFromL3: TransmissionL3;
        endOfLife: string;
        isQualityControlManagement: boolean;
        stockStatus: StockNature;
        isSingleLotControl: boolean;
        samplingType: SamplingType;
        generalLevelOfInspection: string;
        aql: string;
        freezingPoint: integer;
        freezingReversibility: ReversibleFreezing;
        ammNo: string;
        referredQuantity: string;
        referredUnit: UnitOfMeasure;
        icpeClass: IcpeClasses;
        flashPoint: integer;
        transportCategory: TransportCategory;
        hazardousMaterialClass: HazardousMaterialsClass;
        tunnelRestriction: string;
        classificationCode: string;
        packagingGroup: PackagingGroup;
        onuCodes: OnuCode;
        solventCode: string;
        technicalField: string;
        isActive: boolean;
        isStockUnitManagement: boolean;
        stockUnit: UnitOfMeasure;
        siteDepositorIdentifier: string;
        picture: BinaryStream;
        activeMatters: ClientCollection<ProductActiveMattersBinding>;
        isPrintableDescriptions: ClientCollection<ProductIsPrintableDescriptionsBinding>;
        percentageActiveMatters: ClientCollection<ProductPercentageActiveMattersBinding>;
        stockCount: StockCount;
        stockObjects: ClientCollection<StockObject>;
    }
    export interface ProductExtension$Lookups {
        stockCount: QueryOperation<StockCount>;
    }
    export interface ProductExtension$Operations {
        lookups(dataOrId: string | { data: ProductInput }): ProductExtension$Lookups;
    }
    export interface Package {
        '@sage/wh-stock-data/AdjustmentMovementFinalsAndInitialsValues': AdjustmentMovementFinalsAndInitialsValues$Operations;
        '@sage/wh-stock-data/AdjustmentMovement': AdjustmentMovement$Operations;
        '@sage/wh-stock-data/AdministrativeReceiptLine': AdministrativeReceiptLine$Operations;
        '@sage/wh-stock-data/AdministrativeReceiptMovement': AdministrativeReceiptMovement$Operations;
        '@sage/wh-stock-data/AdministrativeReceipt': AdministrativeReceipt$Operations;
        '@sage/wh-stock-data/AssemblingMovementContainerLevels': AssemblingMovementContainerLevels$Operations;
        '@sage/wh-stock-data/AssemblingMovement': AssemblingMovement$Operations;
        '@sage/wh-stock-data/AssemblingOrderLine': AssemblingOrderLine$Operations;
        '@sage/wh-stock-data/AssemblingOrder': AssemblingOrder$Operations;
        '@sage/wh-stock-data/AssemblingWave': AssemblingWave$Operations;
        '@sage/wh-stock-data/AutoPalletizationOrder': AutoPalletizationOrder$Operations;
        '@sage/wh-stock-data/CarriageNote': CarriageNote$Operations;
        '@sage/wh-stock-data/CarriageReceiptShipToCompanyNames': CarriageReceiptShipToCompanyNames$Operations;
        '@sage/wh-stock-data/CarriageReceiptShiptToAddresses': CarriageReceiptShiptToAddresses$Operations;
        '@sage/wh-stock-data/CarriageReceipt': CarriageReceipt$Operations;
        '@sage/wh-stock-data/CountLine': CountLine$Operations;
        '@sage/wh-stock-data/Counting': Counting$Operations;
        '@sage/wh-stock-data/DeliveryNoteBillToAddresses': DeliveryNoteBillToAddresses$Operations;
        '@sage/wh-stock-data/DeliveryNoteBillToCompanyNames': DeliveryNoteBillToCompanyNames$Operations;
        '@sage/wh-stock-data/DeliveryNoteNumberOfDispatchableParcels': DeliveryNoteNumberOfDispatchableParcels$Operations;
        '@sage/wh-stock-data/DeliveryNoteShipToAddresses': DeliveryNoteShipToAddresses$Operations;
        '@sage/wh-stock-data/DeliveryNoteShipToCompanyNames': DeliveryNoteShipToCompanyNames$Operations;
        '@sage/wh-stock-data/DeliveryNote': DeliveryNote$Operations;
        '@sage/wh-stock-data/DeliveryOrderBillToAddresses': DeliveryOrderBillToAddresses$Operations;
        '@sage/wh-stock-data/DeliveryOrderBillToCompanyNames': DeliveryOrderBillToCompanyNames$Operations;
        '@sage/wh-stock-data/DeliveryOrderLine': DeliveryOrderLine$Operations;
        '@sage/wh-stock-data/DeliveryOrderShipToAddresses': DeliveryOrderShipToAddresses$Operations;
        '@sage/wh-stock-data/DeliveryOrderShipToCompanyNames': DeliveryOrderShipToCompanyNames$Operations;
        '@sage/wh-stock-data/DeliveryOrder': DeliveryOrder$Operations;
        '@sage/wh-stock-data/DirectInputAddresses': DirectInputAddresses$Operations;
        '@sage/wh-stock-data/DirectInputLine': DirectInputLine$Operations;
        '@sage/wh-stock-data/DirectInputSupplierNames': DirectInputSupplierNames$Operations;
        '@sage/wh-stock-data/DirectInput': DirectInput$Operations;
        '@sage/wh-stock-data/ExpectedInputAddresses': ExpectedInputAddresses$Operations;
        '@sage/wh-stock-data/ExpectedInputLine': ExpectedInputLine$Operations;
        '@sage/wh-stock-data/ExpectedInputSupplierNames': ExpectedInputSupplierNames$Operations;
        '@sage/wh-stock-data/ExpectedInput': ExpectedInput$Operations;
        '@sage/wh-stock-data/KitDeclaration': KitDeclaration$Operations;
        '@sage/wh-stock-data/OutputMovementContainerLevels': OutputMovementContainerLevels$Operations;
        '@sage/wh-stock-data/OutputMovement': OutputMovement$Operations;
        '@sage/wh-stock-data/Parcel': Parcel$Operations;
        '@sage/wh-stock-data/PickingOrder': PickingOrder$Operations;
        '@sage/wh-stock-data/ReceiptMovementContainerLevels': ReceiptMovementContainerLevels$Operations;
        '@sage/wh-stock-data/ReceiptMovement': ReceiptMovement$Operations;
        '@sage/wh-stock-data/Round': Round$Operations;
        '@sage/wh-stock-data/SerialNumberCountingLine': SerialNumberCountingLine$Operations;
        '@sage/wh-stock-data/SerialNumber': SerialNumber$Operations;
        '@sage/wh-stock-data/SerialTraceability': SerialTraceability$Operations;
        '@sage/wh-stock-data/ShippingUnitCompanyNames': ShippingUnitCompanyNames$Operations;
        '@sage/wh-stock-data/ShippingUnit': ShippingUnit$Operations;
        '@sage/wh-stock-data/StockCountCampaign': StockCountCampaign$Operations;
        '@sage/wh-stock-data/StockCountLinesByLocation': StockCountLinesByLocation$Operations;
        '@sage/wh-stock-data/StockCountLinesByProduct': StockCountLinesByProduct$Operations;
        '@sage/wh-stock-data/StockCount': StockCount$Operations;
        '@sage/wh-stock-data/StockObjectContainerLevels': StockObjectContainerLevels$Operations;
        '@sage/wh-stock-data/StockObject': StockObject$Operations;
        '@sage/wh-stock-data/StoringList': StoringList$Operations;
        '@sage/wh-stock-data/TransferMovementContainerLevels': TransferMovementContainerLevels$Operations;
        '@sage/wh-stock-data/TransferMovement': TransferMovement$Operations;
        '@sage/wh-stock-data/Wave': Wave$Operations;
    }
    export interface GraphApi
        extends Package,
            SageWhMasterData$Package,
            SageWhProductData$Package,
            SageWhStructure$Package,
            SageWhSystem$Package,
            SageXtremAppMetadata$Package,
            SageXtremX3SystemUtils$Package {}
}
declare module '@sage/wh-stock-data-api' {
    export type * from '@sage/wh-stock-data-api-partial';
}
declare module '@sage/wh-master-data-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/wh-stock-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/wh-product-data-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/wh-stock-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/wh-structure-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/wh-stock-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/wh-system-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/wh-stock-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/xtrem-app-metadata-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/wh-stock-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/xtrem-x3-system-utils-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/wh-stock-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/wh-master-data-api-partial' {
    import type {
        LocationBindingExtension,
        LocationExtension,
        LocationExtension$Lookups,
        LocationExtension$Operations,
        LocationInputExtension,
    } from '@sage/wh-stock-data-api';
    export interface Location extends LocationExtension {}
    export interface LocationBinding extends LocationBindingExtension {}
    export interface LocationInput extends LocationInputExtension {}
    export interface Location$Lookups extends LocationExtension$Lookups {}
    export interface Location$Operations extends LocationExtension$Operations {}
}
declare module '@sage/wh-product-data-api-partial' {
    import type {
        ProductBindingExtension,
        ProductExtension,
        ProductExtension$Lookups,
        ProductExtension$Operations,
        ProductInputExtension,
    } from '@sage/wh-stock-data-api';
    export interface Product extends ProductExtension {}
    export interface ProductBinding extends ProductBindingExtension {}
    export interface ProductInput extends ProductInputExtension {}
    export interface Product$Lookups extends ProductExtension$Lookups {}
    export interface Product$Operations extends ProductExtension$Operations {}
}
