"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDefaultSiteFromModule = exports.getSiteFromModule = exports.getUserProfile = void 0;
const xtrem_decimal_1 = require("@sage/xtrem-decimal"), typesLib = xtrem_decimal_1;
/**
 * Server-side function to get user profile
 */
/**
 * Internal function to get user profile
 * @param _this Instance of the user
 * @returns
 */
async function getUserProfile(_this) {
    if (_this) {
        const functionProfile = await _this.functionProfile;
        if (!functionProfile) {
            return (await (await _this.profession)?.functionProfile) ?? null;
        }
        return functionProfile;
    }
    return null;
}
exports.getUserProfile = getUserProfile;
/**
 *  get site from module
 * @param _this
 * @param moduleNumber
 * @param profile
 * @returns
 */
async function getSiteFromModule(_this, moduleNumber, profile) {
    const _userDefaultSites = await profile?.userProfileDefaultSites?.toArray();
    if (_userDefaultSites && typesLib.gt(moduleNumber, 0) && typesLib.lte(moduleNumber, _userDefaultSites.length)) {
        return _userDefaultSites[typesLib.sub(moduleNumber, 1)]?.site;
    }
    return null;
}
exports.getSiteFromModule = getSiteFromModule;
/**
 *  get default site for the user for given module
 * @param _this
 * @param moduleNumber
 * @returns
 */
async function getDefaultSiteFromModule(_this, moduleNumber) {
    const userProfile = await getUserProfile(_this);
    if (userProfile) {
        return (await getSiteFromModule(_this, moduleNumber, userProfile)) ?? null;
    }
    return null;
}
exports.getDefaultSiteFromModule = getDefaultSiteFromModule;
//# sourceMappingURL=user-parameters-values.js.map