import { stockControl } from '@sage/wh-master-data/build/lib/menu-items/stock-control';
import { getCurrentSiteDepositor } from '@sage/wh-master-data/lib/client-functions/get-selected-site-depositor';
import { SiteDepositor } from '@sage/wh-master-data/lib/client-functions/storage-properties';
import { Product } from '@sage/wh-product-data-api';
import { GraphApi } from '@sage/wh-stock-api';
import { setApplicativePageCrudActions } from '@sage/wh-system/lib/client-functions/applicative-crud-actions';
import { Dict } from '@sage/xtrem-client';
import * as ui from '@sage/xtrem-ui';
import { StockByProductArgs } from '../interfaces/index';

@ui.decorators.page<MobileViewStockByProduct>({
    title: 'View stock by product',
    mode: 'default',
    menuItem: stockControl,
    priority: 100,
    subtitle: 'Select a product',
    isTitleHidden: false,
    node: '@sage/wh-product-data/Product',
    isTransient: false,
    createAction: undefined,
    objectTypeSingular: 'Product',
    objectTypePlural: 'Products',
    authorizationCode: 'INQSTOPRO',
    // idField() {
    //     return this.code;
    // },
    // headerCard() {
    //     return {
    //         title: this.code,
    //     };
    // },
    headerDropDownActions() {
        return [
            // this.$standardSaveAction,
            // this.$standardCancelAction,
            // this.$standardOpenRecordHistoryAction,
            // this.$standardOpenAttachmentsDialog,
        ];
    },
    async onLoad() {
        if (!(await this._initSiteDepositor())) {
            this.disablePage();
            // Close the page
            this.$.finish();
        }
    },
    async onDirtyStateUpdated(isDirty: boolean) {
        setApplicativePageCrudActions({
            page: this,
            isDirty,
            save: undefined, // this.$standardSaveAction,
            cancel: undefined, //this.$standardCancelAction,
            remove: undefined, //this.$standardDeleteAction,
        });
    },
    businessActions() {
        return [
            // this.$standardSaveAction,
            // this.$standardCancelAction,
            // this.$standardNewAction,
            // this.$standardDeleteAction,
        ];
    },
    navigationPanel: {
        canFilter: false,
        isHeaderHidden: true,
        isAutoSelectEnabled: true,
        listItem: {
            title: ui.nestedFields.text({
                title: 'Product',
                bind: 'code',
                canFilter: true,
            }),
            titleRight: ui.nestedFields.checkbox({
                title: 'Lot',
                bind: 'isKeyInLotNumber',
                canFilter: false,
            }),
            line2: ui.nestedFields.text({
                title: 'Description',
                bind: 'localizedDescription',
                canFilter: true,
            }),
            line2Right: ui.nestedFields.checkbox({
                title: 'Serial number',
                bind: 'isKeyInSerialNumber',
                canFilter: false,
            }),
            line3: ui.nestedFields.reference({
                title: 'Stock unit',
                node: '@sage/wh-master-data/UnitOfMeasure',
                bind: 'stockUnit',
                valueField: 'code',
                canFilter: false,
                isHidden(value: any, rowValue?: Dict<Product>) {
                    return !rowValue?.isStockUnitManagement;
                },
                columns: [
                    ui.nestedFields.numeric({
                        bind: 'numberOfDecimals',
                        isHidden: true,
                    }),
                ],
            }),
            line3Right: ui.nestedFields.checkbox({
                title: 'Hazardous materials',
                bind: 'isHazardousMaterials',
                canFilter: false,
            }),
            line4: ui.nestedFields.checkbox({
                title: 'Stock unit management',
                bind: 'isStockUnitManagement',
                canFilter: false,
                isHidden: true,
            }),
            line4Right: ui.nestedFields.technical({
                node: '@sage/wh-product-data/OutputMode',
                bind: 'outputMode',
                nestedFields: [
                    ui.nestedFields.checkbox({
                        bind: 'code',
                    }),
                    ui.nestedFields.checkbox({
                        bind: 'isSerialNumberInOutputAllowed',
                    }),
                    ui.nestedFields.checkbox({
                        bind: 'isLocalizedSerialNumberAllowed',
                    }),
                ],
            }),
            line5: ui.nestedFields.numeric({
                bind: '_id',
                canFilter: false,
                isHidden: true,
            }),
        },
        orderBy: {
            code: 1,
        },
        async optionsMenu(_graph, _storage, _queryParam, _username, userCode) {
            const _selectedSiteDepositor = JSON.parse(_storage.get('mobile-selected-site-depositor') as string) as
                | SiteDepositor
                | undefined;
            return [
                {
                    title: '',
                    graphQLFilter: {
                        site: {
                            code: _selectedSiteDepositor?.site,
                        },
                        depositor: {
                            code: _selectedSiteDepositor?.depositor,
                        },
                        isActive: true,
                    },
                },
            ];
        },
        onSelect(product: any) {
            if (product && this.siteCodeSelected && this.depositorCodeSelected) {
                this.$.router.goTo(
                    `@sage/wh-stock/MobileViewStockByProductSelectStoreLocation`,
                    this._getCurrentParameters(product),
                );
            }
            return true;
        },
    },
})
export class MobileViewStockByProduct extends ui.Page<GraphApi> {
    /** internal properties */

    private siteCodeSelected: string | undefined;
    private depositorCodeSelected: string | undefined;

    /*
     *
     *  Sections
     *
     */

    @ui.decorators.section<MobileViewStockByProduct>({
        isTitleHidden: true,
        isHidden: true,
    })
    mainSection: ui.containers.Section;

    /*
     *
     *  Blocks
     *
     */

    @ui.decorators.block<MobileViewStockByProduct>({
        parent() {
            return this.mainSection;
        },
    })
    productBlock: ui.containers.Block;
    /*
     *
     *  Page properties
     *
     */
    // -----------------------------

    /*
     *
     *  Fields
     *
     */

    // -----------------------------------------------
    // Block: Product block
    // -----------------------------------------------

    @ui.decorators.checkboxField<MobileViewStockByProduct>({
        parent() {
            return this.productBlock;
        },
        isTransient: false,
        isMandatory: false,
        isDisabled: true,
        isHidden: true,
    })
    isStockUnitManagement: ui.fields.Checkbox;

    @ui.decorators.referenceField<MobileViewStockByProduct>({
        parent() {
            return this.productBlock;
        },
        title: 'Stock unit',
        isTransient: false,
        isMandatory: false,
        isDisabled: true,
        isHidden(value) {
            return !value || !this.isStockUnitManagement.value;
        },
    })
    stockUnit: ui.fields.Reference;

    @ui.decorators.checkboxField<MobileViewStockByProduct>({
        parent() {
            return this.productBlock;
        },
        title: 'Lot',
        isTransient: false,
        isMandatory: false,
        isDisabled: true,
        isHidden: true,
    })
    isKeyInLotNumber: ui.fields.Checkbox;

    @ui.decorators.checkboxField<MobileViewStockByProduct>({
        parent() {
            return this.productBlock;
        },
        title: 'Serial number',
        isTransient: false,
        isMandatory: false,
        isDisabled: true,
        isHidden: true,
    })
    isKeyInSerialNumber: ui.fields.Checkbox;

    @ui.decorators.checkboxField<MobileViewStockByProduct>({
        parent() {
            return this.productBlock;
        },
        title: 'Hazardous materials',
        isTransient: false,
        isMandatory: false,
        isDisabled: true,
        isHidden: true,
    })
    isHazardousMaterials: ui.fields.Checkbox;

    @ui.decorators.referenceField<MobileViewStockByProduct>({
        parent() {
            return this.productBlock;
        },
        title: 'Site',
        isReadOnly: true,
        isHidden: true,
    })
    site: ui.fields.Reference;

    @ui.decorators.referenceField<MobileViewStockByProduct>({
        parent() {
            return this.productBlock;
        },
        title: 'Depositor',
        isReadOnly: true,
        isHidden: true,
    })
    depositor: ui.fields.Reference;

    private async _initSiteDepositor(): Promise<boolean> {
        const siteDepositor = await getCurrentSiteDepositor(
            this,
            ui.localize('@sage/wh-stock/dialog-error-title', 'Error'),
            ui.localize(
                '@sage/wh-stock/dialog-error-location-inquiry-set-site-depositor',
                'Define a default site and depositor on the user function profile.',
            ),
        );
        if (siteDepositor && siteDepositor?.site && siteDepositor?.depositor) {
            this.siteCodeSelected = siteDepositor?.site;
            this.depositorCodeSelected = siteDepositor?.depositor;
            return true;
        }
        return false;
    }

    private async disablePage() {
        this.mainSection.isDisabled = true;
        this.productBlock.isDisabled = true;
    }

    /**
     * get query parameters
     * @returns expected parameters or undefined
     */
    private _getQueryParameters(): StockByProductArgs | undefined {
        try {
            return JSON.parse(String(this.$.queryParameters['stockByProductArgs'])) as StockByProductArgs;
        } catch (error) {
            ui.console.error(`Error retrieving query parameters:\n${JSON.stringify(error)}`);
            return undefined;
        }
    }

    /**
     * Return current parameter before chain another page
     * @return return the current parameters
     */
    private _getCurrentParameters(product: any): {
        stockByProductArgs: string;
    } {
        return {
            stockByProductArgs: JSON.stringify(<StockByProductArgs>{
                siteDepositorSelected: {
                    siteCode: this.siteCodeSelected,
                    depositorCode: this.depositorCodeSelected,
                },
                _id: product._id,
                productCode: product.code,
                localizedDescription: product.localizedDescription,
                isKeyInLotNumber: product.isKeyInLotNumber,
                isKeyInSerialNumber: product.isKeyInSerialNumber,
                isSerialNumberInOutputAllowed: product.outputMode?.isSerialNumberInOutputAllowed,
                isLocalizedSerialNumberAllowed: product.outputMode?.isLocalizedSerialNumberAllowed,
                isHazardousMaterials: product.isHazardousMaterials,
                isStockUnitManagement: product.isStockUnitManagement,
                ...(product.isStockUnitManagement && {
                    stockUnit: {
                        code: product.stockUnit?.code,
                        numberOfDecimals: product.stockUnit?.numberOfDecimals,
                    },
                }),
            }),
        };
    }
}
